=== modified file 'HACKING'
--- HACKING	2006-06-19 19:48:46 +0000
+++ HACKING	2006-06-20 07:55:43 +0000
@@ -282,6 +282,19 @@
     command changes it name or signature. Ideally only the tests for a
     given command are affected when a given command is changed.
 
+Doctests
+--------
+
+We make selective use of doctests__.  In general they should provide 
+*examples* within the API documentation which can incidentally be tested.  We 
+don't try to test every important case using doctests -- regular Python
+tests are generally a better solution.
+
+Most of these are in ``bzrlib/doc/api``.  More additions are welcome.
+
+  __ http://docs.python.org/lib/module-doctest.html
+
+
 Running tests
 =============
 Currently, bzr selftest is used to invoke tests.
@@ -406,4 +419,4 @@
 so, please reply and say so.)
 
 
-:: vim:tw=74:ai
+:: vim: ft=rst tw=74 ai

=== modified file 'Makefile'
--- Makefile	2006-05-11 02:23:31 +0000
+++ Makefile	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-all: 
+all:
 
 check:
 	./bzr selftest -v $(tests)
@@ -8,7 +8,16 @@
 check-msgeditor:
 	./bzr --no-plugins selftest -v msgeditor
 
-clean: 
+# Run Python style checker (apt-get install pyflakes)
+pyflakes:
+	pyflakes bzrlib
+
+pyflakes-nounused:
+	# There are many of these warnings at the moment and they're not a
+	# high priority to fix
+	pyflakes bzrlib | grep -v ' imported but unused'
+
+clean:
 	./setup.py clean
 	-find . -name "*.pyc" -o -name "*.pyo" | xargs rm -f
 	rm -rf test????.tmp

=== modified file 'NEWS'
--- NEWS	2006-06-17 19:01:45 +0000
+++ NEWS	2006-06-20 07:55:43 +0000
@@ -74,6 +74,9 @@
     * Fix unnecessary requirement of sign-my-commits that it be run from
       a working directory.  (Martin Pool, Robert Collins)
 
+    * 'bzr push location' will only remember the push location if it succeeds
+      in connecting to the remote location. (#49742, John Arbash Meinel)
+
   INTERNALS:
 
     * Combine the ignore rules into a single regex rather than looping over
@@ -87,6 +90,10 @@
     * bzrlib.delta.compare_trees now iterates in alphabetically sorted order,
       rather than randomly walking the inventories. (John Arbash Meinel)
 
+    * Doctests are now run in temporary directories which are cleaned up when
+      they finish, rather than using special ScratchDir/ScratchBranch objects.
+      (Martin Pool)
+
     * Split ``check`` into separate methods on the branch and on the repository,
       so that it can be specialized in ways that are useful or efficient for
       different formats.  (Martin Pool, Robert Collins)
@@ -103,6 +110,10 @@
       Uses subprocess instead of spawnvp.
       (#4047, #48914, James Henstridge, John Arbash Meinel)
 
+    * New command line option '--profile-imports', which will install a custom
+      importer to log time to import modules and regex compilation time to 
+      sys.stderr (John Arbash Meinel)
+
 bzr 0.8.2  2006-05-17
   
   BUG FIXES:

=== modified file 'bzr'
--- bzr	2006-05-17 07:09:13 +0000
+++ bzr	2006-06-19 14:40:19 +0000
@@ -16,7 +16,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Bazaar-NG -- a free distributed version-control tool"""
-import os, sys
+
+import os
+import sys
+
+
 if __doc__ is None:
     print "bzr does not support python -OO."
     sys.exit(2)
@@ -44,6 +48,16 @@
 if hasattr(os, "unsetenv"):
     os.unsetenv(REINVOKE)
 
+
+
+profiling = False
+if '--profile-imports' in sys.argv:
+    sys.argv.remove('--profile-imports')
+    import profile_imports
+    profile_imports.install()
+    profiling = True
+
+
 try:
     import bzrlib
     import bzrlib.commands
@@ -63,6 +77,10 @@
 
 if __name__ == '__main__':
     bzrlib.trace.enable_default_logging()
-    sys.exit(bzrlib.commands.main(sys.argv))
+    exit_val = bzrlib.commands.main(sys.argv)
+
+    if profiling:
+        profile_imports.log_stack_info(sys.stderr)
+    sys.exit(exit_val)
 else:
     pass    # should this give an error? - it can't be used as a lib

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2006-06-07 08:02:10 +0000
+++ bzrlib/__init__.py	2006-06-20 04:45:30 +0000
@@ -88,6 +88,7 @@
     sys.platform = 'darwin'
 else:
     import locale
+# XXX: This probably belongs in osutils instead
 user_encoding = locale.getpreferredencoding() or 'ascii'
 del locale
 

=== modified file 'bzrlib/add.py'
--- bzrlib/add.py	2006-06-13 12:55:45 +0000
+++ bzrlib/add.py	2006-06-20 04:45:30 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +14,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import errno
+import os
+from os.path import dirname
 import sys
-from os.path import dirname
 
 import bzrlib.errors as errors
 from bzrlib.inventory import InventoryEntry
@@ -132,8 +134,6 @@
     further dry-run tasks to take place. To restore the original inventory
     call tree.read_working_inventory().
     """
-    import os, errno
-    from bzrlib.errors import BadFileKindError, ForbiddenFileError
     assert isinstance(recurse, bool)
     if action is None:
         action = AddAction()
@@ -154,7 +154,7 @@
         # validate user parameters. Our recursive code avoids adding new files
         # that need such validation 
         if tree.is_control_filename(rf.raw_path):
-            raise ForbiddenFileError('cannot add control file %s' % filepath)
+            raise errors.ForbiddenControlFileError(filename=rf)
         
         abspath = tree.abspath(rf.raw_path)
         kind = bzrlib.osutils.file_kind(abspath)
@@ -163,7 +163,7 @@
             user_dirs.add(rf.raw_path)
         else:
             if not InventoryEntry.versionable_kind(kind):
-                raise BadFileKindError("cannot add %s of type %s" % (abspath, kind))
+                raise errors.BadFileKindError(filename=abspath, kind=kind)
         # ensure the named path is added, so that ignore rules in the later directory
         # walk dont skip it.
         # we dont have a parent ie known yet.: use the relatively slower inventory 

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2006-02-22 10:35:05 +0000
+++ bzrlib/annotate.py	2006-06-20 03:57:11 +0000
@@ -26,10 +26,8 @@
 # e.g. "3:12 Tue", "13 Oct", "Oct 2005", etc.  
 
 import sys
-import os
 import time
 
-import bzrlib.weave
 from bzrlib.config import extract_email_address
 from bzrlib.errors import BzrError
 

=== modified file 'bzrlib/atomicfile.py'
--- bzrlib/atomicfile.py	2005-12-18 04:08:46 +0000
+++ bzrlib/atomicfile.py	2006-06-20 03:57:11 +0000
@@ -14,11 +14,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
+import errno
+import os
 
 from warnings import warn
 from bzrlib.osutils import rename
-import errno
 
 class AtomicFile(object):
     """A file that does an atomic-rename to move into place.
@@ -35,7 +35,7 @@
         if mode != 'wb' and mode != 'wt':
             raise ValueError("invalid AtomicFile mode %r" % mode)
 
-        import os, socket
+        import socket
         self.tmpfilename = '%s.%d.%s.tmp' % (filename, os.getpid(),
                                              socket.gethostname())
         self.realfilename = filename
@@ -58,8 +58,7 @@
 
     def commit(self):
         """Close the file and move to final name."""
-        import sys, os
-        
+
         if self.closed:
             raise Exception('%r is already closed' % self)
 
@@ -81,7 +80,6 @@
 
     def abort(self):
         """Discard temporary file without committing changes."""
-        import os
 
         if self.closed:
             raise Exception('%r is already closed' % self)

=== modified file 'bzrlib/benchmarks/__init__.py'
--- bzrlib/benchmarks/__init__.py	2006-06-15 18:11:51 +0000
+++ bzrlib/benchmarks/__init__.py	2006-06-20 05:32:16 +0000
@@ -18,8 +18,8 @@
 """Benchmark test suite for bzr."""
 
 import bzrlib
+from bzrlib.tests.TestUtil import TestLoader
 from bzrlib.bzrdir import BzrDir
-from bzrlib.tests import TestLoader
 from bzrlib.tests.blackbox import ExternalBase
 
 class Benchmark(ExternalBase):

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-06-16 19:55:10 +0000
+++ bzrlib/branch.py	2006-06-21 11:13:11 +0000
@@ -17,15 +17,14 @@
 
 from copy import deepcopy
 from cStringIO import StringIO
-import errno
-import os
-import shutil
-import sys
 from unittest import TestSuite
 from warnings import warn
 
 import bzrlib
-import bzrlib.bzrdir as bzrdir
+from bzrlib import bzrdir, errors, lockdir, osutils, revision, \
+        tree, \
+        ui, \
+        urlutils
 from bzrlib.config import TreeConfig
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 import bzrlib.errors as errors
@@ -36,31 +35,14 @@
                            NotBranchError, UninitializableFormat, 
                            UnlistableStore, UnlistableBranch, 
                            )
-import bzrlib.inventory as inventory
-from bzrlib.inventory import Inventory
 from bzrlib.lockable_files import LockableFiles, TransportLock
-from bzrlib.lockdir import LockDir
-from bzrlib.osutils import (isdir, quotefn,
-                            rename, splitpath, sha_file,
-                            file_kind, abspath, normpath, pathjoin,
-                            safe_unicode,
-                            rmtree,
-                            )
-from bzrlib.repository import Repository
-from bzrlib.revision import (
-                             is_ancestor,
-                             NULL_REVISION,
-                             Revision,
-                             )
-from bzrlib.store import copy_all
-from bzrlib.symbol_versioning import *
-from bzrlib.textui import show_status
+from bzrlib.symbol_versioning import (deprecated_function,
+                                      deprecated_method,
+                                      DEPRECATED_PARAMETER,
+                                      deprecated_passed,
+                                      zero_eight,
+                                      )
 from bzrlib.trace import mutter, note
-import bzrlib.transactions as transactions
-from bzrlib.transport import Transport, get_transport
-import bzrlib.ui
-import bzrlib.urlutils as urlutils
-import bzrlib.xml5
 
 
 BZR_BRANCH_FORMAT_4 = "Bazaar-NG branch, format 0.0.4\n"
@@ -217,7 +199,7 @@
         if self.base == from_branch.base:
             return (0, [])
         if pb is None:
-            nested_pb = bzrlib.ui.ui_factory.nested_progress_bar()
+            nested_pb = ui.ui_factory.nested_progress_bar()
             pb = nested_pb
         else:
             nested_pb = None
@@ -231,7 +213,7 @@
                     last_revision = from_history[-1]
                 else:
                     # no history in the source branch
-                    last_revision = NULL_REVISION
+                    last_revision = revision.NULL_REVISION
             return self.repository.fetch(from_branch.repository,
                                          revision_id=last_revision,
                                          pb=nested_pb)
@@ -330,36 +312,6 @@
         
         If self and other have not diverged, return a list of the revisions
         present in other, but missing from self.
-
-        >>> from bzrlib.workingtree import WorkingTree
-        >>> bzrlib.trace.silent = True
-        >>> d1 = bzrdir.ScratchDir()
-        >>> br1 = d1.open_branch()
-        >>> wt1 = d1.open_workingtree()
-        >>> d2 = bzrdir.ScratchDir()
-        >>> br2 = d2.open_branch()
-        >>> wt2 = d2.open_workingtree()
-        >>> br1.missing_revisions(br2)
-        []
-        >>> wt2.commit("lala!", rev_id="REVISION-ID-1")
-        'REVISION-ID-1'
-        >>> br1.missing_revisions(br2)
-        [u'REVISION-ID-1']
-        >>> br2.missing_revisions(br1)
-        []
-        >>> wt1.commit("lala!", rev_id="REVISION-ID-1")
-        'REVISION-ID-1'
-        >>> br1.missing_revisions(br2)
-        []
-        >>> wt2.commit("lala!", rev_id="REVISION-ID-2A")
-        'REVISION-ID-2A'
-        >>> br1.missing_revisions(br2)
-        [u'REVISION-ID-2A']
-        >>> wt1.commit("lala!", rev_id="REVISION-ID-2B")
-        'REVISION-ID-2B'
-        >>> br1.missing_revisions(br2)
-        Traceback (most recent call last):
-        DivergedBranches: These branches have diverged.  Try merge.
         """
         self_history = self.revision_history()
         self_len = len(self_history)
@@ -375,7 +327,7 @@
         else:
             assert isinstance(stop_revision, int)
             if stop_revision > other_len:
-                raise bzrlib.errors.NoSuchRevision(self, stop_revision)
+                raise errors.NoSuchRevision(self, stop_revision)
         return other_history[self_len:stop_revision]
 
     def update_revisions(self, other, stop_revision=None):
@@ -578,6 +530,8 @@
         In particular this checks that revisions given in the revision-history
         do actually match up in the revision graph, and that they're all 
         present in the repository.
+        
+        Callers will typically also want to check the repository.
 
         :return: A BranchCheckResult.
         """
@@ -586,14 +540,14 @@
             try:
                 revision = self.repository.get_revision(revision_id)
             except errors.NoSuchRevision, e:
-                raise BzrCheckError("mainline revision {%s} not in repository"
-                        % revision_id)
+                raise errors.BzrCheckError("mainline revision {%s} not in repository"
+                            % revision_id)
             # In general the first entry on the revision history has no parents.
             # But it's not illegal for it to have parents listed; this can happen
             # in imports from Arch when the parents weren't reachable.
             if mainline_parent_id is not None:
                 if mainline_parent_id not in revision.parent_ids:
-                    raise BzrCheckError("previous revision {%s} not listed among "
+                    raise errors.BzrCheckError("previous revision {%s} not listed among "
                                         "parents of {%s}"
                                         % (mainline_parent_id, revision_id))
             mainline_parent_id = revision_id
@@ -634,7 +588,7 @@
         except NoSuchFile:
             raise NotBranchError(path=transport.base)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):
@@ -767,7 +721,7 @@
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
-        control_files = LockableFiles(branch_transport, 'lock', LockDir)
+        control_files = LockableFiles(branch_transport, 'lock', lockdir.LockDir)
         control_files.create_lock()
         control_files.lock_write()
         control_files.put_utf8('format', self.get_format_string())
@@ -792,7 +746,7 @@
             format = BranchFormat.find_format(a_bzrdir)
             assert format.__class__ == self.__class__
         transport = a_bzrdir.get_branch_transport(None)
-        control_files = LockableFiles(transport, 'lock', LockDir)
+        control_files = LockableFiles(transport, 'lock', lockdir.LockDir)
         return BzrBranch5(_format=self,
                           _control_files=control_files,
                           a_bzrdir=a_bzrdir,
@@ -913,7 +867,7 @@
         self._base = self._transport.base
         self._format = _format
         if _control_files is None:
-            raise BzrBadParameterMissing('_control_files')
+            raise ValueError('BzrBranch _control_files is None')
         self.control_files = _control_files
         if deprecated_passed(init):
             warn("BzrBranch.__init__(..., init=XXX): The init parameter is "
@@ -934,11 +888,7 @@
                  stacklevel=2)
             if (not relax_version_check
                 and not self._format.is_supported()):
-                raise errors.UnsupportedFormatError(
-                        'sorry, branch format %r not supported' % fmt,
-                        ['use a different bzr version',
-                         'or remove the .bzr directory'
-                         ' and "bzr init" again'])
+                raise errors.UnsupportedFormatError(format=fmt)
         if deprecated_passed(transport):
             warn("BzrBranch.__init__(transport=XXX...): The transport "
                  "parameter is deprecated as of bzr 0.8. "
@@ -962,7 +912,7 @@
         # XXX: cache_root seems to be unused, 2006-01-13 mbp
         if hasattr(self, 'cache_root') and self.cache_root is not None:
             try:
-                rmtree(self.cache_root)
+                osutils.rmtree(self.cache_root)
             except:
                 pass
             self.cache_root = None
@@ -1011,7 +961,7 @@
         FIXME: DELETE THIS METHOD when pre 0.8 support is removed.
         """
         if format is None:
-            format = BzrBranchFormat.find_format(self.bzrdir)
+            format = BranchFormat.find_format(self.bzrdir)
         self._format = format
         mutter("got branch format %s", self._format)
 
@@ -1100,6 +1050,35 @@
         return list(history)
 
     @needs_write_lock
+    def generate_revision_history(self, revision_id, last_rev=None, 
+        other_branch=None):
+        """Create a new revision history that will finish with revision_id.
+        
+        :param revision_id: the new tip to use.
+        :param last_rev: The previous last_revision. If not None, then this
+            must be a ancestory of revision_id, or DivergedBranches is raised.
+        :param other_branch: The other branch that DivergedBranches should
+            raise with respect to.
+        """
+        # stop_revision must be a descendant of last_revision
+        stop_graph = self.repository.get_revision_graph(revision_id)
+        if last_rev is not None and last_rev not in stop_graph:
+            # our previous tip is not merged into stop_revision
+            raise errors.DivergedBranches(self, other_branch)
+        # make a new revision history from the graph
+        current_rev_id = revision_id
+        new_history = []
+        while current_rev_id not in (None, revision.NULL_REVISION):
+            new_history.append(current_rev_id)
+            current_rev_id_parents = stop_graph[current_rev_id]
+            try:
+                current_rev_id = current_rev_id_parents[0]
+            except IndexError:
+                current_rev_id = None
+        new_history.reverse()
+        self.set_revision_history(new_history)
+
+    @needs_write_lock
     def update_revisions(self, other, stop_revision=None):
         """See Branch.update_revisions."""
         other.lock_read()
@@ -1119,23 +1098,8 @@
             if stop_revision in my_ancestry:
                 # last_revision is a descendant of stop_revision
                 return
-            # stop_revision must be a descendant of last_revision
-            stop_graph = self.repository.get_revision_graph(stop_revision)
-            if last_rev is not None and last_rev not in stop_graph:
-                # our previous tip is not merged into stop_revision
-                raise errors.DivergedBranches(self, other)
-            # make a new revision history from the graph
-            current_rev_id = stop_revision
-            new_history = []
-            while current_rev_id not in (None, NULL_REVISION):
-                new_history.append(current_rev_id)
-                current_rev_id_parents = stop_graph[current_rev_id]
-                try:
-                    current_rev_id = current_rev_id_parents[0]
-                except IndexError:
-                    current_rev_id = None
-            new_history.reverse()
-            self.set_revision_history(new_history)
+            self.generate_revision_history(stop_revision, last_rev=last_rev,
+                other_branch=other)
         finally:
             other.unlock()
 
@@ -1146,7 +1110,7 @@
     @deprecated_method(zero_eight)
     def working_tree(self):
         """Create a Working tree object for this branch."""
-        from bzrlib.workingtree import WorkingTree
+
         from bzrlib.transport.local import LocalTransport
         if (self.base.find('://') != -1 or 
             not isinstance(self._transport, LocalTransport)):
@@ -1173,7 +1137,7 @@
 
     def get_parent(self):
         """See Branch.get_parent."""
-        import errno
+
         _locs = ['parent', 'pull', 'x-pull']
         assert self.base[-1] == '/'
         for l in _locs:
@@ -1416,13 +1380,6 @@
 
 
 @deprecated_function(zero_eight)
-def ScratchBranch(*args, **kwargs):
-    """See bzrlib.bzrdir.ScratchDir."""
-    d = ScratchDir(*args, **kwargs)
-    return d.open_branch()
-
-
-@deprecated_function(zero_eight)
 def is_control_file(*args, **kwargs):
     """See bzrlib.workingtree.is_control_file."""
     return bzrlib.workingtree.is_control_file(*args, **kwargs)

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-06-19 08:54:42 +0000
+++ bzrlib/builtins.py	2006-06-21 13:37:30 +0000
@@ -20,33 +20,26 @@
 import codecs
 import errno
 import os
-from shutil import rmtree
 import sys
 
 import bzrlib
-import bzrlib.branch
-from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
+from bzrlib.branch import Branch, BranchReferenceFormat
+from bzrlib import (bundle, branch, bzrdir, errors, osutils, ui, config,
+    repository, log)
 from bzrlib.bundle import read_bundle_from_url
-from bzrlib.bundle.read_bundle import BundleReader
 from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
 from bzrlib.commands import Command, display_command
-import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, BzrCheckError, BzrCommandError, 
                            NotBranchError, DivergedBranches, NotConflicted,
                            NoSuchFile, NoWorkingTree, FileInWrongBranch,
                            NotVersionedError, NotABundle)
-from bzrlib.log import show_one_log
 from bzrlib.merge import Merge3Merger
 from bzrlib.option import Option
-import bzrlib.osutils
 from bzrlib.progress import DummyProgress, ProgressPhase
 from bzrlib.revision import common_ancestor
 from bzrlib.revisionspec import RevisionSpec
-import bzrlib.trace
-from bzrlib.trace import mutter, note, log_error, warning, is_quiet
+from bzrlib.trace import mutter, note, log_error, warning, is_quiet, info
 from bzrlib.transport.local import LocalTransport
-import bzrlib.ui
 import bzrlib.urlutils as urlutils
 from bzrlib.workingtree import WorkingTree
 
@@ -95,11 +88,11 @@
         return bzrdir.BzrDirMetaFormat1()
     if typestring == "metaweave":
         format = bzrdir.BzrDirMetaFormat1()
-        format.repository_format = bzrlib.repository.RepositoryFormat7()
+        format.repository_format = repository.RepositoryFormat7()
         return format
     if typestring == "knit":
         format = bzrdir.BzrDirMetaFormat1()
-        format.repository_format = bzrlib.repository.RepositoryFormatKnit1()
+        format.repository_format = repository.RepositoryFormatKnit1()
         return format
     msg = "Unknown bzr format %s. Current formats are: default, knit,\n" \
           "metaweave and weave" % typestring
@@ -416,7 +409,8 @@
 
     If there is no default location set, the first pull will set it.  After
     that, you can omit the location to use the default.  To change the
-    default, use --remember.
+    default, use --remember. The value will only be saved if the remote
+    location can be accessed.
     """
 
     takes_options = ['remember', 'overwrite', 'revision', 'verbose']
@@ -435,7 +429,7 @@
         reader = None
         if location is not None:
             try:
-                reader = read_bundle_from_url(location)
+                reader = bundle.read_bundle_from_url(location)
             except NotABundle:
                 pass # Continue on considering this url a Branch
 
@@ -462,7 +456,7 @@
         rev_id = None
         if revision is None:
             if reader is not None:
-                rev_id = reader.info.target
+                rev_id = reader.target
         elif len(revision) == 1:
             rev_id = revision[0].in_history(branch_from).rev_id
         else:
@@ -506,7 +500,8 @@
 
     If there is no default push location set, the first push will set it.
     After that, you can omit the location to use the default.  To change the
-    default, use --remember.
+    default, use --remember. The value will only be saved if the remote
+    location can be accessed.
     """
 
     takes_options = ['remember', 'overwrite', 'verbose',
@@ -530,17 +525,15 @@
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
-                self.outf.write("Using saved location: %s" % display_url)
+                self.outf.write("Using saved location: %s\n" % display_url)
                 location = stored_loc
 
         transport = get_transport(location)
         location_url = transport.base
-        if br_from.get_push_location() is None or remember:
-            br_from.set_push_location(location_url)
 
         old_rh = []
         try:
-            dir_to = bzrlib.bzrdir.BzrDir.open(location_url)
+            dir_to = bzrdir.BzrDir.open(location_url)
             br_to = dir_to.open_branch()
         except NotBranchError:
             # create a branch.
@@ -572,7 +565,14 @@
                 revision_id=br_from.last_revision())
             br_to = dir_to.open_branch()
             count = len(br_to.revision_history())
+            # We successfully created the target, remember it
+            if br_from.get_push_location() is None or remember:
+                br_from.set_push_location(br_to.base)
         else:
+            # We were able to connect to the remote location, so remember it
+            # we don't need to successfully push because of possible divergence.
+            if br_from.get_push_location() is None or remember:
+                br_from.set_push_location(br_to.base)
             old_rh = br_to.revision_history()
             try:
                 try:
@@ -618,7 +618,6 @@
 
     def run(self, from_location, to_location=None, revision=None, basis=None):
         from bzrlib.transport import get_transport
-        from bzrlib.osutils import rmtree
         if revision is None:
             revision = [None]
         elif len(revision) > 1:
@@ -654,10 +653,10 @@
             to_transport = get_transport(to_location)
             try:
                 to_transport.mkdir('.')
-            except bzrlib.errors.FileExists:
+            except errors.FileExists:
                 raise BzrCommandError('Target directory "%s" already'
                                       ' exists.' % to_location)
-            except bzrlib.errors.NoSuchFile:
+            except errors.NoSuchFile:
                 raise BzrCommandError('Parent of "%s" does not exist.' %
                                       to_location)
             try:
@@ -665,12 +664,12 @@
                 dir = br_from.bzrdir.sprout(to_transport.base,
                         revision_id, basis_dir)
                 branch = dir.open_branch()
-            except bzrlib.errors.NoSuchRevision:
+            except errors.NoSuchRevision:
                 to_transport.delete_tree('.')
                 msg = "The branch %s has no revision %s." % (from_location, revision[0])
                 raise BzrCommandError(msg)
-            except bzrlib.errors.UnlistableBranch:
-                rmtree(to_location)
+            except errors.UnlistableBranch:
+                osutils.rmtree(to_location)
                 msg = "The branch %s cannot be used as a --basis" % (basis,)
                 raise BzrCommandError(msg)
             if name:
@@ -719,7 +718,7 @@
             raise BzrCommandError(
                 'bzr checkout --revision takes exactly 1 revision value')
         if branch_location is None:
-            branch_location = bzrlib.osutils.getcwd()
+            branch_location = osutils.getcwd()
             to_location = branch_location
         source = Branch.open(branch_location)
         if len(revision) == 1 and revision[0] is not None:
@@ -731,8 +730,8 @@
         # if the source and to_location are the same, 
         # and there is no working tree,
         # then reconstitute a branch
-        if (bzrlib.osutils.abspath(to_location) == 
-            bzrlib.osutils.abspath(branch_location)):
+        if (osutils.abspath(to_location) == 
+            osutils.abspath(branch_location)):
             try:
                 source.bzrdir.open_workingtree()
             except errors.NoWorkingTree:
@@ -749,14 +748,14 @@
                                       to_location)
             else:
                 raise
-        old_format = bzrlib.bzrdir.BzrDirFormat.get_default_format()
-        bzrlib.bzrdir.BzrDirFormat.set_default_format(bzrdir.BzrDirMetaFormat1())
+        old_format = bzrdir.BzrDirFormat.get_default_format()
+        bzrdir.BzrDirFormat.set_default_format(bzrdir.BzrDirMetaFormat1())
         try:
             if lightweight:
                 checkout = bzrdir.BzrDirMetaFormat1().initialize(to_location)
-                bzrlib.branch.BranchReferenceFormat().initialize(checkout, source)
+                branch.BranchReferenceFormat().initialize(checkout, source)
             else:
-                checkout_branch =  bzrlib.bzrdir.BzrDir.create_branch_convenience(
+                checkout_branch =  bzrdir.BzrDir.create_branch_convenience(
                     to_location, force_new_tree=False)
                 checkout = checkout_branch.bzrdir
                 checkout_branch.bind(source)
@@ -765,7 +764,7 @@
                     checkout_branch.set_revision_history(rh[:rh.index(revision_id) + 1])
             checkout.create_workingtree(revision_id)
         finally:
-            bzrlib.bzrdir.BzrDirFormat.set_default_format(old_format)
+            bzrdir.BzrDirFormat.set_default_format(old_format)
 
 
 class cmd_renames(Command):
@@ -778,11 +777,11 @@
 
     @display_command
     def run(self, dir=u'.'):
+        from bzrlib.tree import find_renames
         tree = WorkingTree.open_containing(dir)[0]
         old_inv = tree.basis_tree().inventory
         new_inv = tree.read_working_inventory()
-
-        renames = list(bzrlib.tree.find_renames(old_inv, new_inv))
+        renames = list(find_renames(old_inv, new_inv))
         renames.sort()
         for old_name, new_name in renames:
             self.outf.write("%s => %s\n" % (old_name, new_name))
@@ -936,7 +935,7 @@
 
     def run(self, branch="."):
         from bzrlib.reconcile import reconcile
-        dir = bzrlib.bzrdir.BzrDir.open(branch)
+        dir = bzrdir.BzrDir.open(branch)
         reconcile(dir)
 
 
@@ -1009,7 +1008,6 @@
                             type=get_format_type),
                      ]
     def run(self, location=None, format=None):
-        from bzrlib.branch import Branch
         if format is None:
             format = get_format_type('default')
         if location is None:
@@ -1214,7 +1212,7 @@
             if file_id in basis_inv:
                 continue
             path = inv.id2path(file_id)
-            if not os.access(bzrlib.osutils.abspath(path), os.F_OK):
+            if not os.access(osutils.abspath(path), os.F_OK):
                 continue
             self.outf.write(path + '\n')
 
@@ -1329,7 +1327,7 @@
             (rev2, rev1) = (rev1, rev2)
 
         if (log_format == None):
-            default = bzrlib.config.BranchConfig(b).log_format()
+            default = config.BranchConfig(b).log_format()
             log_format = get_log_format(long=long, short=short, line=line, default=default)
         lf = log_formatter(log_format,
                            show_ids=show_ids,
@@ -1372,7 +1370,7 @@
         b = tree.branch
         inv = tree.read_working_inventory()
         file_id = inv.path2id(relpath)
-        for revno, revision_id, what in bzrlib.log.find_touching_revisions(b, file_id):
+        for revno, revision_id, what in log.find_touching_revisions(b, file_id):
             self.outf.write("%6d %s\n" % (revno, what))
 
 
@@ -1434,9 +1432,8 @@
     """List unknown files."""
     @display_command
     def run(self):
-        from bzrlib.osutils import quotefn
         for f in WorkingTree.open_containing(u'.')[0].unknowns():
-            self.outf.write(quotefn(f) + '\n')
+            self.outf.write(osutils.quotefn(f) + '\n')
 
 
 class cmd_ignore(Command):
@@ -1606,7 +1603,7 @@
     hidden = True    
     @display_command
     def run(self):
-        print bzrlib.osutils.local_time_offset()
+        print osutils.local_time_offset()
 
 
 
@@ -1690,7 +1687,7 @@
             message = codecs.open(file, 'rt', bzrlib.user_encoding).read()
 
         if message == "":
-                raise BzrCommandError("empty commit message specified")
+            raise BzrCommandError("empty commit message specified")
         
         if verbose:
             reporter = ReportCommitToLog()
@@ -1789,14 +1786,13 @@
     def run(self, email=False):
         try:
             b = WorkingTree.open_containing(u'.')[0].branch
-            config = bzrlib.config.BranchConfig(b)
+            c = config.BranchConfig(b)
         except NotBranchError:
-            config = bzrlib.config.GlobalConfig()
-        
+            c = config.GlobalConfig()
         if email:
-            print config.user_email()
+            print c.user_email()
         else:
-            print config.username()
+            print c.username()
 
 
 class cmd_nick(Command):
@@ -1882,13 +1878,13 @@
         # we don't want progress meters from the tests to go to the
         # real output; and we don't want log messages cluttering up
         # the real logs.
-        save_ui = bzrlib.ui.ui_factory
-        print '%10s: %s' % ('bzr', bzrlib.osutils.realpath(sys.argv[0]))
+        save_ui = ui.ui_factory
+        print '%10s: %s' % ('bzr', osutils.realpath(sys.argv[0]))
         print '%10s: %s' % ('bzrlib', bzrlib.__path__[0])
         print
-        bzrlib.trace.info('running tests...')
+        info('running tests...')
         try:
-            bzrlib.ui.ui_factory = bzrlib.ui.SilentUIFactory()
+            ui.ui_factory = ui.SilentUIFactory()
             if testspecs_list is not None:
                 pattern = '|'.join(testspecs_list)
             else:
@@ -1909,29 +1905,27 @@
                               test_suite_factory=test_suite_factory,
                               lsprof_timed=lsprof_timed)
             if result:
-                bzrlib.trace.info('tests passed')
+                info('tests passed')
             else:
-                bzrlib.trace.info('tests failed')
+                info('tests failed')
             return int(not result)
         finally:
-            bzrlib.ui.ui_factory = save_ui
+            ui.ui_factory = save_ui
 
 
 def _get_bzr_branch():
     """If bzr is run from a branch, return Branch or None"""
-    import bzrlib.errors
-    from bzrlib.branch import Branch
-    from bzrlib.osutils import abspath
     from os.path import dirname
     
     try:
-        branch = Branch.open(dirname(abspath(dirname(__file__))))
+        branch = Branch.open(dirname(osutils.abspath(dirname(__file__))))
         return branch
-    except bzrlib.errors.BzrError:
+    except errors.BzrError:
         return None
     
 
 def show_version():
+    import bzrlib
     print "bzr (bazaar-ng) %s" % bzrlib.__version__
     # is bzrlib itself in a branch?
     branch = _get_bzr_branch()
@@ -2003,28 +1997,16 @@
         base_rev_id = common_ancestor(last1, last2, source)
 
         print 'merge base is revision %s' % base_rev_id
-        
-        return
-
-        if base_revno is None:
-            raise bzrlib.errors.UnrelatedBranches()
-
-        print ' r%-6d in %s' % (base_revno, branch)
-
-        other_revno = branch2.revision_id_to_revno(base_revid)
-        
-        print ' r%-6d in %s' % (other_revno, other)
-
 
 
 class cmd_merge(Command):
     """Perform a three-way merge.
     
-    The branch is the branch you will merge from.  By default, it will
-    merge the latest revision.  If you specify a revision, that
-    revision will be merged.  If you specify two revisions, the first
-    will be used as a BASE, and the second one as OTHER.  Revision
-    numbers are always relative to the specified branch.
+    The branch is the branch you will merge from.  By default, it will merge
+    the latest revision.  If you specify a revision, that revision will be
+    merged.  If you specify two revisions, the first will be used as a BASE,
+    and the second one as OTHER.  Revision numbers are always relative to the
+    specified branch.
 
     By default, bzr will try to merge in all new work from the other
     branch, automatically determining an appropriate base.  If this
@@ -2039,7 +2021,8 @@
 
     If there is no default branch set, the first merge will set it. After
     that, you can omit the branch to use the default.  To change the
-    default, use --remember.
+    default, use --remember. The value will only be saved if the remote
+    location can be accessed.
 
     Examples:
 
@@ -2076,7 +2059,7 @@
 
         if branch is not None:
             try:
-                reader = read_bundle_from_url(branch)
+                reader = bundle.read_bundle_from_url(branch)
             except NotABundle:
                 pass # Continue on considering this url a Branch
             else:
@@ -2116,7 +2099,7 @@
             interesting_files = [path]
         else:
             interesting_files = None
-        pb = bzrlib.ui.ui_factory.nested_progress_bar()
+        pb = ui.ui_factory.nested_progress_bar()
         try:
             try:
                 conflict_count = merge(other, base, check_clean=(not force),
@@ -2130,7 +2113,7 @@
                 return 1
             else:
                 return 0
-        except bzrlib.errors.AmbiguousBase, e:
+        except errors.AmbiguousBase, e:
             m = ("sorry, bzr can't determine the right merge base yet\n"
                  "candidates are:\n  "
                  + "\n  ".join(e.bases)
@@ -2269,7 +2252,7 @@
             raise BzrCommandError('bzr revert --revision takes exactly 1 argument')
         else:
             rev_id = revision[0].in_history(tree.branch).rev_id
-        pb = bzrlib.ui.ui_factory.nested_progress_bar()
+        pb = ui.ui_factory.nested_progress_bar()
         try:
             tree.revert(file_list, 
                         tree.branch.repository.revision_tree(rev_id),
@@ -2323,7 +2306,6 @@
     takes_args = ['from_branch', 'to_branch']
     def run(self, from_branch, to_branch):
         from bzrlib.fetch import Fetcher
-        from bzrlib.branch import Branch
         from_b = Branch.open(from_branch)
         to_b = Branch.open(to_branch)
         Fetcher(to_b, from_b)
@@ -2352,14 +2334,14 @@
             show_ids=False, verbose=False):
         from bzrlib.missing import find_unmerged, iter_log_data
         from bzrlib.log import log_formatter
-        local_branch = bzrlib.branch.Branch.open_containing(u".")[0]
+        local_branch = Branch.open_containing(u".")[0]
         parent = local_branch.get_parent()
         if other_branch is None:
             other_branch = parent
             if other_branch is None:
                 raise BzrCommandError("No missing location known or specified.")
             print "Using last location: " + local_branch.get_parent()
-        remote_branch = bzrlib.branch.Branch.open(other_branch)
+        remote_branch = Branch.open(other_branch)
         if remote_branch.base == local_branch.base:
             remote_branch = local_branch
         local_branch.lock_read()
@@ -2368,7 +2350,7 @@
             try:
                 local_extra, remote_extra = find_unmerged(local_branch, remote_branch)
                 if (log_format == None):
-                    default = bzrlib.config.BranchConfig(local_branch).log_format()
+                    default = config.BranchConfig(local_branch).log_format()
                     log_format = get_log_format(long=long, short=short, line=line, default=default)
                 lf = log_formatter(log_format, sys.stdout,
                                    show_ids=show_ids,
@@ -2433,11 +2415,16 @@
 
 class cmd_testament(Command):
     """Show testament (signing-form) of a revision."""
-    takes_options = ['revision', 'long']
+    takes_options = ['revision', 'long', 
+                     Option('strict', help='Produce a strict testament')]
     takes_args = ['branch?']
     @display_command
-    def run(self, branch=u'.', revision=None, long=False):
-        from bzrlib.testament import Testament
+    def run(self, branch=u'.', revision=None, long=False, strict=False):
+        from bzrlib.testament import Testament, StrictTestament
+        if strict is True:
+            testament_class = StrictTestament
+        else:
+            testament_class = Testament
         b = WorkingTree.open_containing(branch)[0].branch
         b.lock_read()
         try:
@@ -2445,7 +2432,7 @@
                 rev_id = b.last_revision()
             else:
                 rev_id = revision[0].in_history(b).rev_id
-            t = Testament.from_revision(b.repository, rev_id)
+            t = testament_class.from_revision(b.repository, rev_id)
             if long:
                 sys.stdout.writelines(t.as_text_lines())
             else:
@@ -2503,7 +2490,6 @@
     takes_options = ['revision']
     
     def run(self, revision_id_list=None, revision=None):
-        import bzrlib.config as config
         import bzrlib.gpg as gpg
         if revision_id_list is not None and revision is not None:
             raise BzrCommandError('You can only supply one of revision_id or --revision')
@@ -2571,7 +2557,7 @@
             raise BzrCommandError('Local branch is not bound')
 
 
-class cmd_uncommit(bzrlib.commands.Command):
+class cmd_uncommit(Command):
     """Remove the last committed revision.
 
     --verbose will print out what is being removed.
@@ -2595,7 +2581,6 @@
     def run(self, location=None, 
             dry_run=False, verbose=False,
             revision=None, force=False):
-        from bzrlib.branch import Branch
         from bzrlib.log import log_formatter
         import sys
         from bzrlib.uncommit import uncommit

=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2006-06-15 21:24:47 +0000
+++ bzrlib/bundle/__init__.py	2006-06-21 13:37:30 +0000
@@ -14,10 +14,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from bzrlib.bundle.serializer import read_bundle
 import bzrlib.errors as errors
 import bzrlib.urlutils
 import bzrlib.transport
-import bzrlib.bundle.read_bundle
 
 
 def read_bundle_from_url(url):
@@ -38,7 +38,7 @@
     try:
         t = bzrlib.transport.get_transport(url)
         f = t.get(filename)
-        return bzrlib.bundle.read_bundle.BundleReader(f)
+        return read_bundle(f)
     except (errors.TransportError, errors.PathError), e:
         raise errors.NotABundle(str(e))
 

=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2006-06-06 18:15:46 +0000
+++ bzrlib/bundle/apply_bundle.py	2006-06-20 02:32:24 +0000
@@ -13,7 +13,7 @@
     pb = bzrlib.ui.ui_factory.nested_progress_bar()
     repository.lock_write()
     try:
-        real_revisions = bundle_reader.info.real_revisions
+        real_revisions = bundle_reader.real_revisions
         for i, revision in enumerate(reversed(real_revisions)):
             pb.update("Install revisions",i, len(real_revisions))
             if repository.has_revision(revision.revision_id):
@@ -38,9 +38,9 @@
         merger.pp = pp
         merger.pp.next_phase()
         merger.check_basis(check_clean, require_commits=False)
-        merger.other_rev_id = reader.info.target
-        merger.other_tree = merger.revision_tree(reader.info.target)
-        merger.other_basis = reader.info.target
+        merger.other_rev_id = reader.target
+        merger.other_tree = merger.revision_tree(reader.target)
+        merger.other_basis = reader.target
         merger.pp.next_phase()
         merger.find_base()
         if merger.base_rev_id == merger.other_rev_id:

=== renamed file 'bzrlib/bundle/read_bundle.py' => 'bzrlib/bundle/bundle_data.py'
--- bzrlib/bundle/read_bundle.py	2006-06-22 17:30:03 +0000
+++ bzrlib/bundle/bundle_data.py	2006-06-22 18:24:25 +0000
@@ -21,14 +21,13 @@
 import os
 import pprint
 
-from bzrlib.bundle.common import get_header, header_str
 import bzrlib.errors
 from bzrlib.errors import (TestamentMismatch, BzrError, 
                            MalformedHeader, MalformedPatches, NotABundle)
 from bzrlib.inventory import (Inventory, InventoryEntry,
                               InventoryDirectory, InventoryFile,
                               InventoryLink)
-from bzrlib.osutils import sha_file, sha_string
+from bzrlib.osutils import sha_file, sha_string, pathjoin
 from bzrlib.revision import Revision, NULL_REVISION
 from bzrlib.testament import StrictTestament
 from bzrlib.trace import mutter, warning
@@ -168,63 +167,22 @@
                 return r
         raise KeyError(revision_id)
 
-
-class BundleReader(object):
-    """This class reads in a bundle from a file, and returns
-    a Bundle object, which can then be applied against a tree.
-    """
-    def __init__(self, from_file):
-        """Read in the bundle from the file.
-
-        :param from_file: A file-like object (must have iterator support).
-        """
-        object.__init__(self)
-        self.from_file = iter(from_file)
-        self._next_line = None
-        
-        self.info = BundleInfo()
-        # We put the actual inventory ids in the footer, so that the patch
-        # is easier to read for humans.
-        # Unfortunately, that means we need to read everything before we
-        # can create a proper bundle.
-        self._read()
-        self._validate()
-
-    def _read(self):
-        self._read_header()
-        while self._next_line is not None:
-            if not self._read_revision_header():
-                break
-            if self._next_line is None:
-                break
-            self._read_patches()
-            self._read_footer()
-
-    def _validate(self):
-        """Make sure that the information read in makes sense
-        and passes appropriate checksums.
-        """
-        # Fill in all the missing blanks for the revisions
-        # and generate the real_revisions list.
-        self.info.complete_info()
-
-    def _validate_revision(self, inventory, revision_id):
-        """Make sure all revision entries match their checksum."""
-
-        # This is a mapping from each revision id to it's sha hash
-        rev_to_sha1 = {}
-        
-        rev = self.info.get_revision(revision_id)
-        rev_info = self.info.get_revision_info(revision_id)
-        assert rev.revision_id == rev_info.revision_id
-        assert rev.revision_id == revision_id
-        sha1 = StrictTestament(rev, inventory).as_sha1()
-        if sha1 != rev_info.sha1:
-            raise TestamentMismatch(rev.revision_id, rev_info.sha1, sha1)
-        if rev_to_sha1.has_key(rev.revision_id):
-            raise BzrError('Revision {%s} given twice in the list'
-                    % (rev.revision_id))
-        rev_to_sha1[rev.revision_id] = sha1
+    def revision_tree(self, repository, revision_id, base=None):
+        revision = self.get_revision(revision_id)
+        base = self.get_base(revision)
+        assert base != revision_id
+        self._validate_references_from_repository(repository)
+        revision_info = self.get_revision_info(revision_id)
+        inventory_revision_id = revision_id
+        bundle_tree = BundleTree(repository.revision_tree(base), 
+                                  inventory_revision_id)
+        self._update_tree(bundle_tree, revision_id)
+
+        inv = bundle_tree.inventory
+        self._validate_inventory(inv, revision_id)
+        self._validate_revision(inv, revision_id)
+
+        return bundle_tree
 
     def _validate_references_from_repository(self, repository):
         """Now that we have a repository which should have some of the
@@ -252,11 +210,11 @@
         # All of the contained revisions were checked
         # in _validate_revisions
         checked = {}
-        for rev_info in self.info.revisions:
+        for rev_info in self.revisions:
             checked[rev_info.revision_id] = True
             add_sha(rev_to_sha, rev_info.revision_id, rev_info.sha1)
                 
-        for (rev, rev_info) in zip(self.info.real_revisions, self.info.revisions):
+        for (rev, rev_info) in zip(self.real_revisions, self.revisions):
             add_sha(inv_to_sha, rev_info.revision_id, rev_info.inventory_sha1)
 
         count = 0
@@ -306,219 +264,30 @@
         s = serializer_v5.write_inventory_to_string(inv)
         sha1 = sha_string(s)
         # Target revision is the last entry in the real_revisions list
-        rev = self.info.get_revision(revision_id)
+        rev = self.get_revision(revision_id)
         assert rev.revision_id == revision_id
         if sha1 != rev.inventory_sha1:
             open(',,bogus-inv', 'wb').write(s)
             warning('Inventory sha hash mismatch for revision %s. %s'
                     ' != %s' % (revision_id, sha1, rev.inventory_sha1))
 
-    def get_bundle(self, repository):
-        """Return the meta information, and a Bundle tree which can
-        be used to populate the local stores and working tree, respectively.
-        """
-        return self.info, self.revision_tree(repository, self.info.target)
-
-    def revision_tree(self, repository, revision_id, base=None):
-        revision = self.info.get_revision(revision_id)
-        base = self.info.get_base(revision)
-        assert base != revision_id
-        self._validate_references_from_repository(repository)
-        revision_info = self.info.get_revision_info(revision_id)
-        inventory_revision_id = revision_id
-        bundle_tree = BundleTree(repository.revision_tree(base), 
-                                  inventory_revision_id)
-        self._update_tree(bundle_tree, revision_id)
-
-        inv = bundle_tree.inventory
-        self._validate_inventory(inv, revision_id)
-        self._validate_revision(inv, revision_id)
-
-        return bundle_tree
-
-    def _next(self):
-        """yield the next line, but secretly
-        keep 1 extra line for peeking.
-        """
-        # FIXME:
-        # The current implementation of this is technically borked
-        # 'self._next()' returns a generator, but there are multiple
-        # calls to it. So if it wasn't for the fact that 'from_file'
-        # keeps track of a current position, this would break
-        for line in self.from_file:
-            last = self._next_line
-            self._next_line = line
-            if last is not None:
-                #mutter('yielding line: %r' % last)
-                yield last
-        last = self._next_line
-        self._next_line = None
-        #mutter('yielding line: %r' % last)
-        yield last
-
-    def _read_header(self):
-        """Read the bzr header"""
-        header = get_header()
-        found = False
-        for line in self._next():
-            if found:
-                # not all mailers will keep trailing whitespace
-                if line == '#\n':
-                    line = '# \n'
-                if (not line.startswith('# ') or not line.endswith('\n')
-                        or line[2:-1].decode('utf-8') != header[0]):
-                    raise MalformedHeader('Found a header, but it'
-                        ' was improperly formatted')
-                header.pop(0) # We read this line.
-                if not header:
-                    break # We found everything.
-            elif (line.startswith('#') and line.endswith('\n')):
-                line = line[1:-1].strip().decode('utf-8')
-                if line[:len(header_str)] == header_str:
-                    if line == header[0]:
-                        found = True
-                    else:
-                        raise MalformedHeader('Found what looks like'
-                                ' a header, but did not match')
-                    header.pop(0)
-        else:
-            raise NotABundle('Did not find an opening header')
-
-    def _read_revision_header(self):
-        self.info.revisions.append(RevisionInfo(None))
-        found_something = False
-        for line in self._next():
-            # The bzr header is terminated with a blank line
-            # which does not start with '#'
-            if line is None or line == '\n':
-                break
-            found_something = True
-            self._handle_next(line)
-        if not found_something:
-            # Remove the entry we just added, there isn't anything here
-            self.info.revisions.pop()
-        return found_something
-
-    def _read_next_entry(self, line, indent=1):
-        """Read in a key-value pair
-        """
-        if not line.startswith('#'):
-            raise MalformedHeader('Bzr header did not start with #')
-        line = line[1:-1].decode('utf-8') # Remove the '#' and '\n'
-        if line[:indent] == ' '*indent:
-            line = line[indent:]
-        if not line:
-            return None, None# Ignore blank lines
-
-        loc = line.find(': ')
-        if loc != -1:
-            key = line[:loc]
-            value = line[loc+2:]
-            if not value:
-                value = self._read_many(indent=indent+2)
-        elif line[-1:] == ':':
-            key = line[:-1]
-            value = self._read_many(indent=indent+2)
-        else:
-            raise MalformedHeader('While looking for key: value pairs,'
-                    ' did not find the colon %r' % (line))
-
-        key = key.replace(' ', '_')
-        #mutter('found %s: %s' % (key, value))
-        return key, value
-
-    def _handle_next(self, line):
-        if line is None:
-            return
-        key, value = self._read_next_entry(line, indent=1)
-        #mutter('_handle_next %r => %r' % (key, value))
-        if key is None:
-            return
-
-        revision_info = self.info.revisions[-1]
-        if hasattr(revision_info, key):
-            if getattr(revision_info, key) is None:
-                setattr(revision_info, key, value)
-            else:
-                raise MalformedHeader('Duplicated Key: %s' % key)
-        else:
-            # What do we do with a key we don't recognize
-            raise MalformedHeader('Unknown Key: "%s"' % key)
-    
-    def _read_many(self, indent):
-        """If a line ends with no entry, that means that it should be
-        followed with multiple lines of values.
-
-        This detects the end of the list, because it will be a line that
-        does not start properly indented.
-        """
-        values = []
-        start = '#' + (' '*indent)
-
-        if self._next_line is None or self._next_line[:len(start)] != start:
-            return values
-
-        for line in self._next():
-            values.append(line[len(start):-1].decode('utf-8'))
-            if self._next_line is None or self._next_line[:len(start)] != start:
-                break
-        return values
-
-    def _read_one_patch(self):
-        """Read in one patch, return the complete patch, along with
-        the next line.
-
-        :return: action, lines, do_continue
-        """
-        #mutter('_read_one_patch: %r' % self._next_line)
-        # Peek and see if there are no patches
-        if self._next_line is None or self._next_line.startswith('#'):
-            return None, [], False
-
-        first = True
-        lines = []
-        for line in self._next():
-            if first:
-                if not line.startswith('==='):
-                    raise MalformedPatches('The first line of all patches'
-                        ' should be a bzr meta line "==="'
-                        ': %r' % line)
-                action = line[4:-1].decode('utf-8')
-            elif line.startswith('... '):
-                action += line[len('... '):-1].decode('utf-8')
-
-            if (self._next_line is not None and 
-                self._next_line.startswith('===')):
-                return action, lines, True
-            elif self._next_line is None or self._next_line.startswith('#'):
-                return action, lines, False
-
-            if first:
-                first = False
-            elif not line.startswith('... '):
-                lines.append(line)
-
-        return action, lines, False
-            
-    def _read_patches(self):
-        do_continue = True
-        revision_actions = []
-        while do_continue:
-            action, lines, do_continue = self._read_one_patch()
-            if action is not None:
-                revision_actions.append((action, lines))
-        assert self.info.revisions[-1].tree_actions is None
-        self.info.revisions[-1].tree_actions = revision_actions
-
-    def _read_footer(self):
-        """Read the rest of the meta information."""
-        for line in self._next():
-            self._handle_next(line)
-            if not self._next_line.startswith('#'):
-                self._next().next()
-                break
-            if self._next_line is None:
-                break
+    def _validate_revision(self, inventory, revision_id):
+        """Make sure all revision entries match their checksum."""
+
+        # This is a mapping from each revision id to it's sha hash
+        rev_to_sha1 = {}
+        
+        rev = self.get_revision(revision_id)
+        rev_info = self.get_revision_info(revision_id)
+        assert rev.revision_id == rev_info.revision_id
+        assert rev.revision_id == revision_id
+        sha1 = StrictTestament(rev, inventory).as_sha1()
+        if sha1 != rev_info.sha1:
+            raise TestamentMismatch(rev.revision_id, rev_info.sha1, sha1)
+        if rev_to_sha1.has_key(rev.revision_id):
+            raise BzrError('Revision {%s} given twice in the list'
+                    % (rev.revision_id))
+        rev_to_sha1[rev.revision_id] = sha1
 
     def _update_tree(self, bundle_tree, revision_id):
         """This fills out a BundleTree based on the information
@@ -632,7 +401,7 @@
             'modified':modified
         }
         for action_line, lines in \
-            self.info.get_revision_info(revision_id).tree_actions:
+            self.get_revision_info(revision_id).tree_actions:
             first = action_line.find(' ')
             if first == -1:
                 raise BzrError('Bogus action line'
@@ -726,7 +495,7 @@
             if old_dir is None:
                 old_path = None
             else:
-                old_path = os.path.join(old_dir, basename)
+                old_path = pathjoin(old_dir, basename)
         else:
             old_path = new_path
         #If the new path wasn't in renamed, the old one shouldn't be in
@@ -751,7 +520,7 @@
             if new_dir is None:
                 new_path = None
             else:
-                new_path = os.path.join(new_dir, basename)
+                new_path = pathjoin(new_dir, basename)
         else:
             new_path = old_path
         #If the old path wasn't in renamed, the new one shouldn't be in

=== modified file 'bzrlib/bundle/serializer/__init__.py'
--- bzrlib/bundle/serializer/__init__.py	2006-05-30 15:18:12 +0000
+++ bzrlib/bundle/serializer/__init__.py	2006-06-20 02:32:24 +0000
@@ -40,7 +40,7 @@
     return '<unknown>'
 
 
-def read(f):
+def read_bundle(f):
     """Read in a bundle from a filelike object.
 
     :param f: A file-like object
@@ -58,7 +58,7 @@
             raise errors.BundleNotSupported(version, 'old format bundles not supported')
 
     if version is None:
-        raise errors.NoBundleFound(_get_filename(f))
+        raise errors.NotABundle('Did not find an opening header')
 
     # Now we have a version, to figure out how to read the bundle 
     if not _serializers.has_key(version):

=== modified file 'bzrlib/bundle/serializer/v07.py'
--- bzrlib/bundle/serializer/v07.py	2006-06-10 22:13:45 +0000
+++ bzrlib/bundle/serializer/v07.py	2006-06-22 18:24:25 +0000
@@ -1,15 +1,15 @@
 # (C) 2005 Canonical Development Ltd
-
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -25,6 +25,7 @@
                                       unpack_highres_date,
                                      )
 from bzrlib.bundle.serializer import binary_diff
+from bzrlib.bundle.bundle_data import (RevisionInfo, BundleInfo, BundleTree)
 from bzrlib.delta import compare_trees
 from bzrlib.diff import internal_diff
 import bzrlib.errors as errors
@@ -35,6 +36,7 @@
 import bzrlib.ui
 from bzrlib.testament import StrictTestament
 from bzrlib.textfile import text_file
+from bzrlib.trace import mutter
 
 bool_text = {True: 'yes', False: 'no'}
 
@@ -91,9 +93,7 @@
         :param f: The file to read from
         :return: A list of bundles
         """
-        assert self.version == '0.7'
-        # The first line of the header should have been read
-        raise NotImplementedError
+        return BundleReader(f).info
 
     def write(self, source, revision_ids, forced_bases, f):
         """Write the bundless to the supplied files.
@@ -303,3 +303,198 @@
                                              new_tree.id2path(ie.file_id)])
                 action.add_property('last-changed', ie.revision)
                 action.write(self.to_file)
+
+
+class BundleReader(object):
+    """This class reads in a bundle from a file, and returns
+    a Bundle object, which can then be applied against a tree.
+    """
+    def __init__(self, from_file):
+        """Read in the bundle from the file.
+
+        :param from_file: A file-like object (must have iterator support).
+        """
+        object.__init__(self)
+        self.from_file = iter(from_file)
+        self._next_line = None
+        
+        self.info = BundleInfo()
+        # We put the actual inventory ids in the footer, so that the patch
+        # is easier to read for humans.
+        # Unfortunately, that means we need to read everything before we
+        # can create a proper bundle.
+        self._read()
+        self._validate()
+
+    def _read(self):
+        self._next().next()
+        while self._next_line is not None:
+            if not self._read_revision_header():
+                break
+            if self._next_line is None:
+                break
+            self._read_patches()
+            self._read_footer()
+
+    def _validate(self):
+        """Make sure that the information read in makes sense
+        and passes appropriate checksums.
+        """
+        # Fill in all the missing blanks for the revisions
+        # and generate the real_revisions list.
+        self.info.complete_info()
+
+    def _next(self):
+        """yield the next line, but secretly
+        keep 1 extra line for peeking.
+        """
+        for line in self.from_file:
+            last = self._next_line
+            self._next_line = line
+            if last is not None:
+                #mutter('yielding line: %r' % last)
+                yield last
+        last = self._next_line
+        self._next_line = None
+        #mutter('yielding line: %r' % last)
+        yield last
+
+    def _read_revision_header(self):
+        found_something = False
+        self.info.revisions.append(RevisionInfo(None))
+        for line in self._next():
+            # The bzr header is terminated with a blank line
+            # which does not start with '#'
+            if line is None or line == '\n':
+                break
+            found_something = True
+            self._handle_next(line)
+        if not found_something:
+            # Nothing was there, so remove the added revision
+            self.info.revisions.pop()
+        return found_something
+
+    def _read_next_entry(self, line, indent=1):
+        """Read in a key-value pair
+        """
+        if not line.startswith('#'):
+            raise MalformedHeader('Bzr header did not start with #')
+        line = line[1:-1].decode('utf-8') # Remove the '#' and '\n'
+        if line[:indent] == ' '*indent:
+            line = line[indent:]
+        if not line:
+            return None, None# Ignore blank lines
+
+        loc = line.find(': ')
+        if loc != -1:
+            key = line[:loc]
+            value = line[loc+2:]
+            if not value:
+                value = self._read_many(indent=indent+2)
+        elif line[-1:] == ':':
+            key = line[:-1]
+            value = self._read_many(indent=indent+2)
+        else:
+            raise MalformedHeader('While looking for key: value pairs,'
+                    ' did not find the colon %r' % (line))
+
+        key = key.replace(' ', '_')
+        #mutter('found %s: %s' % (key, value))
+        return key, value
+
+    def _handle_next(self, line):
+        if line is None:
+            return
+        key, value = self._read_next_entry(line, indent=1)
+        mutter('_handle_next %r => %r' % (key, value))
+        if key is None:
+            return
+
+        revision_info = self.info.revisions[-1]
+        if hasattr(revision_info, key):
+            if getattr(revision_info, key) is None:
+                setattr(revision_info, key, value)
+            else:
+                raise MalformedHeader('Duplicated Key: %s' % key)
+        else:
+            # What do we do with a key we don't recognize
+            raise MalformedHeader('Unknown Key: "%s"' % key)
+    
+    def _read_many(self, indent):
+        """If a line ends with no entry, that means that it should be
+        followed with multiple lines of values.
+
+        This detects the end of the list, because it will be a line that
+        does not start properly indented.
+        """
+        values = []
+        start = '#' + (' '*indent)
+
+        if self._next_line is None or self._next_line[:len(start)] != start:
+            return values
+
+        for line in self._next():
+            values.append(line[len(start):-1].decode('utf-8'))
+            if self._next_line is None or self._next_line[:len(start)] != start:
+                break
+        return values
+
+    def _read_one_patch(self):
+        """Read in one patch, return the complete patch, along with
+        the next line.
+
+        :return: action, lines, do_continue
+        """
+        #mutter('_read_one_patch: %r' % self._next_line)
+        # Peek and see if there are no patches
+        if self._next_line is None or self._next_line.startswith('#'):
+            return None, [], False
+
+        first = True
+        lines = []
+        for line in self._next():
+            if first:
+                if not line.startswith('==='):
+                    raise MalformedPatches('The first line of all patches'
+                        ' should be a bzr meta line "==="'
+                        ': %r' % line)
+                action = line[4:-1].decode('utf-8')
+            elif line.startswith('... '):
+                action += line[len('... '):-1].decode('utf-8')
+
+            if (self._next_line is not None and 
+                self._next_line.startswith('===')):
+                return action, lines, True
+            elif self._next_line is None or self._next_line.startswith('#'):
+                return action, lines, False
+
+            if first:
+                first = False
+            elif not line.startswith('... '):
+                lines.append(line)
+
+        return action, lines, False
+            
+    def _read_patches(self):
+        do_continue = True
+        revision_actions = []
+        while do_continue:
+            action, lines, do_continue = self._read_one_patch()
+            if action is not None:
+                revision_actions.append((action, lines))
+        assert self.info.revisions[-1].tree_actions is None
+        self.info.revisions[-1].tree_actions = revision_actions
+
+    def _read_footer(self):
+        """Read the rest of the meta information.
+
+        :param first_line:  The previous step iterates past what it
+                            can handle. That extra line is given here.
+        """
+        for line in self._next():
+            self._handle_next(line)
+            if not self._next_line.startswith('#'):
+                self._next().next()
+                break
+            if self._next_line is None:
+                break

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-06-15 04:40:07 +0000
+++ bzrlib/bzrdir.py	2006-06-20 07:55:43 +0000
@@ -20,9 +20,12 @@
 directories.
 """
 
+# TODO: remove unittest dependency; put that stuff inside the test suite
+
 from copy import deepcopy
+from cStringIO import StringIO
 import os
-from cStringIO import StringIO
+from stat import S_ISDIR
 from unittest import TestSuite
 
 import bzrlib
@@ -39,7 +42,6 @@
 from bzrlib.store.revision.text import TextRevisionStore
 from bzrlib.store.text import TextStore
 from bzrlib.store.versioned import WeaveStore
-from bzrlib.symbol_versioning import *
 from bzrlib.trace import mutter
 from bzrlib.transactions import WriteTransaction
 from bzrlib.transport import get_transport
@@ -92,11 +94,7 @@
         """
         if not allow_unsupported and not format.is_supported():
             # see open_downlevel to open legacy branches.
-            raise errors.UnsupportedFormatError(
-                    'sorry, format %s not supported' % format,
-                    ['use a different bzr version',
-                     'or remove the .bzr directory'
-                     ' and "bzr init" again'])
+            raise errors.UnsupportedFormatError(format=format)
 
     def clone(self, url, revision_id=None, basis=None, force_new_repo=False):
         """Clone this bzrdir and its contents to url verbatim.
@@ -978,7 +976,7 @@
         try:
             return klass._formats[format_string]
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):
@@ -1378,72 +1376,6 @@
         return result
 
 
-class ScratchDir(BzrDir6):
-    """Special test class: a bzrdir that cleans up itself..
-
-    >>> d = ScratchDir()
-    >>> base = d.transport.base
-    >>> isdir(base)
-    True
-    >>> b.transport.__del__()
-    >>> isdir(base)
-    False
-    """
-
-    def __init__(self, files=[], dirs=[], transport=None):
-        """Make a test branch.
-
-        This creates a temporary directory and runs init-tree in it.
-
-        If any files are listed, they are created in the working copy.
-        """
-        if transport is None:
-            transport = bzrlib.transport.local.ScratchTransport()
-            # local import for scope restriction
-            BzrDirFormat6().initialize(transport.base)
-            super(ScratchDir, self).__init__(transport, BzrDirFormat6())
-            self.create_repository()
-            self.create_branch()
-            self.create_workingtree()
-        else:
-            super(ScratchDir, self).__init__(transport, BzrDirFormat6())
-
-        # BzrBranch creates a clone to .bzr and then forgets about the
-        # original transport. A ScratchTransport() deletes itself and
-        # everything underneath it when it goes away, so we need to
-        # grab a local copy to prevent that from happening
-        self._transport = transport
-
-        for d in dirs:
-            self._transport.mkdir(d)
-            
-        for f in files:
-            self._transport.put(f, 'content of %s' % f)
-
-    def clone(self):
-        """
-        >>> orig = ScratchDir(files=["file1", "file2"])
-        >>> os.listdir(orig.base)
-        [u'.bzr', u'file1', u'file2']
-        >>> clone = orig.clone()
-        >>> if os.name != 'nt':
-        ...   os.path.samefile(orig.base, clone.base)
-        ... else:
-        ...   orig.base == clone.base
-        ...
-        False
-        >>> os.listdir(clone.base)
-        [u'.bzr', u'file1', u'file2']
-        """
-        from shutil import copytree
-        from bzrlib.osutils import mkdtemp
-        base = mkdtemp()
-        os.rmdir(base)
-        copytree(self.base, base, symlinks=True)
-        return ScratchDir(
-            transport=bzrlib.transport.local.ScratchTransport(base))
-
-
 class Converter(object):
     """Converts a disk format object from one format to another."""
 

=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2006-06-10 23:16:19 +0000
+++ bzrlib/check.py	2006-06-20 04:45:30 +0000
@@ -32,11 +32,9 @@
 # raising them.  If there's more than one exception it'd be good to see them
 # all.
 
-from bzrlib.errors import BzrCheckError, NoSuchRevision
-from bzrlib.symbol_versioning import *
-from bzrlib.trace import mutter, note, warning
+from bzrlib.errors import BzrCheckError
 import bzrlib.ui
-
+from bzrlib.trace import note
 
 class Check(object):
     """Check a repository"""
@@ -148,9 +146,6 @@
             if inv_sha1 != rev.inventory_sha1:
                 raise BzrCheckError('Inventory sha1 hash doesn\'t match'
                     ' value in revision {%s}' % rev_id)
-        else:
-            self.missing_inventory_sha_cnt += 1
-            mutter("no inventory_sha1 on revision {%s}", rev_id)
         self._check_revision_tree(rev_id)
         self.checked_rev_cnt += 1
 

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-06-18 23:19:23 +0000
+++ bzrlib/commands.py	2006-06-20 05:32:16 +0000
@@ -35,15 +35,16 @@
 import codecs
 
 import bzrlib
+import bzrlib.errors as errors
 from bzrlib.errors import (BzrError,
+                           BzrCommandError,
                            BzrCheckError,
-                           BzrCommandError,
-                           BzrOptionError,
                            NotBranchError)
 from bzrlib.option import Option
+import bzrlib.osutils
 from bzrlib.revisionspec import RevisionSpec
-from bzrlib.symbol_versioning import *
-import bzrlib.trace
+from bzrlib.symbol_versioning import (deprecated_method, zero_eight)
+from bzrlib import trace
 from bzrlib.trace import mutter, note, log_error, warning, be_quiet
 
 plugin_cmds = {}
@@ -146,7 +147,7 @@
     if cmd_obj:
         return cmd_obj
 
-    raise BzrCommandError("unknown command %r" % cmd_name)
+    raise BzrCommandError('unknown command "%s"' % cmd_name)
 
 
 class Command(object):
@@ -235,17 +236,7 @@
             self.outf = sys.stdout
             return
 
-        output_encoding = getattr(sys.stdout, 'encoding', None)
-        if not output_encoding:
-            input_encoding = getattr(sys.stdin, 'encoding', None)
-            if not input_encoding:
-                output_encoding = bzrlib.user_encoding
-                mutter('encoding stdout as bzrlib.user_encoding %r', output_encoding)
-            else:
-                output_encoding = input_encoding
-                mutter('encoding stdout as sys.stdin encoding %r', output_encoding)
-        else:
-            mutter('encoding stdout as sys.stdout encoding %r', output_encoding)
+        output_encoding = bzrlib.osutils.get_terminal_encoding()
 
         # use 'replace' so that we don't abort if trying to write out
         # in e.g. the default C locale.
@@ -274,8 +265,8 @@
         allowed_names = self.options().keys()
         for oname in opts:
             if oname not in allowed_names:
-                raise BzrCommandError("option '--%s' is not allowed for"
-                                      " command %r" % (oname, self.name()))
+                raise BzrOptionError("option '--%s' is not allowed for"
+                                " command %r" % (oname, self.name()))
         # mix arguments and options into one dictionary
         cmdargs = _match_argform(self.name(), self.takes_args, args)
         cmdopts = {}
@@ -392,9 +383,7 @@
                     else:
                         optname = a[2:]
                     if optname not in cmd_options:
-                        raise BzrOptionError('unknown long option %r for'
-                                             ' command %s' % 
-                                             (a, command.name()))
+                        raise BzrCommandError('unknown option "%s"' % a)
                 else:
                     shortopt = a[1:]
                     if shortopt in Option.SHORT_OPTIONS:
@@ -409,7 +398,7 @@
                         if shortopt not in Option.SHORT_OPTIONS:
                             # We didn't find the multi-character name, and we
                             # didn't find the single char name
-                            raise BzrError('unknown short option %r' % a)
+                            raise BzrCommandError('unknown option "%s"' % a)
                         optname = Option.SHORT_OPTIONS[shortopt].name
 
                         if a[2:]:
@@ -426,15 +415,12 @@
                                 # This option takes an argument, so pack it
                                 # into the array
                                 optarg = a[2:]
-                
                     if optname not in cmd_options:
-                        raise BzrOptionError('unknown short option %r for'
-                                             ' command %s' % 
-                                             (shortopt, command.name()))
+                        raise BzrCommandError('unknown option "%s"' % shortopt)
                 if optname in opts:
                     # XXX: Do we ever want to support this, e.g. for -r?
                     if proc_aliasarg:
-                        raise BzrError('repeated option %r' % a)
+                        raise BzrCommandError('repeated option %r' % a)
                     elif optname in alias_opts:
                         # Replace what's in the alias with what's in the real
                         # argument
@@ -443,14 +429,14 @@
                         proc_argv.insert(0, a)
                         continue
                     else:
-                        raise BzrError('repeated option %r' % a)
+                        raise BzrCommandError('repeated option %r' % a)
                     
                 option_obj = cmd_options[optname]
                 optargfn = option_obj.type
                 if optargfn:
                     if optarg == None:
                         if not proc_argv:
-                            raise BzrError('option %r needs an argument' % a)
+                            raise BzrCommandError('option %r needs an argument' % a)
                         else:
                             optarg = proc_argv.pop(0)
                     opts[optname] = optargfn(optarg)
@@ -458,7 +444,7 @@
                         alias_opts[optname] = optargfn(optarg)
                 else:
                     if optarg != None:
-                        raise BzrError('option %r takes no argument' % optname)
+                        raise BzrCommandError('option %r takes no argument' % optname)
                     opts[optname] = True
                     if proc_aliasarg:
                         alias_opts[optname] = True
@@ -495,7 +481,7 @@
                 raise BzrCommandError("command %r needs one or more %s"
                         % (cmd, argname.upper()))
             argdict[argname + '_list'] = args[:-1]
-            args[:-1] = []                
+            args[:-1] = []
         else:
             # just a plain arg
             argname = ap
@@ -693,10 +679,7 @@
 def main(argv):
     import bzrlib.ui
     from bzrlib.ui.text import TextUIFactory
-    ## bzrlib.trace.enable_default_logging()
-    bzrlib.trace.log_startup(argv)
     bzrlib.ui.ui_factory = TextUIFactory()
-
     argv = [a.decode(bzrlib.user_encoding) for a in argv[1:]]
     ret = run_bzr_catch_errors(argv)
     mutter("return code %d", ret)
@@ -713,19 +696,12 @@
     except Exception, e:
         # used to handle AssertionError and KeyboardInterrupt
         # specially here, but hopefully they're handled ok by the logger now
-        import errno
-        if (isinstance(e, IOError) 
-            and hasattr(e, 'errno')
-            and e.errno == errno.EPIPE):
-            bzrlib.trace.note('broken pipe')
-            return 3
-        else:
-            bzrlib.trace.log_exception()
-            if os.environ.get('BZR_PDB'):
-                print '**** entering debugger'
-                import pdb
-                pdb.post_mortem(sys.exc_traceback)
-            return 3
+        bzrlib.trace.report_exception(sys.exc_info(), sys.stderr)
+        if os.environ.get('BZR_PDB'):
+            print '**** entering debugger'
+            import pdb
+            pdb.post_mortem(sys.exc_traceback)
+        return 3
 
 if __name__ == '__main__':
     sys.exit(main(sys.argv))

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-06-16 15:25:15 +0000
+++ bzrlib/commit.py	2006-06-20 05:32:16 +0000
@@ -67,7 +67,7 @@
 import re
 import sys
 import time
-import pdb
+import warnings
 
 from cStringIO import StringIO
 
@@ -75,7 +75,6 @@
 import bzrlib.config
 import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, PointlessCommit,
-                           HistoryMissing,
                            ConflictsInTree,
                            StrictCommitFailed
                            )
@@ -86,7 +85,10 @@
 from bzrlib.trace import mutter, note, warning
 from bzrlib.xml5 import serializer_v5
 from bzrlib.inventory import Inventory, ROOT_ID, InventoryEntry
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_passed,
+        deprecated_function,
+        zero_seven,
+        DEPRECATED_PARAMETER)
 from bzrlib.workingtree import WorkingTree
 
 
@@ -221,7 +223,7 @@
         mutter('preparing to commit')
 
         if deprecated_passed(branch):
-            warn("Commit.commit (branch, ...): The branch parameter is "
+            warnings.warn("Commit.commit (branch, ...): The branch parameter is "
                  "deprecated as of bzr 0.8. Please use working_tree= instead.",
                  DeprecationWarning, stacklevel=2)
             self.branch = branch
@@ -457,9 +459,8 @@
             if not self.branch.repository.has_revision(parent_id):
                 if parent_id == self.branch.last_revision():
                     warning("parent is missing %r", parent_id)
-                    raise HistoryMissing(self.branch, 'revision', parent_id)
-                else:
-                    mutter("commit will ghost revision %r", parent_id)
+                    raise BzrCheckError("branch %s is missing revision {%s}"
+                            % (self.branch, parent_id))
             
     def _remove_deleted(self):
         """Remove deleted files from the working inventories.

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-06-16 15:59:24 +0000
+++ bzrlib/config.py	2006-06-20 05:32:16 +0000
@@ -255,7 +255,7 @@
             return self._string_to_signature_policy(policy)
 
     def _get_signing_policy(self):
-        """See Config._get_signature_checking."""
+        """See Config._get_signing_policy"""
         policy = self._get_user_option('create_signatures')
         if policy:
             return self._string_to_signing_policy(policy)
@@ -541,7 +541,7 @@
         if base is None:
             base = os.environ.get('HOME', None)
         if base is None:
-            raise BzrError('You must have one of BZR_HOME, APPDATA, or HOME set')
+            raise errors.BzrError('You must have one of BZR_HOME, APPDATA, or HOME set')
         return pathjoin(base, 'bazaar', '2.0')
     else:
         # cygwin, linux, and darwin all have a $HOME directory

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2006-06-17 01:18:15 +0000
+++ bzrlib/diff.py	2006-06-20 05:32:16 +0000
@@ -27,7 +27,8 @@
 import bzrlib.osutils
 from bzrlib.patiencediff import unified_diff
 import bzrlib.patiencediff
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function,
+        zero_eight)
 from bzrlib.textfile import check_text_lines
 from bzrlib.trace import mutter, warning
 

=== modified file 'bzrlib/doc/api/__init__.py'
--- bzrlib/doc/api/__init__.py	2005-12-24 02:20:45 +0000
+++ bzrlib/doc/api/__init__.py	2006-06-06 08:09:09 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Development Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,6 @@
     
 def test_suite():
     candidates = os.listdir(os.path.dirname(__file__))
-    scripts = [candidate for candidate in candidates 
+    scripts = [candidate for candidate in candidates
                if candidate.endswith('.txt')]
     return doctest.DocFileSuite(*scripts)

=== modified file 'bzrlib/doc/api/branch.txt'
--- bzrlib/doc/api/branch.txt	2006-02-01 11:50:27 +0000
+++ bzrlib/doc/api/branch.txt	2006-06-06 08:09:09 +0000
@@ -2,28 +2,36 @@
 
 A Branch represents a series of commits and merges carried out by a user.
 
+Make a temporary directory for these tests:
+
+   >>> import tempfile
+   >>> test_dir = tempfile.mkdtemp(prefix='bzrlib_doc_api_branch_txt_')
+
 Branches are created by BzrDir's:
 
-   >>> from bzrlib.bzrdir import ScratchDir
    >>> from bzrlib.branch import Branch
-   >>> dir = ScratchDir()
-   >>> new_branch = dir.create_branch()
+   >>> from bzrlib.bzrdir import BzrDir
 
+   >>> new_branch = BzrDir.create_branch_convenience(test_dir)
 
 Existing Branches can be opened directly:
 
-   >>> another_instance = Branch.open(dir.transport.clone('..').base)
+   >>> transport = new_branch.bzrdir.transport
+   >>> another_instance = Branch.open(transport.clone('..').base)
 
 or via the BzrDir:
 
-   >>> still_the_same_branch = dir.open_branch()
-
+   >>> still_the_same_branch = new_branch.bzrdir.open_branch()
 
 A branch has a history of revisions on it:
 
    >>> new_branch.revision_history()
    []
 
-
 We need to write some more documentation, showing
 push and pull operations. Cloning might also be nice.
+
+And finally, clean up:
+
+   >>> import shutil
+   >>> shutil.rmtree(test_dir)

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-06-17 01:04:57 +0000
+++ bzrlib/errors.py	2006-06-20 05:32:16 +0000
@@ -16,6 +16,18 @@
 
 """Exceptions for bzr, and reporting of them.
 
+There are 3 different classes of error:
+
+ * KeyboardInterrupt, and OSError with EPIPE - the program terminates 
+   with an appropriate short message
+
+ * User errors, indicating a problem caused by the user such as a bad URL.
+   These are printed in a short form.
+ 
+ * Internal unexpected errors, including most Python builtin errors
+   and some raised from inside bzr.  These are printed with a full 
+   traceback and an invitation to report the bug.
+
 Exceptions are caught at a high level to report errors to the user, and
 might also be caught inside the program.  Therefore it needs to be
 possible to convert them to a meaningful string, and also for them to be
@@ -44,13 +56,14 @@
 Therefore:
 
  * create a new exception class for any class of error that can be
-   usefully distinguished.
-
- * the printable form of an exception is generated by the base class
-   __str__ method
-
-Exception strings should start with a capital letter and not have a final
-fullstop.
+   usefully distinguished.  If no callers are likely to want to catch
+   one but not another, don't worry about them.
+
+ * the __str__ method should generate something useful; BzrError provides
+   a good default implementation
+
+Exception strings should start with a capital letter and should not have a
+final fullstop.
 """
 
 from warnings import warn
@@ -81,6 +94,9 @@
 
 
 class BzrError(StandardError):
+    
+    is_user_error = True
+    
     def __str__(self):
         # XXX: Should we show the exception class in 
         # exceptions that don't provide their own message?  
@@ -119,6 +135,8 @@
 class BzrCheckError(BzrNewError):
     """Internal check failed: %(message)s"""
 
+    is_user_error = False
+
     def __init__(self, message):
         BzrNewError.__init__(self)
         self.message = message
@@ -126,6 +144,9 @@
 
 class InvalidEntryName(BzrNewError):
     """Invalid entry name: %(name)s"""
+
+    is_user_error = False
+
     def __init__(self, name):
         BzrNewError.__init__(self)
         self.name = name
@@ -163,25 +184,31 @@
         self.url = url
 
 
-class BzrCommandError(BzrError):
-    # Error from malformed user command
-    # This is being misused as a generic exception
-    # please subclass. RBC 20051030
+class BzrCommandError(BzrNewError):
+    """Error from user command"""
+
+    is_user_error = True
+
+    # Error from malformed user command; please avoid raising this as a
+    # generic exception not caused by user input.
     #
     # I think it's a waste of effort to differentiate between errors that
     # are not intended to be caught anyway.  UI code need not subclass
     # BzrCommandError, and non-UI code should not throw a subclass of
     # BzrCommandError.  ADHB 20051211
+    def __init__(self, msg):
+        self.msg = msg
+
     def __str__(self):
-        return self.args[0]
+        return self.msg
 
 
 class BzrOptionError(BzrCommandError):
-    """Some missing or otherwise incorrect option was supplied."""
+    """Error in command line options"""
 
     
-class StrictCommitFailed(Exception):
-    """Commit refused because there are unknowns in the tree."""
+class StrictCommitFailed(BzrNewError):
+    """Commit refused because there are unknown files in the tree"""
 
 
 # XXX: Should be unified with TransportError; they seem to represent the
@@ -233,6 +260,9 @@
 
 class PathNotChild(BzrNewError):
     """Path %(path)r is not a child of path %(base)r%(extra)s"""
+
+    is_user_error = False
+
     def __init__(self, path, base, extra=None):
         BzrNewError.__init__(self)
         self.path = path
@@ -280,16 +310,12 @@
         self.path = path
 
 
-class UnsupportedFormatError(BzrError):
-    """Specified path is a bzr branch that we recognize but cannot read."""
-    def __str__(self):
-        return 'unsupported branch format: %s' % self.args[0]
-
-
-class UnknownFormatError(BzrError):
-    """Specified path is a bzr branch whose format we do not recognize."""
-    def __str__(self):
-        return 'unknown branch format: %s' % self.args[0]
+class UnsupportedFormatError(BzrNewError):
+    """Unsupported branch format: %(format)s"""
+
+
+class UnknownFormatError(BzrNewError):
+    """Unknown branch format: %(format)r"""
 
 
 class IncompatibleFormat(BzrNewError):
@@ -333,14 +359,12 @@
         self.paths_as_string = ' '.join([quotefn(p) for p in paths])
 
 
-class BadFileKindError(BzrError):
-    """Specified file is of a kind that cannot be added.
-
-    (For example a symlink or device file.)"""
-
-
-class ForbiddenFileError(BzrError):
-    """Cannot operate on a file because it is a control file."""
+class BadFileKindError(BzrNewError):
+    """Cannot operate on %(filename)s of unsupported kind %(kind)s"""
+
+
+class ForbiddenControlFileError(BzrNewError):
+    """Cannot operate on %(filename)s because it is a control file"""
 
 
 class LockError(BzrNewError):
@@ -378,6 +402,9 @@
 
 class ObjectNotLocked(LockError):
     """%(obj)r is not locked"""
+
+    is_user_error = False
+
     # this can indicate that any particular object is not locked; see also
     # LockNotHeld which means that a particular *lock* object is not held by
     # the caller -- perhaps they should be unified.
@@ -445,12 +472,14 @@
     """Commit refused because there are unknowns in the tree."""
 
 
-class NoSuchRevision(BzrError):
+class NoSuchRevision(BzrNewError):
+    """Branch %(branch)s has no revision %(revision)s"""
+
+    is_user_error = False
+
     def __init__(self, branch, revision):
         self.branch = branch
         self.revision = revision
-        msg = "Branch %s has no revision %s" % (branch, revision)
-        BzrError.__init__(self, msg)
 
 
 class HistoryMissing(BzrError):
@@ -461,26 +490,28 @@
                           % (branch, object_type, object_id))
 
 
-class DivergedBranches(BzrError):
+class DivergedBranches(BzrNewError):
+    "These branches have diverged.  Use the merge command to reconcile them."""
+
+    is_user_error = True
 
     def __init__(self, branch1, branch2):
-        BzrError.__init__(self, "These branches have diverged.  Try merge.")
         self.branch1 = branch1
         self.branch2 = branch2
 
 
-class UnrelatedBranches(BzrCommandError):
-    def __init__(self):
-        msg = "Branches have no common ancestor, and no base revision"\
-            " specified."
-        BzrCommandError.__init__(self, msg)
-
-
-class NoCommonAncestor(BzrError):
+class UnrelatedBranches(BzrNewError):
+    "Branches have no common ancestor, and no merge base revision was specified."
+
+    is_user_error = True
+
+
+class NoCommonAncestor(BzrNewError):
+    "Revisions have no common ancestor: %(revision_a)s %(revision_b)s"
+
     def __init__(self, revision_a, revision_b):
-        msg = "Revisions have no common ancestor: %s %s." \
-            % (revision_a, revision_b) 
-        BzrError.__init__(self, msg)
+        self.revision_a = revision_a
+        self.revision_b = revision_b
 
 
 class NoCommonRoot(BzrError):

=== modified file 'bzrlib/export/tar_exporter.py'
--- bzrlib/export/tar_exporter.py	2005-12-29 03:26:31 +0000
+++ bzrlib/export/tar_exporter.py	2006-06-20 03:57:11 +0000
@@ -1,15 +1,15 @@
-# Copyright (C) 2005 Canonical Ltd
-
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -20,6 +20,7 @@
 import os
 from bzrlib.trace import mutter
 import tarfile
+from bzrlib import errors, export
 
 
 def tar_exporter(tree, dest, root, compression=None):
@@ -32,11 +33,8 @@
     now = time()
     compression = str(compression or '')
     if root is None:
-        root = get_root_name(dest)
-    try:
-        ball = tarfile.open(dest, 'w:' + compression)
-    except tarfile.CompressionError, e:
-        raise BzrError(str(e))
+        root = export.get_root_name(dest)
+    ball = tarfile.open(dest, 'w:' + compression)
     mutter('export version %r', tree)
     inv = tree.inventory
     for dp, ie in inv.iter_entries():

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2006-06-18 23:21:30 +0000
+++ bzrlib/fetch.py	2006-06-20 05:32:16 +0000
@@ -33,13 +33,15 @@
 
 import bzrlib
 import bzrlib.errors as errors
-from bzrlib.errors import (InstallFailed, NoSuchRevision,
-                           MissingText)
+from bzrlib.errors import (InstallFailed,
+                           )
 from bzrlib.trace import mutter
-from bzrlib.progress import ProgressBar, ProgressPhase
-from bzrlib.reconcile import RepoReconciler
+from bzrlib.progress import ProgressPhase
 from bzrlib.revision import NULL_REVISION
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function,
+        deprecated_method,
+        zero_eight,
+        )
 
 
 # TODO: Avoid repeatedly opening weaves so many times.

=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2006-06-16 17:10:52 +0000
+++ bzrlib/info.py	2006-06-20 05:32:16 +0000
@@ -24,7 +24,8 @@
                            NoRepositoryPresent, NotLocalUrl)
 from bzrlib.missing import find_unmerged
 import bzrlib.osutils as osutils
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function, 
+        zero_eight)
 
 
 def plural(n, base='', pl=None):

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2006-06-17 21:50:40 +0000
+++ bzrlib/knit.py	2006-06-20 05:32:16 +0000
@@ -77,7 +77,7 @@
 from bzrlib.errors import FileExists, NoSuchFile, KnitError, \
         InvalidRevisionId, KnitCorrupt, KnitHeaderError, \
         RevisionNotPresent, RevisionAlreadyPresent
-from bzrlib.tuned_gzip import *
+from bzrlib.tuned_gzip import GzipFile
 from bzrlib.trace import mutter
 from bzrlib.osutils import contains_whitespace, contains_linebreaks, \
      sha_strings
@@ -573,7 +573,7 @@
             records = []
             for comp_id in basis_versions:
                 data_pos, data_size = basis._index.get_data_position(comp_id)
-                records.append((piece_id, data_pos, data_size))
+                records.append((comp_id, data_pos, data_size))
             components.update(basis._data.read_records(records))
 
         records = []
@@ -1069,7 +1069,7 @@
         # position in _history is the 'official' index for a revision
         # but the values may have come from a newer entry.
         # so - wc -l of a knit index is != the number of unique names
-        # in the weave.
+        # in the knit.
         self._history = []
         pb = bzrlib.ui.ui_factory.nested_progress_bar()
         try:

=== modified file 'bzrlib/lock.py'
--- bzrlib/lock.py	2006-03-03 07:31:24 +0000
+++ bzrlib/lock.py	2006-06-20 03:57:11 +0000
@@ -38,7 +38,7 @@
 import os
 import sys
 
-from bzrlib.trace import mutter, note, warning
+from bzrlib.trace import mutter
 from bzrlib.errors import LockError
 
 class _base_Lock(object):

=== modified file 'bzrlib/lockable_files.py'
--- bzrlib/lockable_files.py	2006-06-06 12:06:20 +0000
+++ bzrlib/lockable_files.py	2006-06-20 03:57:11 +0000
@@ -19,11 +19,13 @@
 #import traceback
 
 import bzrlib
-from bzrlib.decorators import *
+from bzrlib.decorators import (needs_read_lock,
+        needs_write_lock)
 import bzrlib.errors as errors
 from bzrlib.errors import BzrError
 from bzrlib.osutils import file_iterator, safe_unicode
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method, 
+        zero_eight)
 from bzrlib.trace import mutter, note
 import bzrlib.transactions as transactions
 import bzrlib.urlutils as urlutils

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-06-10 00:21:11 +0000
+++ bzrlib/lockdir.py	2006-06-20 03:57:11 +0000
@@ -96,7 +96,6 @@
 
 import os
 import time
-from warnings import warn
 from StringIO import StringIO
 
 import bzrlib.config
@@ -106,7 +105,6 @@
         LockBreakMismatch,
         LockBroken,
         LockContention,
-        LockError,
         LockNotHeld,
         NoSuchFile,
         PathError,

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2006-06-17 18:44:05 +0000
+++ bzrlib/log.py	2006-06-20 05:32:16 +0000
@@ -49,8 +49,8 @@
 all the changes since the previous revision that touched hello.c.
 """
 
-
 # TODO: option to show delta summaries for merged-in revisions
+
 from itertools import izip
 import re
 
@@ -272,88 +272,6 @@
             lf.show_merge(rev, merge_depth)
 
 
-def deltas_for_log_dummy(branch, which_revs):
-    """Return all the revisions without intermediate deltas.
-
-    Useful for log commands that won't need the delta information.
-    """
-    
-    for revno, revision_id in which_revs:
-        yield revno, branch.get_revision(revision_id), None
-
-
-def deltas_for_log_reverse(branch, which_revs):
-    """Compute deltas for display in latest-to-earliest order.
-
-    branch
-        Branch to traverse
-
-    which_revs
-        Sequence of (revno, revision_id) for the subset of history to examine
-
-    returns 
-        Sequence of (revno, rev, delta)
-
-    The delta is from the given revision to the next one in the
-    sequence, which makes sense if the log is being displayed from
-    newest to oldest.
-    """
-    last_revno = last_revision_id = last_tree = None
-    for revno, revision_id in which_revs:
-        this_tree = branch.revision_tree(revision_id)
-        this_revision = branch.get_revision(revision_id)
-        
-        if last_revno:
-            yield last_revno, last_revision, compare_trees(this_tree, last_tree, False)
-
-        this_tree = EmptyTree(branch.get_root_id())
-
-        last_revno = revno
-        last_revision = this_revision
-        last_tree = this_tree
-
-    if last_revno:
-        if last_revno == 1:
-            this_tree = EmptyTree(branch.get_root_id())
-        else:
-            this_revno = last_revno - 1
-            this_revision_id = branch.revision_history()[this_revno]
-            this_tree = branch.revision_tree(this_revision_id)
-        yield last_revno, last_revision, compare_trees(this_tree, last_tree, False)
-
-
-def deltas_for_log_forward(branch, which_revs):
-    """Compute deltas for display in forward log.
-
-    Given a sequence of (revno, revision_id) pairs, return
-    (revno, rev, delta).
-
-    The delta is from the given revision to the next one in the
-    sequence, which makes sense if the log is being displayed from
-    newest to oldest.
-    """
-    last_revno = last_revision_id = last_tree = None
-    prev_tree = EmptyTree(branch.get_root_id())
-
-    for revno, revision_id in which_revs:
-        this_tree = branch.revision_tree(revision_id)
-        this_revision = branch.get_revision(revision_id)
-
-        if not last_revno:
-            if revno == 1:
-                last_tree = EmptyTree(branch.get_root_id())
-            else:
-                last_revno = revno - 1
-                last_revision_id = branch.revision_history()[last_revno]
-                last_tree = branch.revision_tree(last_revision_id)
-
-        yield revno, this_revision, compare_trees(last_tree, this_tree, False)
-
-        last_revno = revno
-        last_revision = this_revision
-        last_tree = this_tree
-
-
 class LogFormatter(object):
     """Abstract class to display log messages."""
 

=== modified file 'bzrlib/lsprof.py'
--- bzrlib/lsprof.py	2005-12-08 07:10:37 +0000
+++ bzrlib/lsprof.py	2006-06-20 03:57:11 +0000
@@ -4,7 +4,7 @@
 # instead of just the Stats object
 
 import sys
-from _lsprof import Profiler, profiler_entry, profiler_subentry
+from _lsprof import Profiler, profiler_entry
 
 __all__ = ['profile', 'Stats']
 

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-06-10 00:21:11 +0000
+++ bzrlib/merge.py	2006-06-20 03:57:11 +0000
@@ -1,15 +1,15 @@
 # Copyright (C) 2005, 2006 Canonical Ltd
-
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -18,8 +18,8 @@
 import os
 import errno
 from tempfile import mkdtemp
+import warnings
 
-import bzrlib
 from bzrlib.branch import Branch
 from bzrlib.conflicts import ConflictList, Conflict
 from bzrlib.delta import compare_trees
@@ -41,13 +41,12 @@
 from bzrlib.osutils import rename, pathjoin, rmtree
 from progress import DummyProgress, ProgressPhase
 from bzrlib.revision import common_ancestor, is_ancestor, NULL_REVISION
-from bzrlib.symbol_versioning import *
 from bzrlib.textfile import check_text_lines
 from bzrlib.trace import mutter, warning, note
 from bzrlib.transform import (TreeTransform, resolve_conflicts, cook_conflicts,
                               FinalPaths, create_by_entry, unique_add)
 from bzrlib.versionedfile import WeaveMerge
-import bzrlib.ui
+from bzrlib import ui
 
 # TODO: Report back as changes are merged in
 
@@ -120,7 +119,7 @@
             changes = compare_trees(self.other_tree, other_basis_tree)
             if changes.has_changed():
                 raise WorkingTreeNotRevision(self.this_tree)
-            other_rev_id = other_basis
+            other_rev_id = self.other_basis
             self.other_tree = other_basis_tree
 
     def file_revisions(self, file_id):
@@ -368,7 +367,7 @@
         self.tt = TreeTransform(working_tree, self.pb)
         try:
             self.pp.next_phase()
-            child_pb = bzrlib.ui.ui_factory.nested_progress_bar()
+            child_pb = ui.ui_factory.nested_progress_bar()
             try:
                 for num, file_id in enumerate(all_ids):
                     child_pb.update('Preparing file merge', num, len(all_ids))
@@ -379,7 +378,7 @@
                 child_pb.finished()
                 
             self.pp.next_phase()
-            child_pb = bzrlib.ui.ui_factory.nested_progress_bar()
+            child_pb = ui.ui_factory.nested_progress_bar()
             try:
                 fs_conflicts = resolve_conflicts(self.tt, child_pb)
             finally:
@@ -896,7 +895,7 @@
                      branch.get_revision_tree(base_revision))'
         """
     if this_tree is None:
-        warn("bzrlib.merge.merge_inner requires a this_tree parameter as of "
+        warnings.warn("bzrlib.merge.merge_inner requires a this_tree parameter as of "
              "bzrlib version 0.8.",
              DeprecationWarning,
              stacklevel=2)

=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2006-06-06 12:06:20 +0000
+++ bzrlib/msgeditor.py	2006-06-20 05:32:16 +0000
@@ -26,6 +26,7 @@
 import bzrlib
 import bzrlib.config as config
 from bzrlib.errors import BzrError
+from bzrlib.trace import warning, mutter
 
 
 def _get_editor():
@@ -56,6 +57,7 @@
     for e in _get_editor():
         edargs = e.split(' ')
         try:
+            ## mutter("trying editor: %r", (edargs +[filename]))
             x = call(edargs + [filename])
         except OSError, e:
            # We're searching for an editor, so catch safe errors and continue
@@ -142,7 +144,7 @@
             try:
                 os.unlink(msgfilename)
             except IOError, e:
-                mutter("failed to unlink %s: %s; ignored", msgfilename, e)
+                warning("failed to unlink %s: %s; ignored", msgfilename, e)
 
 
 def make_commit_message_template(working_tree, specific_files):

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2006-06-10 00:21:11 +0000
+++ bzrlib/option.py	2006-06-20 03:57:11 +0000
@@ -19,8 +19,7 @@
 
 import re
 
-import bzrlib.commands
-from bzrlib.trace import warning, mutter
+from bzrlib.trace import warning
 from bzrlib.revisionspec import RevisionSpec
 from bzrlib.errors import BzrCommandError
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-06-16 15:59:24 +0000
+++ bzrlib/osutils.py	2006-06-20 05:32:16 +0000
@@ -18,8 +18,14 @@
 
 from cStringIO import StringIO
 import errno
+from ntpath import (abspath as _nt_abspath,
+                    join as _nt_join,
+                    normpath as _nt_normpath,
+                    realpath as _nt_realpath,
+                    )
 import os
 from os import listdir
+import posixpath
 import re
 import sha
 import shutil
@@ -33,11 +39,6 @@
 import types
 import tempfile
 import unicodedata
-from ntpath import (abspath as _nt_abspath,
-                    join as _nt_join,
-                    normpath as _nt_normpath,
-                    realpath as _nt_realpath,
-                    )
 
 import bzrlib
 from bzrlib.errors import (BzrError,
@@ -46,9 +47,9 @@
                            PathNotChild,
                            IllegalPath,
                            )
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function, 
+        zero_nine)
 from bzrlib.trace import mutter
-import bzrlib.win32console
 
 
 def make_readonly(filename):
@@ -203,24 +204,25 @@
 # string.
 _fs_enc = sys.getfilesystemencoding()
 def _posix_abspath(path):
-    return os.path.abspath(path.encode(_fs_enc)).decode(_fs_enc)
-    # jam 20060426 This is another possibility which mimics 
-    # os.path.abspath, only uses unicode characters instead
-    # if not os.path.isabs(path):
-    #     return os.path.join(os.getcwdu(), path)
-    # return path
+    # jam 20060426 rather than encoding to fsencoding
+    # copy posixpath.abspath, but use os.getcwdu instead
+    if not posixpath.isabs(path):
+        path = posixpath.join(getcwd(), path)
+    return posixpath.normpath(path)
 
 
 def _posix_realpath(path):
-    return os.path.realpath(path.encode(_fs_enc)).decode(_fs_enc)
+    return posixpath.realpath(path.encode(_fs_enc)).decode(_fs_enc)
 
 
 def _win32_abspath(path):
-    return _nt_abspath(path.encode(_fs_enc)).decode(_fs_enc).replace('\\', '/')
+    # Real _nt_abspath doesn't have a problem with a unicode cwd
+    return _nt_abspath(unicode(path)).replace('\\', '/')
 
 
 def _win32_realpath(path):
-    return _nt_realpath(path.encode(_fs_enc)).decode(_fs_enc).replace('\\', '/')
+    # Real _nt_realpath doesn't have a problem with a unicode cwd
+    return _nt_realpath(unicode(path)).replace('\\', '/')
 
 
 def _win32_pathjoin(*args):
@@ -228,7 +230,7 @@
 
 
 def _win32_normpath(path):
-    return _nt_normpath(path).replace('\\', '/')
+    return _nt_normpath(unicode(path)).replace('\\', '/')
 
 
 def _win32_getcwd():
@@ -288,6 +290,33 @@
         return shutil.rmtree(path, ignore_errors, onerror)
 
 
+def get_terminal_encoding():
+    """Find the best encoding for printing to the screen.
+
+    This attempts to check both sys.stdout and sys.stdin to see
+    what encoding they are in, and if that fails it falls back to
+    bzrlib.user_encoding.
+    The problem is that on Windows, locale.getpreferredencoding()
+    is not the same encoding as that used by the console:
+    http://mail.python.org/pipermail/python-list/2003-May/162357.html
+
+    On my standard US Windows XP, the preferred encoding is
+    cp1252, but the console is cp437
+    """
+    output_encoding = getattr(sys.stdout, 'encoding', None)
+    if not output_encoding:
+        input_encoding = getattr(sys.stdin, 'encoding', None)
+        if not input_encoding:
+            output_encoding = bzrlib.user_encoding
+            mutter('encoding stdout as bzrlib.user_encoding %r', output_encoding)
+        else:
+            output_encoding = input_encoding
+            mutter('encoding stdout as sys.stdin encoding %r', output_encoding)
+    else:
+        mutter('encoding stdout as sys.stdout encoding %r', output_encoding)
+    return output_encoding
+
+
 def normalizepath(f):
     if hasattr(os.path, 'realpath'):
         F = realpath

=== modified file 'bzrlib/patiencediff.py'
--- bzrlib/patiencediff.py	2006-05-29 00:50:34 +0000
+++ bzrlib/patiencediff.py	2006-06-20 03:57:11 +0000
@@ -17,7 +17,6 @@
 
 
 from bisect import bisect
-from copy import copy
 import difflib
 import os
 import sys

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2006-02-13 01:28:03 +0000
+++ bzrlib/plugin.py	2006-06-04 21:22:51 +0000
@@ -46,7 +46,7 @@
 
 import bzrlib
 from bzrlib.config import config_dir
-from bzrlib.trace import log_error, mutter, log_exception, warning, \
+from bzrlib.trace import log_error, mutter, warning, \
         log_exception_quietly
 from bzrlib.errors import BzrError
 from bzrlib import plugins

=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2006-05-09 10:33:08 +0000
+++ bzrlib/progress.py	2006-06-21 02:33:40 +0000
@@ -137,7 +137,7 @@
                  to_file=None,
                  show_pct=False,
                  show_spinner=False,
-                 show_eta=True,
+                 show_eta=False,
                  show_bar=True,
                  show_count=True,
                  to_messages_file=None,
@@ -262,20 +262,22 @@
         _BaseProgressBar.__init__(self, **kwargs)
         self.spin_pos = 0
         self.width = terminal_width()
-        self.start_time = None
         self.last_updates = deque()
         self.child_fraction = 0
     
 
-    def throttle(self):
+    def throttle(self, old_msg):
         """Return True if the bar was updated too recently"""
         # time.time consistently takes 40/4000 ms = 0.01 ms.
         # but every single update to the pb invokes it.
         # so we use time.clock which takes 20/4000 ms = 0.005ms
         # on the downside, time.clock() appears to have approximately
         # 10ms granularity, so we treat a zero-time change as 'throttled.'
-        
         now = time.clock()
+        if self.start_time is not None and (now - self.start_time) < 1:
+            return True
+        if old_msg != self.last_msg:
+            return False
         interval = now - self.last_update
         # if interval > 0
         if interval < self.MIN_PAUSE:
@@ -341,7 +343,7 @@
         # but multiple that by 4000 calls -> starts to cost.
         # so anything to make this function call faster
         # will improve base 'diff' time by up to 0.1 seconds.
-        if old_msg == self.last_msg and self.throttle():
+        if self.throttle(old_msg):
             return
 
         if self.show_eta and self.start_time and self.last_total:

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2006-06-12 01:53:19 +0000
+++ bzrlib/reconcile.py	2006-06-20 03:57:11 +0000
@@ -20,12 +20,9 @@
 __all__ = ['reconcile', 'Reconciler', 'RepoReconciler', 'KnitReconciler']
 
 
-import bzrlib.branch
-import bzrlib.errors as errors
-import bzrlib.progress
+from bzrlib import ui
 from bzrlib.trace import mutter
 from bzrlib.tsort import TopoSorter
-import bzrlib.ui as ui
 
 
 def reconcile(dir, other=None):

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-06-16 19:55:10 +0000
+++ bzrlib/repository.py	2006-06-20 05:32:16 +0000
@@ -21,11 +21,9 @@
 import time
 from unittest import TestSuite
 
-import bzrlib.bzrdir as bzrdir
+from bzrlib import bzrdir, check, delta, gpg, errors, xml5, ui, transactions, osutils
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-import bzrlib.errors as errors
 from bzrlib.errors import InvalidRevisionId
-import bzrlib.gpg as gpg
 from bzrlib.graph import Graph
 from bzrlib.inter import InterObject
 from bzrlib.inventory import Inventory
@@ -37,16 +35,15 @@
 from bzrlib.revision import NULL_REVISION, Revision
 from bzrlib.store.versioned import VersionedFileStore, WeaveStore
 from bzrlib.store.text import TextStore
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method,
+        zero_nine, 
+        )
 from bzrlib.trace import mutter, note
 from bzrlib.tree import RevisionTree, EmptyTree
 from bzrlib.tsort import topo_sort
 from bzrlib.testament import Testament
 from bzrlib.tree import EmptyTree
-from bzrlib.delta import compare_trees
-import bzrlib.ui
 from bzrlib.weave import WeaveFile
-import bzrlib.xml5
 
 
 class Repository(object):
@@ -73,11 +70,11 @@
         assert inv.revision_id is None or inv.revision_id == revid, \
             "Mismatch between inventory revision" \
             " id and insertion revid (%r, %r)" % (inv.revision_id, revid)
-        inv_text = bzrlib.xml5.serializer_v5.write_inventory_to_string(inv)
-        inv_sha1 = bzrlib.osutils.sha_string(inv_text)
+        inv_text = xml5.serializer_v5.write_inventory_to_string(inv)
+        inv_sha1 = osutils.sha_string(inv_text)
         inv_vf = self.control_weaves.get_weave('inventory',
                                                self.get_transaction())
-        self._inventory_add_lines(inv_vf, revid, parents, bzrlib.osutils.split_lines(inv_text))
+        self._inventory_add_lines(inv_vf, revid, parents, osutils.split_lines(inv_text))
         return inv_sha1
 
     def _inventory_add_lines(self, inv_vf, revid, parents, lines):
@@ -120,7 +117,6 @@
         """Return all the possible revisions that we could find."""
         return self.get_inventory_weave().versions()
 
-    @deprecated_method(zero_nine)
     def all_revision_ids(self):
         """Returns a list of all the revision ids in the repository. 
 
@@ -227,7 +223,7 @@
         For instance, if the repository is at URL/.bzr/repository,
         Repository.open(URL) -> a Repository instance.
         """
-        control = bzrlib.bzrdir.BzrDir.open(base)
+        control = bzrdir.BzrDir.open(base)
         return control.open_repository()
 
     def copy_content_into(self, destination, revision_id=None, basis=None):
@@ -278,9 +274,9 @@
             result = a_bzrdir.create_repository()
         # FIXME RBC 20060209 split out the repository type to avoid this check ?
         elif isinstance(a_bzrdir._format,
-                      (bzrlib.bzrdir.BzrDirFormat4,
-                       bzrlib.bzrdir.BzrDirFormat5,
-                       bzrlib.bzrdir.BzrDirFormat6)):
+                      (bzrdir.BzrDirFormat4,
+                       bzrdir.BzrDirFormat5,
+                       bzrdir.BzrDirFormat6)):
             result = a_bzrdir.open_repository()
         else:
             result = self._format.initialize(a_bzrdir, shared=self.is_shared())
@@ -347,7 +343,7 @@
             old_tree = EmptyTree()
         else:
             old_tree = self.revision_tree(revision.parent_ids[0])
-        return compare_trees(old_tree, new_tree)
+        return delta.compare_trees(old_tree, new_tree)
 
     def _check_revision_parents(self, revision, inventory):
         """Private to Repository and Fetch.
@@ -431,7 +427,7 @@
         :param revision_id: The expected revision id of the inventory.
         :param xml: A serialised inventory.
         """
-        return bzrlib.xml5.serializer_v5.read_inventory_from_string(xml)
+        return xml5.serializer_v5.read_inventory_from_string(xml)
 
     @needs_read_lock
     def get_inventory_xml(self, revision_id):
@@ -441,7 +437,7 @@
             iw = self.get_inventory_weave()
             return iw.get_text(revision_id)
         except IndexError:
-            raise bzrlib.errors.HistoryMissing(self, 'inventory', revision_id)
+            raise errors.HistoryMissing(self, 'inventory', revision_id)
 
     @needs_read_lock
     def get_inventory_sha1(self, revision_id):
@@ -643,7 +639,7 @@
         return self._check(revision_ids)
 
     def _check(self, revision_ids):
-        result = bzrlib.check.Check(self)
+        result = check.Check(self)
         result.check()
         return result
 
@@ -920,8 +916,9 @@
         reconciler.reconcile()
         return reconciler
     
-    def revision_parents(self, revid):
-        return self._get_revision_vf().get_parents(rev_id)
+    def revision_parents(self, revision_id):
+        return self._get_revision_vf().get_parents(revision_id)
+
 
 class RepositoryFormat(object):
     """A repository format.
@@ -963,7 +960,7 @@
         except errors.NoSuchFile:
             raise errors.NoRepositoryPresent(a_bzrdir)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     def _get_control_store(self, repo_transport, control_files):
         """Return the control store for this repository."""
@@ -1090,7 +1087,7 @@
         
         # Create an empty weave
         sio = StringIO()
-        bzrlib.weavefile.write_weave_v5(Weave(), sio)
+        write_weave_v5(Weave(), sio)
         empty_weave = sio.getvalue()
 
         mutter('creating repository in %s.', a_bzrdir.transport.base)
@@ -1156,7 +1153,7 @@
 
     def __init__(self):
         super(RepositoryFormat4, self).__init__()
-        self._matchingbzrdir = bzrlib.bzrdir.BzrDirFormat4()
+        self._matchingbzrdir = bzrdir.BzrDirFormat4()
 
     def get_format_description(self):
         """See RepositoryFormat.get_format_description()."""
@@ -1205,7 +1202,7 @@
 
     def __init__(self):
         super(RepositoryFormat5, self).__init__()
-        self._matchingbzrdir = bzrlib.bzrdir.BzrDirFormat5()
+        self._matchingbzrdir = bzrdir.BzrDirFormat5()
 
     def get_format_description(self):
         """See RepositoryFormat.get_format_description()."""
@@ -1235,7 +1232,7 @@
 
     def __init__(self):
         super(RepositoryFormat6, self).__init__()
-        self._matchingbzrdir = bzrlib.bzrdir.BzrDirFormat6()
+        self._matchingbzrdir = bzrdir.BzrDirFormat6()
 
     def get_format_description(self):
         """See RepositoryFormat.get_format_description()."""
@@ -1259,7 +1256,7 @@
 
     def __init__(self):
         super(MetaDirRepositoryFormat, self).__init__()
-        self._matchingbzrdir = bzrlib.bzrdir.BzrDirMetaFormat1()
+        self._matchingbzrdir = bzrdir.BzrDirMetaFormat1()
 
     def _create_control_files(self, a_bzrdir):
         """Create the required files and the initial control_files object."""
@@ -1340,7 +1337,7 @@
 
         # Create an empty weave
         sio = StringIO()
-        bzrlib.weavefile.write_weave_v5(Weave(), sio)
+        write_weave_v5(Weave(), sio)
         empty_weave = sio.getvalue()
 
         mutter('creating repository in %s.', a_bzrdir.transport.base)
@@ -1451,7 +1448,7 @@
         repo_transport = a_bzrdir.get_repository_transport(None)
         control_files = LockableFiles(repo_transport, 'lock', LockDir)
         control_store = self._get_control_store(repo_transport, control_files)
-        transaction = bzrlib.transactions.WriteTransaction()
+        transaction = transactions.WriteTransaction()
         # trigger a write of the inventory store.
         control_store.get_weave_or_empty('inventory', transaction)
         _revision_store = self._get_revision_store(repo_transport, control_files)
@@ -1660,7 +1657,7 @@
                 pass
             # FIXME do not peek!
             if self.source.control_files._transport.listable():
-                pb = bzrlib.ui.ui_factory.nested_progress_bar()
+                pb = ui.ui_factory.nested_progress_bar()
                 try:
                     self.target.weave_store.copy_all_ids(
                         self.source.weave_store,
@@ -2089,7 +2086,7 @@
             # TODO: Rather than invoking sha_strings here, _add_text_to_weave
             # should return the SHA1 and size
             self._add_text_to_weave(file_id, new_lines, file_parents.keys())
-            return bzrlib.osutils.sha_strings(new_lines), \
+            return osutils.sha_strings(new_lines), \
                 sum(map(len, new_lines))
 
     def modified_link(self, file_id, file_parents, link_target):

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2006-06-13 13:24:40 +0000
+++ bzrlib/revision.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical
+# Copyright (C) 2005, 2006 Canonical
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,12 +18,13 @@
 # perhaps show them in log -v and allow them as options to the commit command.
 
 
-import bzrlib.errors
 import bzrlib.errors as errors
 from bzrlib.graph import node_distances, select_farthest, all_descendants, Graph
 from bzrlib.osutils import contains_whitespace
 from bzrlib.progress import DummyProgress
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function,
+        zero_eight,
+        )
 
 NULL_REVISION="null:"
 
@@ -130,7 +131,7 @@
                 yield ancestor, distance
             try:
                 revision = revision_source.get_revision(ancestor)
-            except bzrlib.errors.NoSuchRevision, e:
+            except errors.NoSuchRevision, e:
                 if e.revision == revision_id:
                     raise 
                 else:
@@ -220,7 +221,7 @@
     root_b, ancestors_b, descendants_b = revision_graph(
         revision_b, revision_source)
     if root != root_b:
-        raise bzrlib.errors.NoCommonRoot(revision_a, revision_b)
+        raise errors.NoCommonRoot(revision_a, revision_b)
     common = set()
     for node, node_anc in ancestors_b.iteritems():
         if node in ancestors:
@@ -273,15 +274,15 @@
                 
             root = NULL_REVISION
             common.add(NULL_REVISION)
-        except bzrlib.errors.NoCommonRoot:
-            raise bzrlib.errors.NoCommonAncestor(revision_a, revision_b)
+        except errors.NoCommonRoot:
+            raise errors.NoCommonAncestor(revision_a, revision_b)
             
         pb.update('Picking ancestor', 2, 3)
         distances = node_distances (descendants, ancestors, root)
         pb.update('Picking ancestor', 3, 2)
         farthest = select_farthest(distances, common)
         if farthest is None or farthest == NULL_REVISION:
-            raise bzrlib.errors.NoCommonAncestor(revision_a, revision_b)
+            raise errors.NoCommonAncestor(revision_a, revision_b)
     finally:
         pb.clear()
     return farthest
@@ -306,7 +307,7 @@
         for source in self._revision_sources:
             try:
                 return source.get_revision(revision_id)
-            except bzrlib.errors.NoSuchRevision, e:
+            except errors.NoSuchRevision, e:
                 pass
         raise e
 
@@ -419,14 +420,14 @@
     """
     root, ancestors, descendants = revision_graph(rev_id, rev_source)
     if len(descendants) == 0:
-        raise NoSuchRevision(rev_source, rev_id)
+        raise errors.NoSuchRevision(rev_source, rev_id)
     if ancestor_id not in descendants:
         rev_source.get_revision(ancestor_id)
-        raise bzrlib.errors.NotAncestor(rev_id, ancestor_id)
+        raise errors.NotAncestor(rev_id, ancestor_id)
     root_descendants = all_descendants(descendants, ancestor_id)
     root_descendants.add(ancestor_id)
     if rev_id not in root_descendants:
-        raise bzrlib.errors.NotAncestor(rev_id, ancestor_id)
+        raise errors.NotAncestor(rev_id, ancestor_id)
     distances = node_distances(descendants, ancestors, ancestor_id,
                                root_descendants=root_descendants)
 

=== modified file 'bzrlib/sign_my_commits.py'
--- bzrlib/sign_my_commits.py	2006-06-10 23:16:19 +0000
+++ bzrlib/sign_my_commits.py	2006-06-20 03:57:11 +0000
@@ -17,10 +17,9 @@
 """Command which looks for unsigned commits by the current user, and signs them.
 """
 
+from bzrlib import config, gpg
 from bzrlib.commands import Command
-import bzrlib.config
-import bzrlib.errors as errors
-import bzrlib.gpg
+from bzrlib.bzrdir import BzrDir
 from bzrlib.option import Option
 
 
@@ -44,18 +43,16 @@
 
     def run(self, location=None, committer=None, dry_run=False):
         if location is None:
-            bzrdir = bzrlib.bzrdir.BzrDir.open_containing('.')[0]
+            bzrdir = BzrDir.open_containing('.')[0]
         else:
             # Passed in locations should be exact
-            bzrdir = bzrlib.bzrdir.BzrDir.open(location)
+            bzrdir = BzrDir.open(location)
         branch = bzrdir.open_branch()
         repo = branch.repository
-        config = bzrlib.config.BranchConfig(branch)
-
+        branch_config = config.BranchConfig(branch)
         if committer is None:
-            committer = config.username()
-
-        gpg_strategy = bzrlib.gpg.GPGStrategy(config)
+            committer = branch_config.username()
+        gpg_strategy = gpg.GPGStrategy(branch_config)
 
         count = 0
         repo.lock_write()

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2006-06-16 10:18:34 +0000
+++ bzrlib/status.py	2006-06-20 05:32:16 +0000
@@ -18,10 +18,12 @@
 
 from bzrlib.delta import compare_trees
 from bzrlib.diff import _raise_if_nonexistent
-from bzrlib.errors import NoSuchRevision
+import bzrlib.errors as errors
 from bzrlib.log import line_log
 from bzrlib.osutils import is_inside_any
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function,
+        zero_eight,
+        )
 
 # TODO: when showing single-line logs, truncate to the width of the terminal
 # if known, but only if really going to the terminal (not into a file)
@@ -117,15 +119,15 @@
             try:
                 rev_id = revision[0].in_history(wt.branch).rev_id
                 old = wt.branch.repository.revision_tree(rev_id)
-            except NoSuchRevision, e:
-                raise BzrCommandError(str(e))
+            except errors.NoSuchRevision, e:
+                raise errors.BzrCommandError(str(e))
             if (len(revision) > 1) and (revision[1].spec is not None):
                 try:
                     rev_id = revision[1].in_history(wt.branch).rev_id
                     new = wt.branch.repository.revision_tree(rev_id)
                     new_is_working_tree = False
-                except NoSuchRevision, e:
-                    raise BzrCommandError(str(e))
+                except errors.NoSuchRevision, e:
+                    raise errors.BzrCommandError(str(e))
             else:
                 new = wt
         _raise_if_nonexistent(specific_files, old, new)
@@ -175,8 +177,8 @@
                 mm_revision = branch.repository.get_revision(mmerge)
                 print >> to_file, '   ', line_log(mm_revision, 75)
                 ignore.add(mmerge)
-        except NoSuchRevision:
-            print >> to_file, ' ', merge 
+        except errors.NoSuchRevision:
+            print >> to_file, ' ', merge
         
 def list_paths(header, paths, specific_files, to_file):
     done_header = False

=== modified file 'bzrlib/store/__init__.py'
--- bzrlib/store/__init__.py	2006-06-09 09:04:53 +0000
+++ bzrlib/store/__init__.py	2006-06-20 03:57:11 +0000
@@ -32,7 +32,7 @@
 import bzrlib
 import bzrlib.errors as errors
 from bzrlib.errors import BzrError, UnlistableStore, TransportNotPossible
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_function, zero_eight)
 from bzrlib.trace import mutter
 from bzrlib.transport import Transport
 from bzrlib.transport.local import LocalTransport

=== modified file 'bzrlib/store/revision/knit.py'
--- bzrlib/store/revision/knit.py	2006-06-12 21:17:37 +0000
+++ bzrlib/store/revision/knit.py	2006-06-20 05:32:16 +0000
@@ -132,5 +132,5 @@
 
     def total_size(self, transaction):
         """ See RevisionStore.total_size()."""
-        return (len(self.all_revision_ids(transaction)), 
+        return (len(self.all_revision_ids(transaction)),
             self.versioned_file_store.total_size()[1])

=== modified file 'bzrlib/store/text.py'
--- bzrlib/store/text.py	2006-04-04 10:20:54 +0000
+++ bzrlib/store/text.py	2006-06-20 07:55:43 +0000
@@ -120,7 +120,3 @@
             from cStringIO import StringIO
             sio = StringIO(f.read())
             return gzip.GzipFile(mode='rb', fileobj=sio)
-
-
-def ScratchTextStore():
-    return TextStore(ScratchTransport())

=== modified file 'bzrlib/store/versioned/__init__.py'
--- bzrlib/store/versioned/__init__.py	2006-05-23 04:29:35 +0000
+++ bzrlib/store/versioned/__init__.py	2006-06-20 03:57:11 +0000
@@ -22,13 +22,15 @@
 import os
 from cStringIO import StringIO
 import urllib
+from warnings import warn
 
+from bzrlib import errors
 from bzrlib.weavefile import read_weave, write_weave_v5
 from bzrlib.weave import WeaveFile, Weave
 from bzrlib.store import TransportStore
 from bzrlib.atomicfile import AtomicFile
-from bzrlib.errors import NoSuchFile, FileExists
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method,
+        zero_eight)
 from bzrlib.trace import mutter
 import bzrlib.ui
 
@@ -112,7 +114,7 @@
         fn = self.filename(file_id)
         try:
             return self._transport.put(fn, f, mode=self._file_mode)
-        except NoSuchFile:
+        except errors.NoSuchFile:
             if not self._prefixed:
                 raise
             self._transport.mkdir(os.path.dirname(fn), mode=self._dir_mode)
@@ -173,7 +175,7 @@
             # for the common case.
             weave = self._versionedfile_class(_filename, self._transport, self._file_mode, create=True,
                                               **self._versionedfile_kwargs)
-        except NoSuchFile:
+        except errors.NoSuchFile:
             if not self._prefixed:
                 # unexpected error - NoSuchFile is expected to be raised on a
                 # missing dir only and that only occurs when we are prefixed.
@@ -194,7 +196,7 @@
         _filename = self.filename(file_id)
         try:
             return self.get_weave(file_id, transaction, _filename=_filename)
-        except NoSuchFile:
+        except errors.NoSuchFile:
             weave = self._make_new_versionedfile(file_id, transaction,
                 known_missing=True, _filename=_filename)
             transaction.map.add_weave(file_id, weave)
@@ -255,7 +257,7 @@
             warn("Please pass to_transaction into "
                  "versioned_store.copy_all_ids.", stacklevel=2)
         if not store_from.listable():
-            raise UnlistableStore(store_from)
+            raise errors.UnlistableStore(store_from)
         ids = []
         for count, file_id in enumerate(store_from):
             if pb:

=== modified file 'bzrlib/tests/EncodingAdapter.py'
--- bzrlib/tests/EncodingAdapter.py	2006-06-07 16:05:27 +0000
+++ bzrlib/tests/EncodingAdapter.py	2006-06-11 03:09:28 +0000
@@ -25,6 +25,15 @@
 # prefix for micro (1/1000000)
 _mu = u'\xb5'
 
+# greek letter omega, not to be confused with
+# the Ohm sign, u'\u2126'. Though they are probably identical
+# cp437 can handle the first, but not the second
+_omega = u'\u03a9'
+
+# smallest error possible, epsilon
+# cp437 handles u03b5, but not u2208 the 'element of' operator
+_epsilon = u'\u03b5'
+
 # Swedish?
 _erik = u'Erik B\xe5gfors'
 
@@ -39,8 +48,8 @@
 
 # Russian, 'Alexander' in russian
 _alexander = u'\u0410\u043b\u0435\u043a\u0441\u0430\u043d\u0434\u0440'
-# No idea if this means anything, but we need another string
-_alex = u'\u0410\u043b\u0435\u043a'
+# The word 'test' in Russian
+_russian_test = u'\u0422\u0435\u0441\u0442'
 
 # Kanji
 # It is a kanji sequence for nihonjin, or Japanese in English.
@@ -100,8 +109,15 @@
                   , 'directory':_something}),
         ('cp1251', 0, {'committer':_alexander
                   , 'message':u'Testing ' + _mu
-                  , 'filename':_alex
-                  , 'directory':_alex + 'dir'}),
+                  , 'filename':_russian_test
+                  , 'directory':_russian_test + 'dir'}),
+# The iso-8859-1 tests run on a default windows cp437 installation
+# and it takes a long time to run an extra permutation of the tests
+# But just in case we want to add this back in:
+#        ('cp437', 0, {'committer':_erik
+#                  , 'message':u'Testing ' + _mu
+#                  , 'filename':'file_' + _omega
+#                  , 'directory':_epsilon + '_dir'}),
     ]
 
     def adapt(self, test):

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-06-16 21:05:03 +0000
+++ bzrlib/tests/__init__.py	2006-06-20 07:55:43 +0000
@@ -29,6 +29,7 @@
 import codecs
 from cStringIO import StringIO
 import difflib
+import doctest
 import errno
 import logging
 import os
@@ -69,7 +70,11 @@
 from bzrlib.transport.local import LocalRelpathServer
 from bzrlib.transport.readonly import ReadonlyServer
 from bzrlib.trace import mutter
-from bzrlib.tests.TestUtil import TestLoader, TestSuite
+from bzrlib.tests import TestUtil
+from bzrlib.tests.TestUtil import (
+                          TestSuite,
+                          TestLoader,
+                          )
 from bzrlib.tests.treeshape import build_tree_contents
 import bzrlib.urlutils as urlutils
 from bzrlib.workingtree import WorkingTree, WorkingTreeFormat2
@@ -334,8 +339,16 @@
                 # If LANG=C we probably have created some bogus paths
                 # which rmtree(unicode) will fail to delete
                 # so make sure we are using rmtree(str) to delete everything
-                osutils.rmtree(test_root.encode(
-                    sys.getfilesystemencoding()))
+                # except on win32, where rmtree(str) will fail
+                # since it doesn't have the property of byte-stream paths
+                # (they are either ascii or mbcs)
+                if sys.platform == 'win32':
+                    # make sure we are using the unicode win32 api
+                    test_root = unicode(test_root)
+                else:
+                    test_root = test_root.encode(
+                        sys.getfilesystemencoding())
+                osutils.rmtree(test_root)
         else:
             if self.pb is not None:
                 self.pb.note("Failed tests working directories are in '%s'\n",
@@ -676,7 +689,6 @@
         self.log('run bzr: %r', argv)
         # FIXME: don't call into logging here
         handler = logging.StreamHandler(stderr)
-        handler.setFormatter(bzrlib.trace.QuietFormatter())
         handler.setLevel(logging.INFO)
         logger = logging.getLogger('')
         logger.addHandler(handler)
@@ -1129,7 +1141,7 @@
 
 
 def filter_suite_by_re(suite, pattern):
-    result = TestSuite()
+    result = TestUtil.TestSuite()
     filter_re = re.compile(pattern)
     for test in iter_suite_tests(suite):
         if filter_re.search(test.id()):
@@ -1190,11 +1202,7 @@
     This function can be replaced if you need to change the default test
     suite on a global basis, but it is not encouraged.
     """
-    from doctest import DocTestSuite
-
-    global MODULES_TO_DOCTEST
-
-    testmod_names = [ \
+    testmod_names = [
                    'bzrlib.tests.test_ancestry',
                    'bzrlib.tests.test_api',
                    'bzrlib.tests.test_bad_files',
@@ -1274,8 +1282,7 @@
         'bzrlib.tests.test_transport_implementations',
         'bzrlib.tests.test_read_bundle',
         ]
-
-    suite = TestSuite()
+    suite = TestUtil.TestSuite()
     loader = TestUtil.TestLoader()
     from bzrlib.transport import TransportTestProviderAdapter
     adapter = TransportTestProviderAdapter()
@@ -1285,8 +1292,8 @@
         suite.addTest(package.test_suite())
     for m in MODULES_TO_TEST:
         suite.addTest(loader.loadTestsFromModule(m))
-    for m in (MODULES_TO_DOCTEST):
-        suite.addTest(DocTestSuite(m))
+    for m in MODULES_TO_DOCTEST:
+        suite.addTest(doctest.DocTestSuite(m))
     for name, plugin in bzrlib.plugin.all_plugins().items():
         if getattr(plugin, 'test_suite', None) is not None:
             suite.addTest(plugin.test_suite())

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-06-19 08:54:42 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-06-20 03:30:14 +0000
@@ -53,6 +53,7 @@
                      'bzrlib.tests.blackbox.test_commit',
                      'bzrlib.tests.blackbox.test_conflicts',
                      'bzrlib.tests.blackbox.test_diff',
+                     'bzrlib.tests.blackbox.test_exceptions',
                      'bzrlib.tests.blackbox.test_export',
                      'bzrlib.tests.blackbox.test_find_merge_base',
                      'bzrlib.tests.blackbox.test_help',

=== modified file 'bzrlib/tests/blackbox/test_aliases.py'
--- bzrlib/tests/blackbox/test_aliases.py	2006-03-12 20:42:58 +0000
+++ bzrlib/tests/blackbox/test_aliases.py	2006-06-15 05:36:34 +0000
@@ -57,9 +57,9 @@
 
         # If --no-aliases breaks all of bzr, we also get retcode=3
         # So we need to catch the output as well
-        self.assertEquals(bzr_catch_error('--no-aliases', 'c', 'a', 
-                                          retcode=None), 
-                          "bzr: ERROR: unknown command 'c'\n")
+        self.assertEquals(bzr_catch_error('--no-aliases', 'c', 'a',
+                                          retcode=None),
+                          'bzr: ERROR: unknown command "c"\n')
 
         bzr('c', '-r1', '-r2', retcode=3)
         bzr('c1', '-r1', '-r2', retcode=3)

=== modified file 'bzrlib/tests/blackbox/test_annotate.py'
--- bzrlib/tests/blackbox/test_annotate.py	2006-05-05 01:29:34 +0000
+++ bzrlib/tests/blackbox/test_annotate.py	2006-06-20 03:57:11 +0000
@@ -28,7 +28,6 @@
 import os
 import shutil
 import sys
-import os
 
 from bzrlib.branch import Branch
 from bzrlib.errors import BzrCommandError

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2006-05-24 16:21:15 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005,2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 by Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
 
 import os
 
-import bzrlib.branch
-import bzrlib.bzrdir
+from bzrlib import branch, bzrdir
 from bzrlib.repository import RepositoryFormatKnit1
 from bzrlib.tests.blackbox import ExternalBase
 from bzrlib.workingtree import WorkingTree
@@ -44,7 +43,7 @@
         self.example_branch()
         os.chdir('..')
         self.runbzr('branch a b')
-        b = bzrlib.branch.Branch.open('b')
+        b = branch.Branch.open('b')
         self.assertEqual('b\n', b.control_files.get_utf8('branch-name').read())
         self.runbzr('branch a c -r 1')
         os.chdir('b')
@@ -66,14 +65,14 @@
         self.assertFalse(source.branch.repository.has_revision('2'))
         dir = source.bzrdir
         self.runbzr('branch source target --basis commit_tree')
-        target = bzrlib.bzrdir.BzrDir.open('target')
+        target = bzrdir.BzrDir.open('target')
         self.assertEqual('2', target.open_branch().last_revision())
         self.assertEqual('2', target.open_workingtree().last_revision())
         self.assertTrue(target.open_branch().repository.has_revision('2'))
 
     def test_branch_only_copies_history(self):
         # Knit branches should only push the history for the current revision.
-        format = bzrlib.bzrdir.BzrDirMetaFormat1()
+        format = bzrdir.BzrDirMetaFormat1()
         format.repository_format = RepositoryFormatKnit1()
         shared_repo = self.make_repository('repo', format=format, shared=True)
         shared_repo.set_make_working_trees(True)

=== modified file 'bzrlib/tests/blackbox/test_bundle.py'
--- bzrlib/tests/blackbox/test_bundle.py	2006-06-16 22:29:03 +0000
+++ bzrlib/tests/blackbox/test_bundle.py	2006-06-20 02:32:24 +0000
@@ -19,7 +19,7 @@
 import os
 from StringIO import StringIO
 
-from bzrlib.bundle.read_bundle import BundleReader
+from bzrlib.bundle.serializer import read_bundle
 from bzrlib.bzrdir import BzrDir
 from bzrlib.tests import TestCaseInTempDir
 
@@ -38,7 +38,7 @@
         branch_tree.commit('next commit', rev_id='revision2')
         branch_tree.commit('last commit', rev_id='revision3')
         os.chdir('../branch')
-        br = BundleReader(StringIO(self.run_bzr('bundle')[0]))
-        self.assertEqual(br.info.revisions[0].revision_id, 'revision3')
-        self.assertEqual(len(br.info.revisions), 2)
-        self.assertEqual(br.info.revisions[1].revision_id, 'revision2')
+        br = read_bundle(StringIO(self.run_bzr('bundle')[0]))
+        self.assertEqual(br.revisions[0].revision_id, 'revision3')
+        self.assertEqual(len(br.revisions), 2)
+        self.assertEqual(br.revisions[1].revision_id, 'revision2')

=== added file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2006-06-15 05:49:38 +0000
@@ -0,0 +1,37 @@
+# Copyright (C) 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for display of exceptions."""
+
+import os
+import sys
+
+from bzrlib.tests import TestCaseInTempDir, TestCase
+from bzrlib.errors import NotBranchError
+
+class TestExceptionReporting(TestCase):
+
+    def test_report_exception(self):
+        """When an error occurs, display bug report details to stderr"""
+        out, err = self.run_bzr("assert-fail", retcode=3)
+        self.assertContainsRe(err,
+                r'bzr: ERROR: exceptions\.AssertionError: always fails\n')
+        self.assertContainsRe(err, r'please send this report to')
+
+    # TODO: assert-fail doesn't need to always be present; we could just
+    # register (and unregister) it from tests that want to touch it.
+    #
+    # TODO: Some kind of test for the feature of invoking pdb

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2006-05-05 01:29:34 +0000
+++ bzrlib/tests/blackbox/test_init.py	2006-06-15 05:36:34 +0000
@@ -70,9 +70,9 @@
         
         out, err = self.run_bzr('init', 'subdir2/nothere', retcode=3)
         self.assertEqual('', out)
-        self.failUnless(err.startswith(
-            'bzr: ERROR: exceptions.OSError: '
-            '[Errno 2] No such file or directory: '))
+        self.assertContainsRe(err,
+            r'^bzr: ERROR: .*'
+            '\[Errno 2\] No such file or directory: ')
         
         os.mkdir('subdir2')
         out, err = self.run_bzr('init', 'subdir2')

=== modified file 'bzrlib/tests/blackbox/test_logformats.py'
--- bzrlib/tests/blackbox/test_logformats.py	2006-03-12 20:42:58 +0000
+++ bzrlib/tests/blackbox/test_logformats.py	2006-06-20 03:57:11 +0000
@@ -14,7 +14,7 @@
         return self.run_bzr(*args, **kwargs)[0]
 
     def test_log_default_format(self):
-        setup_config()
+        self.setup_config()
 
         self.bzr('init')
         open('a', 'wb').write('foo\n')
@@ -42,7 +42,7 @@
         self.assertEquals(7, len(self.bzr('log', '--log-format', 'short').split('\n')))
 
     def test_missing_default_format(self):
-        setup_config()
+        self.setup_config()
 
         os.mkdir('a')
         os.chdir('a')
@@ -69,7 +69,7 @@
         os.chdir('..')
 
     def test_missing_format_arg(self):
-        setup_config()
+        self.setup_config()
 
         os.mkdir('a')
         os.chdir('a')
@@ -96,7 +96,7 @@
         os.chdir('..')
 
 
-def setup_config():
+    def setup_config(self):
         if os.path.isfile(config_filename()):
                 # Something is wrong in environment, 
                 # we risk overwriting users config 
@@ -108,4 +108,3 @@
                 "log_format=line\n")
 
         open(config_filename(),'wb').write(CONFIG)
-

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2006-06-07 16:05:27 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2006-06-11 02:57:43 +0000
@@ -21,6 +21,7 @@
 import os
 
 import bzrlib
+import bzrlib.osutils as osutils
 from bzrlib.tests import TestCaseInTempDir, TestSkipped
 from bzrlib.trace import mutter, note
 import bzrlib.urlutils as urlutils
@@ -52,6 +53,7 @@
         bzr = self.run_bzr
 
         fs_enc = sys.getfilesystemencoding()
+        terminal_enc = osutils.get_terminal_encoding()
         fname = self.info['filename']
         dir_name = self.info['directory']
         for thing in [fname, dir_name]:
@@ -59,8 +61,16 @@
                 thing.encode(fs_enc)
             except UnicodeEncodeError:
                 raise TestSkipped(('Unable to represent path %r'
-                                   ' in filesystem encoding %s')
+                                   ' in filesystem encoding "%s"')
                                     % (thing, fs_enc))
+            try:
+                thing.encode(terminal_enc)
+            except UnicodeEncodeError:
+                raise TestSkipped(('Unable to represent path %r'
+                                   ' in terminal encoding "%s"'
+                                   ' (even though it is valid in'
+                                   ' filesystem encoding "%s")')
+                                   % (thing, terminal_enc, fs_enc))
 
         bzr('init')
         open('a', 'wb').write('foo\n')
@@ -208,7 +218,7 @@
         open('a', 'ab').write('more text\n')
         bzr('commit', '-m', 'mod a')
 
-        pwd = os.getcwdu()
+        pwd = osutils.getcwd()
 
         os.chdir(u'../' + dirname2)
         txt = bzr('pull')

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2006-06-15 22:51:05 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2006-06-20 03:30:14 +0000
@@ -247,7 +247,7 @@
         tree_b.commit('commit d')
         out = self.runbzr('pull ../branch_a', retcode=3)
         self.assertEquals(out,
-                ('','bzr: ERROR: These branches have diverged.  Try merge.\n'))
+                ('','bzr: ERROR: These branches have diverged.  Use the merge command to reconcile them.\n'))
         self.assertEquals(branch_b.get_parent(), parent)
         # test implicit --remember after resolving previous failure
         uncommit(branch=branch_b, tree=tree_b)

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2006-05-21 13:58:58 +0000
+++ bzrlib/tests/blackbox/test_push.py	2006-06-17 00:49:34 +0000
@@ -27,6 +27,7 @@
 from bzrlib.repository import RepositoryFormatKnit1
 from bzrlib.tests.blackbox import ExternalBase
 from bzrlib.uncommit import uncommit
+from bzrlib.urlutils import local_path_from_url
 from bzrlib.workingtree import WorkingTree
 
 
@@ -52,28 +53,43 @@
         tree_b.commit('commit c')
         # initial push location must be empty
         self.assertEqual(None, branch_b.get_push_location())
+
         # test push for failure without push location set
         os.chdir('branch_a')
         out = self.runbzr('push', retcode=3)
         self.assertEquals(out,
                 ('','bzr: ERROR: No push location known or specified.\n'))
+
+        # test not remembered if cannot actually push
+        self.run_bzr('push', '../path/which/doesnt/exist', retcode=3)
+        out = self.run_bzr('push', retcode=3)
+        self.assertEquals(
+                ('', 'bzr: ERROR: No push location known or specified.\n'),
+                out)
+
         # test implicit --remember when no push location set, push fails
-        out = self.runbzr('push ../branch_b', retcode=3)
+        out = self.run_bzr('push', '../branch_b', retcode=3)
         self.assertEquals(out,
                 ('','bzr: ERROR: These branches have diverged.  '
                     'Try a merge then push with overwrite.\n'))
         self.assertEquals(abspath(branch_a.get_push_location()),
                           abspath(branch_b.bzrdir.root_transport.base))
+
         # test implicit --remember after resolving previous failure
         uncommit(branch=branch_b, tree=tree_b)
         transport.delete('branch_b/c')
-        self.runbzr('push')
-        self.assertEquals(abspath(branch_a.get_push_location()),
-                          abspath(branch_b.bzrdir.root_transport.base))
+        out = self.run_bzr('push')
+        path = branch_a.get_push_location()
+        self.assertEquals(('Using saved location: %s\n' 
+                           % (local_path_from_url(path),)
+                          , 'All changes applied successfully.\n'
+                            '1 revision(s) pushed.\n'), out)
+        self.assertEqual(path,
+                         branch_b.bzrdir.root_transport.base)
         # test explicit --remember
-        self.runbzr('push ../branch_c --remember')
-        self.assertEquals(abspath(branch_a.get_push_location()),
-                          abspath(branch_c.bzrdir.root_transport.base))
+        self.run_bzr('push', '../branch_c', '--remember')
+        self.assertEquals(branch_a.get_push_location(),
+                          branch_c.bzrdir.root_transport.base)
     
     def test_push_without_tree(self):
         # bzr push from a branch that does not have a checkout should work.

=== modified file 'bzrlib/tests/branch_implementations/test_branch.py'
--- bzrlib/tests/branch_implementations/test_branch.py	2006-06-17 19:01:15 +0000
+++ bzrlib/tests/branch_implementations/test_branch.py	2006-06-21 11:13:11 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,24 +19,19 @@
 import os
 import sys
 
-import bzrlib.branch
-import bzrlib.bzrdir as bzrdir
+from bzrlib import branch, bzrdir, errors, gpg, transactions, repository
 from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
-from bzrlib.commit import commit
 from bzrlib.delta import TreeDelta
-import bzrlib.errors as errors
 from bzrlib.errors import (FileExists,
                            NoSuchRevision,
                            NoSuchFile,
                            UninitializableFormat,
                            NotBranchError,
                            )
-import bzrlib.gpg
 from bzrlib.osutils import getcwd
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
 from bzrlib.tests.bzrdir_implementations.test_bzrdir import TestCaseWithBzrDir
 from bzrlib.trace import mutter
-import bzrlib.transactions as transactions
 from bzrlib.transport import get_transport
 from bzrlib.transport.http import HttpServer
 from bzrlib.transport.memory import MemoryServer
@@ -244,7 +239,7 @@
         branch = wt.branch
         wt.commit("base", allow_pointless=True, rev_id='A')
         from bzrlib.testament import Testament
-        strategy = bzrlib.gpg.LoopbackGPGStrategy(None)
+        strategy = gpg.LoopbackGPGStrategy(None)
         branch.repository.sign_revision('A', strategy)
         self.assertEqual(Testament.from_revision(branch.repository, 
                          'A').as_short_text(),
@@ -254,7 +249,7 @@
         wt = self.make_branch_and_tree('.')
         branch = wt.branch
         branch.repository.store_revision_signature(
-            bzrlib.gpg.LoopbackGPGStrategy(None), 'FOO', 'A')
+            gpg.LoopbackGPGStrategy(None), 'FOO', 'A')
         self.assertRaises(errors.NoSuchRevision,
                           branch.repository.has_signature_for_revision_id,
                           'A')
@@ -266,7 +261,7 @@
         wt = self.make_branch_and_tree('source')
         wt.commit('A', allow_pointless=True, rev_id='A')
         wt.branch.repository.sign_revision('A',
-            bzrlib.gpg.LoopbackGPGStrategy(None))
+            gpg.LoopbackGPGStrategy(None))
         #FIXME: clone should work to urls,
         # wt.clone should work to disks.
         self.build_tree(['target/'])
@@ -324,7 +319,7 @@
             return
         self.assertEqual(repo.bzrdir.root_transport.base,
                          child_branch.repository.bzrdir.root_transport.base)
-        child_branch = bzrlib.branch.Branch.open(self.get_url('child'))
+        child_branch = branch.Branch.open(self.get_url('child'))
         self.assertEqual(repo.bzrdir.root_transport.base,
                          child_branch.repository.bzrdir.root_transport.base)
 
@@ -343,7 +338,16 @@
 
     def test_get_commit_builder(self):
         self.assertIsInstance(self.make_branch(".").get_commit_builder([]), 
-            bzrlib.repository.CommitBuilder)
+            repository.CommitBuilder)
+
+    def test_generate_revision_history(self):
+        """Create a fake revision history easily."""
+        tree = self.make_branch_and_tree('.')
+        rev1 = tree.commit('foo')
+        orig_history = tree.branch.revision_history()
+        rev2 = tree.commit('bar', allow_pointless=True)
+        tree.branch.generate_revision_history(rev1)
+        self.assertEqual(orig_history, tree.branch.revision_history())
 
 
 class ChrootedTests(TestCaseWithBranch):
@@ -370,24 +374,6 @@
         branch, relpath = Branch.open_containing(self.get_readonly_url('g/p/q'))
         self.assertEqual('g/p/q', relpath)
         
-# TODO: rewrite this as a regular unittest, without relying on the displayed output        
-#         >>> from bzrlib.commit import commit
-#         >>> bzrlib.trace.silent = True
-#         >>> br1 = ScratchBranch(files=['foo', 'bar'])
-#         >>> br1.working_tree().add('foo')
-#         >>> br1.working_tree().add('bar')
-#         >>> commit(br1, "lala!", rev_id="REVISION-ID-1", verbose=False)
-#         >>> br2 = ScratchBranch()
-#         >>> br2.update_revisions(br1)
-#         Added 2 texts.
-#         Added 1 inventories.
-#         Added 1 revisions.
-#         >>> br2.revision_history()
-#         [u'REVISION-ID-1']
-#         >>> br2.update_revisions(br1)
-#         Added 0 revisions.
-#         >>> br1.text_store.total_size() == br2.text_store.total_size()
-#         True
 
 class InstrumentedTransaction(object):
 
@@ -544,7 +530,7 @@
         t = get_transport(self.get_url())
         readonly_t = get_transport(self.get_readonly_url())
         made_branch = self.make_branch('.')
-        self.failUnless(isinstance(made_branch, bzrlib.branch.Branch))
+        self.failUnless(isinstance(made_branch, branch.Branch))
 
         # find it via bzrdir opening:
         opened_control = bzrdir.BzrDir.open(readonly_t.base)
@@ -555,7 +541,7 @@
                         self.branch_format.__class__))
 
         # find it via Branch.open
-        opened_branch = bzrlib.branch.Branch.open(readonly_t.base)
+        opened_branch = branch.Branch.open(readonly_t.base)
         self.failUnless(isinstance(opened_branch, made_branch.__class__))
         self.assertEqual(made_branch._format.__class__,
                          opened_branch._format.__class__)
@@ -565,4 +551,4 @@
         except NotImplementedError:
             return
         self.assertEqual(self.branch_format,
-                         bzrlib.branch.BranchFormat.find_format(opened_control))
+                         branch.BranchFormat.find_format(opened_control))

=== modified file 'bzrlib/tests/bzrdir_implementations/test_bzrdir.py'
--- bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-05-17 04:09:58 +0000
+++ bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +18,13 @@
 
 from cStringIO import StringIO
 import os
-from stat import *
+from stat import S_ISDIR
 import sys
 
 import bzrlib.branch
 import bzrlib.bzrdir as bzrdir
 from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
 from bzrlib.check import check
-from bzrlib.commit import commit
 import bzrlib.errors as errors
 from bzrlib.errors import (FileExists,
                            NoSuchRevision,

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2006-06-16 19:55:10 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2006-06-20 05:32:16 +0000
@@ -21,18 +21,15 @@
 import sys
 
 import bzrlib
-import bzrlib.bzrdir as bzrdir
+from bzrlib import bzrdir, errors, repository
 from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
-from bzrlib.commit import commit
 from bzrlib.delta import TreeDelta
-import bzrlib.errors as errors
 from bzrlib.errors import (FileExists,
                            NoSuchRevision,
                            NoSuchFile,
                            UninitializableFormat,
                            NotBranchError,
                            )
-import bzrlib.repository as repository
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
 from bzrlib.tests.bzrdir_implementations.test_bzrdir import TestCaseWithBzrDir

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2006-06-22 17:18:45 +0000
+++ bzrlib/tests/test_bundle.py	2006-06-22 18:24:25 +0000
@@ -19,8 +19,8 @@
 from bzrlib.builtins import merge
 from bzrlib.bzrdir import BzrDir
 from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
-from bzrlib.bundle.read_bundle import BundleTree, BundleReader
-from bzrlib.bundle.serializer import write_bundle
+from bzrlib.bundle.bundle_data import BundleTree
+from bzrlib.bundle.serializer import write_bundle, read_bundle
 from bzrlib.diff import internal_diff
 from bzrlib.errors import BzrError, TestamentMismatch, NotABundle
 from bzrlib.merge import Merge3Merger
@@ -324,9 +324,9 @@
         bundle_txt, rev_ids = self.create_bundle_text(base_rev_id, rev_id)
 
         # This should also validate the generated bundle 
-        bundle = BundleReader(bundle_txt)
+        bundle = read_bundle(bundle_txt)
         repository = self.b1.repository
-        for bundle_rev in bundle.info.real_revisions:
+        for bundle_rev in bundle.real_revisions:
             # These really should have already been checked when we read the
             # bundle, since it computes the sha1 hash for the revision, which
             # only will match if everything is okay, but lets be explicit about
@@ -340,7 +340,7 @@
             self.assertEqual(len(branch_rev.parent_ids), 
                              len(bundle_rev.parent_ids))
         self.assertEqual(rev_ids, 
-                         [r.revision_id for r in bundle.info.real_revisions])
+                         [r.revision_id for r in bundle.real_revisions])
         self.valid_apply_bundle(base_rev_id, bundle,
                                    checkout_dir=checkout_dir)
 
@@ -356,12 +356,12 @@
         new_text = bundle_txt.getvalue().replace('executable:no', 
                                                'executable:yes')
         bundle_txt = StringIO(new_text)
-        bundle = BundleReader(bundle_txt)
+        bundle = read_bundle(bundle_txt)
         self.valid_apply_bundle(base_rev_id, bundle)
         return bundle 
 
     def test_non_bundle(self):
-        self.assertRaises(NotABundle, BundleReader, StringIO('#!/bin/sh\n'))
+        self.assertRaises(NotABundle, read_bundle, StringIO('#!/bin/sh\n'))
 
     def get_checkout(self, rev_id, checkout_dir=None):
         """Get a new tree, with the specified revision in it.
@@ -381,7 +381,7 @@
         s.seek(0)
         assert isinstance(s.getvalue(), str), (
             "Bundle isn't a bytestring:\n %s..." % repr(s.getvalue())[:40])
-        install_bundle(tree.branch.repository, BundleReader(s))
+        install_bundle(tree.branch.repository, read_bundle(s))
         for ancestor in ancestors:
             old = self.b1.repository.revision_tree(ancestor)
             new = tree.branch.repository.revision_tree(ancestor)
@@ -400,19 +400,18 @@
             tree.update()
         return tree
 
-    def valid_apply_bundle(self, base_rev_id, reader, checkout_dir=None):
+    def valid_apply_bundle(self, base_rev_id, info, checkout_dir=None):
         """Get the base revision, apply the changes, and make
         sure everything matches the builtin branch.
         """
         to_tree = self.get_checkout(base_rev_id, checkout_dir=checkout_dir)
         repository = to_tree.branch.repository
         self.assertIs(repository.has_revision(base_rev_id), True)
-        info = reader.info
         for rev in info.real_revisions:
             self.assert_(not repository.has_revision(rev.revision_id),
                 'Revision {%s} present before applying bundle' 
                 % rev.revision_id)
-        merge_bundle(reader, to_tree, True, Merge3Merger, False, False)
+        merge_bundle(info, to_tree, True, Merge3Merger, False, False)
 
         for rev in info.real_revisions:
             self.assert_(repository.has_revision(rev.revision_id),
@@ -700,7 +699,7 @@
     def check_valid(self, bundle):
         """Check that after whatever munging, the final object is valid."""
         self.assertEqual(['a@cset-0-2'], 
-            [r.revision_id for r in bundle.info.real_revisions])
+            [r.revision_id for r in bundle.real_revisions])
 
     def test_extra_whitespace(self):
         bundle_txt = self.build_test_bundle()
@@ -712,7 +711,7 @@
         bundle_txt.write('\n')
         bundle_txt.seek(0)
 
-        bundle = BundleReader(bundle_txt)
+        bundle = read_bundle(bundle_txt)
         self.check_valid(bundle)
 
     def test_extra_whitespace_2(self):
@@ -725,7 +724,7 @@
         bundle_txt.write('\n\n')
         bundle_txt.seek(0)
 
-        bundle = BundleReader(bundle_txt)
+        bundle = read_bundle(bundle_txt)
         self.check_valid(bundle)
 
     def test_missing_trailing_whitespace(self):
@@ -740,5 +739,5 @@
         self.assertEqual('\n\n', raw[-2:])
         bundle_text = StringIO(raw[:-1])
 
-        bundle = BundleReader(bundle_txt)
+        bundle = read_bundle(bundle_txt)
         self.check_valid(bundle)

=== modified file 'bzrlib/tests/test_commit_merge.py'
--- bzrlib/tests/test_commit_merge.py	2006-02-20 09:50:27 +0000
+++ bzrlib/tests/test_commit_merge.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005, 2006 by Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,9 +20,8 @@
 
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.branch import Branch
-from bzrlib.errors import PointlessCommit, BzrError, PointlessCommit
+from bzrlib.errors import PointlessCommit, BzrError
 from bzrlib.tests.test_revision import make_branches
-from bzrlib.check import check
 
 
 class TestCommitMerge(TestCaseWithTransport):
@@ -93,5 +92,7 @@
         self.assertEquals(inv['ecks-id'].revision, 'x@u-0-1')
         self.assertEquals(inv['why-id'].revision, 'y@u-0-1')
 
-        check(bx, False)
-        check(by, False)
+        bx.check()
+        by.check()
+        bx.repository.check([bx.last_revision()])
+        by.repository.check([by.last_revision()])

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2006-04-18 22:41:16 +0000
+++ bzrlib/tests/test_conflicts.py	2006-06-20 03:57:11 +0000
@@ -17,9 +17,13 @@
 
 import os
 
+from bzrlib import bzrdir
 from bzrlib.tests import TestCaseWithTransport, TestCase
 from bzrlib.branch import Branch
-from bzrlib.conflicts import *
+from bzrlib.conflicts import (MissingParent, ContentsConflict, TextConflict,
+        PathConflict, DuplicateID, DuplicateEntry, ParentLoop, UnversionedParent,
+        ConflictList, 
+        restore)
 from bzrlib.errors import NotConflicted
 
 
@@ -46,7 +50,7 @@
     def test_conflicts(self):
         """Conflicts are detected properly"""
         tree = self.make_branch_and_tree('.',
-            format=bzrlib.bzrdir.BzrDirFormat6())
+            format=bzrdir.BzrDirFormat6())
         b = tree.branch
         file('hello', 'w').write('hello world4')
         file('hello.THIS', 'w').write('hello world2')

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2006-02-26 07:54:02 +0000
+++ bzrlib/tests/test_errors.py	2006-06-15 05:36:34 +0000
@@ -27,8 +27,8 @@
     def test_no_repo(self):
         dir = bzrdir.BzrDir.create(self.get_url())
         error = errors.NoRepositoryPresent(dir)
-        self.assertNotEqual(-1, str(error).find(repr(dir.transport.clone('..').base)))
-        self.assertEqual(-1, str(error).find(repr(dir.transport.base)))
+        self.assertNotEqual(-1, str(error).find((dir.transport.clone('..').base)))
+        self.assertEqual(-1, str(error).find((dir.transport.base)))
 
     def test_up_to_date(self):
         error = errors.UpToDateFormat(bzrdir.BzrDirFormat4())

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2006-04-09 06:19:54 +0000
+++ bzrlib/tests/test_merge.py	2006-06-20 03:57:11 +0000
@@ -1,9 +1,24 @@
+# Copyright (C) 2005, 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 import os
 from StringIO import StringIO
 
 from bzrlib.branch import Branch
 from bzrlib.builtins import merge
-from bzrlib.commit import commit
 from bzrlib.errors import UnrelatedBranches, NoCommits, BzrCommandError
 from bzrlib.merge import transform_tree, merge_inner
 from bzrlib.osutils import pathjoin

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2006-05-05 01:15:53 +0000
+++ bzrlib/tests/test_merge_core.py	2006-06-20 03:57:11 +0000
@@ -124,12 +124,6 @@
     def change_perms_tree(self, id, tree, mode):
         os.chmod(tree.full_path(id), mode)
 
-    def merge_changeset(self, merge_factory):
-        conflict_handler = changeset.ExceptionConflictHandler()
-        return make_merge_changeset(self.cset, self.this, self.base,
-                                    self.other, conflict_handler,
-                                    merge_factory)
-
     def apply_inv_change(self, inventory_change, orig_inventory):
         orig_inventory_by_path = {}
         for file_id, path in orig_inventory.iteritems():
@@ -168,14 +162,6 @@
             new_inventory[file_id] = path
         return new_inventory
 
-    def apply_changeset(self, cset, conflict_handler=None):
-        inventory_change = changeset.apply_changeset(cset,
-                                                     self.this.inventory_dict,
-                                                     self.this.dir,
-                                                     conflict_handler)
-        self.this.inventory_dict =  self.apply_inv_change(inventory_change, 
-                                                     self.this.inventory_dict)
-
     def cleanup(self):
         rmtree(self.dir)
 

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2006-06-06 16:16:09 +0000
+++ bzrlib/tests/test_msgeditor.py	2006-06-10 13:58:01 +0000
@@ -102,7 +102,7 @@
             f = file('fed.bat', 'w')
             f.write("""\
 @echo off
-%s fed.py %%1
+"%s" fed.py %%1
 """ % sys.executable)
             f.close()
             os.environ['BZR_EDITOR'] = 'fed.bat'
@@ -123,7 +123,7 @@
         working_tree = self.make_uncommitted_tree()
 
         if sys.platform == 'win32':
-            os.environ['BZR_EDITOR'] = 'del'
+            os.environ['BZR_EDITOR'] = 'cmd.exe /c del'
         else:
             os.environ['BZR_EDITOR'] = 'rm'
 

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2006-06-16 15:40:20 +0000
+++ bzrlib/tests/test_options.py	2006-06-20 03:30:14 +0000
@@ -44,7 +44,7 @@
 
     def test_unknown_short_opt(self):
         out, err = self.run_bzr_captured(['help', '-r'], retcode=3)
-        self.assertContainsRe(err, r'unknown short option')
+        self.assertContainsRe(err, r'unknown option')
 
 
 #     >>> parse_args('log -r 500'.split())

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2006-06-16 16:17:40 +0000
+++ bzrlib/tests/test_osutils.py	2006-06-18 18:56:23 +0000
@@ -25,7 +25,12 @@
 import bzrlib
 from bzrlib.errors import BzrBadParameterNotUnicode, InvalidURL
 import bzrlib.osutils as osutils
-from bzrlib.tests import TestCaseInTempDir, TestCase, TestSkipped
+from bzrlib.tests import (
+        StringIOWrapper,
+        TestCase, 
+        TestCaseInTempDir, 
+        TestSkipped,
+        )
 
 
 class TestOSUtils(TestCaseInTempDir):
@@ -342,3 +347,42 @@
         self.assertEqual(
             dir_sorted_paths,
             sorted(original_paths, cmp=osutils.compare_paths_prefix_order))
+
+
+class TestTerminalEncoding(TestCase):
+    """Test the auto-detection of proper terminal encoding."""
+
+    def setUp(self):
+        self._stdout = sys.stdout
+        self._stderr = sys.stderr
+        self._stdin = sys.stdin
+        self._user_encoding = bzrlib.user_encoding
+
+        self.addCleanup(self._reset)
+
+        sys.stdout = StringIOWrapper()
+        sys.stdout.encoding = 'stdout_encoding'
+        sys.stderr = StringIOWrapper()
+        sys.stderr.encoding = 'stderr_encoding'
+        sys.stdin = StringIOWrapper()
+        sys.stdin.encoding = 'stdin_encoding'
+        bzrlib.user_encoding = 'user_encoding'
+
+    def _reset(self):
+        sys.stdout = self._stdout
+        sys.stderr = self._stderr
+        sys.stdin = self._stdin
+        bzrlib.user_encoding = self._user_encoding
+
+    def test_get_terminal_encoding(self):
+        # first preference is stdout encoding
+        self.assertEqual('stdout_encoding', osutils.get_terminal_encoding())
+
+        sys.stdout.encoding = None
+        # if sys.stdout is None, fall back to sys.stdin
+        self.assertEqual('stdin_encoding', osutils.get_terminal_encoding())
+
+        sys.stdin.encoding = None
+        # and in the worst case, use bzrlib.user_encoding
+        self.assertEqual('user_encoding', osutils.get_terminal_encoding())
+

=== modified file 'bzrlib/tests/test_progress.py'
--- bzrlib/tests/test_progress.py	2006-03-08 19:51:44 +0000
+++ bzrlib/tests/test_progress.py	2006-06-21 03:14:59 +0000
@@ -16,7 +16,12 @@
 
 from StringIO import StringIO
 
-from bzrlib.progress import *
+from bzrlib.progress import (
+        DummyProgress, ChildProgress,
+        TTYProgressBar,
+        DotsProgressBar,
+        ProgressBarStack,
+        )
 from bzrlib.tests import TestCase
 
 class FakeStack:
@@ -26,6 +31,19 @@
     def top(self):
         return self.__top
 
+class InstrumentedProgress(TTYProgressBar):
+    """TTYProgress variant that tracks outcomes"""
+
+    def __init__(self, *args, **kwargs):
+        self.always_throttled = True
+        TTYProgressBar.__init__(self, *args, **kwargs)
+
+    def throttle(self, old_message):
+        result = TTYProgressBar.throttle(self, old_message)
+        if result is False:
+            self.always_throttled = False
+        
+
 class TestProgress(TestCase):
     def setUp(self):
         q = DummyProgress()
@@ -90,3 +108,15 @@
                 child.finished()
         finally:
             parent.finished()
+
+    def test_throttling(self):
+        pb = InstrumentedProgress(to_file=StringIO())
+        # instantaneous updates should be squelched
+        pb.update('me', 1, 1)
+        self.assertTrue(pb.always_throttled)
+        pb = InstrumentedProgress(to_file=StringIO())
+        # It's like an instant sleep(1)!
+        pb.start_time -= 1
+        # Updates after a second should not be squelched
+        pb.update('me', 1, 1)
+        self.assertFalse(pb.always_throttled)

=== modified file 'bzrlib/tests/test_read_bundle.py'
--- bzrlib/tests/test_read_bundle.py	2006-06-15 21:24:47 +0000
+++ bzrlib/tests/test_read_bundle.py	2006-06-20 02:32:24 +0000
@@ -97,9 +97,9 @@
         if wt is None:
             return
 
-        reader = bzrlib.bundle.read_bundle_from_url(
+        info = bzrlib.bundle.read_bundle_from_url(
                     self.get_url('test_bundle'))
-        info, bundle_tree = reader.get_bundle(wt.branch.repository)
+        bundle_tree = info.revision_tree(wt.branch.repository, info.target)
         self.assertEqual('commit-1', bundle_tree.revision_id)
 
     def test_read_fail(self):

=== modified file 'bzrlib/tests/test_repository.py'
--- bzrlib/tests/test_repository.py	2006-06-05 17:19:03 +0000
+++ bzrlib/tests/test_repository.py	2006-06-20 03:57:11 +0000
@@ -22,7 +22,7 @@
 also see this file.
 """
 
-from stat import *
+from stat import S_ISDIR
 from StringIO import StringIO
 
 import bzrlib

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2006-06-06 12:06:20 +0000
+++ bzrlib/tests/test_revision.py	2006-06-20 03:57:11 +0000
@@ -20,7 +20,6 @@
 
 from bzrlib.branch import Branch
 from bzrlib.errors import NoSuchRevision
-from bzrlib.commit import commit
 from bzrlib.graph import Graph
 from bzrlib.revision import (find_present_ancestors, combined_graph,
                              common_ancestor,
@@ -147,7 +146,6 @@
 class TestIntermediateRevisions(TestCaseWithTransport):
 
     def setUp(self):
-        from bzrlib.commit import commit
         TestCaseWithTransport.setUp(self)
         self.br1, self.br2 = make_branches(self)
         wt1 = self.br1.bzrdir.open_workingtree()

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-06-12 01:12:14 +0000
+++ bzrlib/tests/test_selftest.py	2006-06-20 03:57:11 +0000
@@ -35,6 +35,7 @@
                           )
 from bzrlib.tests.TestUtil import _load_module_by_name
 import bzrlib.errors as errors
+from bzrlib.trace import note
 
 
 class SelftestTests(TestCase):

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2006-03-05 02:20:07 +0000
+++ bzrlib/tests/test_source.py	2006-06-20 05:32:16 +0000
@@ -72,4 +72,4 @@
         # written. Note that this is an exact equality so that when the number
         # drops, it is not given a buffer but rather this test updated
         # immediately.
-        self.assertEqual(4, occurences)
+        self.assertEqual(2, occurences)

=== modified file 'bzrlib/tests/test_textfile.py'
--- bzrlib/tests/test_textfile.py	2006-04-19 02:16:05 +0000
+++ bzrlib/tests/test_textfile.py	2006-06-20 03:57:11 +0000
@@ -18,7 +18,7 @@
 
 from bzrlib.errors import BinaryFile
 from bzrlib.tests import TestCase, TestCaseInTempDir
-from bzrlib.textfile import *
+from bzrlib.textfile import text_file, check_text_lines, check_text_path
 
 
 class TextFile(TestCase):

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2005-12-27 22:56:50 +0000
+++ bzrlib/tests/test_trace.py	2006-06-20 03:30:14 +0000
@@ -1,5 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
-#   Authors: Robert Collins <robert.collins@canonical.com>
+# Copyright (C) 2005, 2006 by Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,47 +18,64 @@
 
 """Tests for trace library"""
 
+import errno
 import os
 import sys
+from StringIO import StringIO
 
 from bzrlib.tests import TestCaseInTempDir, TestCase
-from bzrlib.trace import format_exception_short, mutter
-from bzrlib.errors import NotBranchError, BzrError, BzrNewError
+from bzrlib.trace import mutter, report_exception
+from bzrlib.errors import NotBranchError
+
+
+def _format_exception():
+    """Format an exception as it would normally be displayed to the user"""
+    buf = StringIO()
+    report_exception(sys.exc_info(), buf)
+    return buf.getvalue()
+
 
 class TestTrace(TestCase):
+
     def test_format_sys_exception(self):
-        """Short formatting of exceptions"""
         try:
             raise NotImplementedError, "time travel"
         except NotImplementedError:
             pass
-        error_lines = format_exception_short(sys.exc_info()).splitlines()
-        self.assertEqualDiff(error_lines[0], 
-                'exceptions.NotImplementedError: time travel')
-        self.assertContainsRe(error_lines[1], 
-                r'^  at .*trace\.py line \d+$')  
-        self.assertContainsRe(error_lines[2], 
-                r'^  in test_format_sys_exception$')
+        err = _format_exception()
+        self.assertEqualDiff(err.splitlines()[0],
+                'bzr: ERROR: exceptions.NotImplementedError: time travel')
+        self.assertContainsRe(err,
+                r'File.*test_trace.py')
+
+    def test_format_interrupt_exception(self):
+        try:
+            raise KeyboardInterrupt()
+        except KeyboardInterrupt:
+            # XXX: Some risk that a *real* keyboard interrupt won't be seen
+            pass
+        msg = _format_exception()
+        self.assertTrue(len(msg) > 0)
+        self.assertEqualDiff(msg, 'bzr: interrupted\n')
+
+    def test_format_os_error(self):
+        try:
+            file('nosuchfile22222')
+        except (OSError, IOError):
+            pass
+        msg = _format_exception()
+        self.assertContainsRe(msg, r'^bzr: ERROR: \[Errno .*\] No such file.*nosuchfile')
+
 
     def test_format_exception(self):
-        """Short formatting of exceptions"""
+        """Short formatting of bzr exceptions"""
         try:
             raise NotBranchError, 'wibble'
         except NotBranchError:
             pass
-        msg = format_exception_short(sys.exc_info())
-        self.assertEqualDiff(msg, 'Not a branch: wibble')
-
-    def test_format_old_exception(self):
-        # format a class that doesn't descend from BzrNewError; 
-        # remove this test when everything is unified there
-        self.assertFalse(issubclass(BzrError, BzrNewError))
-        try:
-            raise BzrError('some old error')
-        except BzrError:
-            pass
-        msg = format_exception_short(sys.exc_info())
-        self.assertEqualDiff(msg, 'some old error')
+        msg = _format_exception()
+        self.assertTrue(len(msg) > 0)
+        self.assertEqualDiff(msg, 'bzr: ERROR: Not a branch: wibble\n')
 
     def test_trace_unicode(self):
         """Write Unicode to trace log"""
@@ -67,6 +83,15 @@
         self.assertContainsRe('the unicode character',
                 self._get_log())
 
+    def test_report_broken_pipe(self):
+        try:
+            raise IOError(errno.EPIPE, 'broken pipe foofofo')
+        except IOError, e:
+            msg = _format_exception()
+            self.assertEquals(msg, "bzr: broken pipe\n")
+        else:
+            self.fail("expected error not raised")
+
     def test_mutter_never_fails(self):
         # Even if the decode/encode stage fails, mutter should not
         # raise an exception
@@ -81,4 +106,3 @@
         self.assertContainsRe(log, 'Writing a greek mu')
         self.assertContainsRe(log, 'UnicodeError')
         self.assertContainsRe(log, "'But fails in an ascii string")
-

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-06-12 14:39:27 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-06-18 18:56:23 +0000
@@ -922,7 +922,7 @@
                 ]
 
         try:
-            self.build_tree(files, transport=t)
+            self.build_tree(files, transport=t, line_endings='binary')
         except UnicodeError:
             raise TestSkipped("cannot handle unicode paths in current encoding")
 

=== modified file 'bzrlib/tests/test_tuned_gzip.py'
--- bzrlib/tests/test_tuned_gzip.py	2006-04-20 04:52:19 +0000
+++ bzrlib/tests/test_tuned_gzip.py	2006-06-20 03:57:11 +0000
@@ -25,7 +25,7 @@
 import zlib
 
 
-from bzrlib.tuned_gzip import *
+from bzrlib import tuned_gzip
 
 
 class FakeDecompress(object):
@@ -74,7 +74,7 @@
         # read more bytes if there is less than 8 bytes (the 
         # gzip trailer) unread.
         stream = StringIO('\0\0\0\0\0\0\0\0')
-        myfile = GzipFile(fileobj=stream)
+        myfile = tuned_gzip.GzipFile(fileobj=stream)
         # disable the _new_member check, we are microtesting.
         myfile._new_member = False
         myfile.crc = zlib.crc32('')

=== modified file 'bzrlib/tests/test_ui.py'
--- bzrlib/tests/test_ui.py	2006-05-12 06:59:47 +0000
+++ bzrlib/tests/test_ui.py	2006-06-21 02:33:40 +0000
@@ -157,6 +157,7 @@
         factory.stdin = StringIO("yada\ny\n")
         pb = self.apply_redirected(
             factory.stdin, factory.stdout, factory.stdout, factory.nested_progress_bar)
+        pb.start_time = None
         self.apply_redirected(
             factory.stdin, factory.stdout, factory.stdout, pb.update, "foo", 0, 1)
         self.assertEqual(

=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2006-06-15 21:54:28 +0000
+++ bzrlib/tests/test_urlutils.py	2006-06-18 18:56:23 +0000
@@ -91,7 +91,9 @@
         norm_file('uni/%25C2%25B5', u'uni/%C2%B5')
         norm_file('uni/%20b', u'uni/ b')
         # All the crazy characters get escaped in local paths => file:/// urls
-        norm_file('%27%3B/%3F%3A%40%26%3D%2B%24%2C%23%20', "';/?:@&=+$,# ")
+        # The ' ' character must not be at the end, because on win32
+        # it gets stripped off by ntpath.abspath
+        norm_file('%27%20%3B/%3F%3A%40%26%3D%2B%24%2C%23', "' ;/?:@&=+$,#")
 
     def test_normalize_url_hybrid(self):
         # Anything with a scheme:// should be treated as a hybrid url
@@ -254,23 +256,31 @@
 
     def test_win32_local_path_to_url(self):
         to_url = urlutils._win32_local_path_to_url
-        self.assertEqual('file:///C:/path/to/foo',
+        self.assertEqual('file:///c:/path/to/foo',
             to_url('C:/path/to/foo'))
+        # BOGUS: on win32, ntpath.abspath will strip trailing
+        #       whitespace, so this will always fail
+        #       Though under linux, it fakes abspath support
+        #       and thus will succeed
+        # self.assertEqual('file:///C:/path/to/foo%20',
+        #     to_url('C:/path/to/foo '))
+        self.assertEqual('file:///c:/path/to/f%20oo',
+            to_url('C:/path/to/f oo'))
 
         try:
             result = to_url(u'd:/path/to/r\xe4ksm\xf6rg\xe5s')
         except UnicodeError:
             raise TestSkipped("local encoding cannot handle unicode")
 
-        self.assertEqual('file:///D:/path/to/r%C3%A4ksm%C3%B6rg%C3%A5s', result)
+        self.assertEqual('file:///d:/path/to/r%C3%A4ksm%C3%B6rg%C3%A5s', result)
 
     def test_win32_local_path_from_url(self):
         from_url = urlutils._win32_local_path_from_url
-        self.assertEqual('C:/path/to/foo',
+        self.assertEqual('c:/path/to/foo',
             from_url('file:///C|/path/to/foo'))
-        self.assertEqual(u'D:/path/to/r\xe4ksm\xf6rg\xe5s',
+        self.assertEqual(u'd:/path/to/r\xe4ksm\xf6rg\xe5s',
             from_url('file:///d|/path/to/r%C3%A4ksm%C3%B6rg%C3%A5s'))
-        self.assertEqual(u'D:/path/to/r\xe4ksm\xf6rg\xe5s',
+        self.assertEqual(u'd:/path/to/r\xe4ksm\xf6rg\xe5s',
             from_url('file:///d:/path/to/r%c3%a4ksm%c3%b6rg%c3%a5s'))
 
         self.assertRaises(InvalidURL, from_url, '/path/to/foo')
@@ -370,8 +380,8 @@
 
         test('http://foo', 'http://foo')
         if sys.platform == 'win32':
-            test('C:/foo/path', 'file:///C|/foo/path')
-            test('C:/foo/path', 'file:///C:/foo/path')
+            test('c:/foo/path', 'file:///C|/foo/path')
+            test('c:/foo/path', 'file:///C:/foo/path')
         else:
             test('/foo/path', 'file:///foo/path')
 

=== modified file 'bzrlib/tests/test_whitebox.py'
--- bzrlib/tests/test_whitebox.py	2006-05-05 01:15:53 +0000
+++ bzrlib/tests/test_whitebox.py	2006-06-20 07:55:43 +0000
@@ -1,8 +1,24 @@
+# Copyright (C) 2005, 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 import os
 import unittest
 
 from bzrlib.tests import TestCaseWithTransport, TestCase
-from bzrlib.branch import ScratchBranch, Branch
+from bzrlib.branch import Branch
 from bzrlib.errors import PathNotChild
 from bzrlib.osutils import relpath, pathjoin, abspath, realpath
 

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2006-06-18 03:36:38 +0000
+++ bzrlib/tests/test_workingtree.py	2006-06-20 05:32:16 +0000
@@ -20,17 +20,14 @@
 
 import bzrlib
 from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
+from bzrlib import bzrdir, conflicts, errors, workingtree
 from bzrlib.bzrdir import BzrDir
-from bzrlib.conflicts import *
-import bzrlib.errors as errors
 from bzrlib.errors import NotBranchError, NotVersionedError
 from bzrlib.lockdir import LockDir
 from bzrlib.osutils import pathjoin, getcwd, has_symlinks
 from bzrlib.tests import TestCaseWithTransport, TestSkipped
 from bzrlib.trace import mutter
 from bzrlib.transport import get_transport
-import bzrlib.workingtree as workingtree
 from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
                                 WorkingTree)
 
@@ -219,20 +216,20 @@
         self.assertRaises(errors.UnsupportedOperation, tree.set_conflicts,
                           None)
         file('lala.BASE', 'wb').write('labase')
-        expected = ContentsConflict('lala')
+        expected = conflicts.ContentsConflict('lala')
         self.assertEqual(list(tree.conflicts()), [expected])
         file('lala', 'wb').write('la')
         tree.add('lala', 'lala-id')
-        expected = ContentsConflict('lala', file_id='lala-id')
+        expected = conflicts.ContentsConflict('lala', file_id='lala-id')
         self.assertEqual(list(tree.conflicts()), [expected])
         file('lala.THIS', 'wb').write('lathis')
         file('lala.OTHER', 'wb').write('laother')
         # When "text conflict"s happen, stem, THIS and OTHER are text
-        expected = TextConflict('lala', file_id='lala-id')
+        expected = conflicts.TextConflict('lala', file_id='lala-id')
         self.assertEqual(list(tree.conflicts()), [expected])
         os.unlink('lala.OTHER')
         os.mkdir('lala.OTHER')
-        expected = ContentsConflict('lala', file_id='lala-id')
+        expected = conflicts.ContentsConflict('lala', file_id='lala-id')
         self.assertEqual(list(tree.conflicts()), [expected])
 
 

=== modified file 'bzrlib/tests/treeshape.py'
--- bzrlib/tests/treeshape.py	2005-12-01 17:25:16 +0000
+++ bzrlib/tests/treeshape.py	2006-06-20 03:57:11 +0000
@@ -65,7 +65,7 @@
         filenames.sort()
         for fn in filenames:
             fullpath = pathjoin(dirpath, fn)
-            self.assertFalse(fullpath[-1] in '@/')
+            assert not (fullpath[-1] in '@/')
             info = os.lstat(fullpath)
             if stat.S_ISLNK(info.st_mode):
                 yield (fullpath + '@', os.readlink(fullpath))

=== modified file 'bzrlib/tests/workingtree_implementations/test_commit.py'
--- bzrlib/tests/workingtree_implementations/test_commit.py	2006-06-15 17:26:25 +0000
+++ bzrlib/tests/workingtree_implementations/test_commit.py	2006-06-20 05:32:16 +0000
@@ -1,4 +1,4 @@
-# (C) 2005,2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,20 +18,13 @@
 from cStringIO import StringIO
 import os
 
-import bzrlib
-import bzrlib.branch
-from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
-from bzrlib.bzrdir import BzrDir
-import bzrlib.errors as errors
+from bzrlib import branch, bzrdir, errors, ui, workingtree
 from bzrlib.errors import (NotBranchError, NotVersionedError, 
                            UnsupportedOperation)
 from bzrlib.osutils import pathjoin, getcwd, has_symlinks
 from bzrlib.tests import TestSkipped, TestCase
 from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
 from bzrlib.trace import mutter
-import bzrlib.ui as ui
-import bzrlib.workingtree as workingtree
 from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
                                 WorkingTree)
 

=== modified file 'bzrlib/tests/workingtree_implementations/test_is_control_filename.py'
--- bzrlib/tests/workingtree_implementations/test_is_control_filename.py	2006-02-16 02:53:00 +0000
+++ bzrlib/tests/workingtree_implementations/test_is_control_filename.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -15,24 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from cStringIO import StringIO
 import os
 
-import bzrlib
-import bzrlib.branch
-from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
-from bzrlib.bzrdir import BzrDir
-import bzrlib.errors as errors
-from bzrlib.errors import NotBranchError, NotVersionedError
 from bzrlib.osutils import basename
-from bzrlib.tests import TestSkipped
 from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
-from bzrlib.trace import mutter
-from bzrlib.transport import get_transport
-import bzrlib.workingtree as workingtree
-from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
-                                WorkingTree)
 
 
 class TestIsControlFilename(TestCaseWithWorkingTree):

=== modified file 'bzrlib/tests/workingtree_implementations/test_pull.py'
--- bzrlib/tests/workingtree_implementations/test_pull.py	2006-02-22 05:45:47 +0000
+++ bzrlib/tests/workingtree_implementations/test_pull.py	2006-06-20 03:57:11 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,21 +18,13 @@
 from cStringIO import StringIO
 import os
 
-import bzrlib
-import bzrlib.branch
-from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
-from bzrlib.bzrdir import BzrDir
-import bzrlib.errors as errors
+from bzrlib import errors
 from bzrlib.errors import NotBranchError, NotVersionedError
 from bzrlib.osutils import basename
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
 from bzrlib.trace import mutter
 from bzrlib.transport import get_transport
-import bzrlib.workingtree as workingtree
-from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
-                                WorkingTree)
 
 
 class TestPull(TestCaseWithWorkingTree):

=== modified file 'bzrlib/tests/workingtree_implementations/test_workingtree.py'
--- bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-06-06 12:06:20 +0000
+++ bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-06-20 07:55:43 +0000
@@ -1,4 +1,4 @@
-# (C) 2005,2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,22 +19,16 @@
 import os
 
 import bzrlib
-import bzrlib.branch
-from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
-from bzrlib.bzrdir import BzrDir
-import bzrlib.errors as errors
+from bzrlib import branch, bzrdir, errors, urlutils, workingtree
 from bzrlib.errors import (NotBranchError, NotVersionedError, 
                            UnsupportedOperation)
 from bzrlib.osutils import pathjoin, getcwd, has_symlinks
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
 from bzrlib.trace import mutter
-import bzrlib.urlutils as urlutils
-import bzrlib.workingtree as workingtree
 from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
                                 WorkingTree)
-
+from bzrlib.conflicts import ConflictList
 
 class TestWorkingTree(TestCaseWithWorkingTree):
 
@@ -151,10 +145,22 @@
         tree.revert(['hello.txt'])
         self.failUnlessExists('hello.txt')
 
-    def test_unknowns(self):
-        tree = self.make_branch_and_tree('.')
-        self.build_tree(['hello.txt',
-                         'hello.txt.~1~'])
+    def test_unknowns_by_default_patterns(self):
+        """Backup files are ignored by default"""
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(['hello.txt',
+                         'hello.txt.~1~'])
+        self.assertEquals(list(tree.unknowns()),
+                          ['hello.txt'])
+
+    def test_versioned_files_not_unknown(self):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(['hello.txt',
+                         'hello.txt.~1~'])
+        tree.add('hello.txt')
+        self.assertEquals(list(tree.unknowns()),
+                          [])
+        tree.remove('hello.txt')
         self.assertEquals(list(tree.unknowns()),
                           ['hello.txt'])
 
@@ -175,7 +181,7 @@
     def test_initialize(self):
         # initialize should create a working tree and branch in an existing dir
         t = self.make_branch_and_tree('.')
-        b = Branch.open('.')
+        b = branch.Branch.open('.')
         self.assertEqual(t.branch.base, b.base)
         t2 = WorkingTree.open('.')
         self.assertEqual(t.basedir, t2.basedir)
@@ -388,7 +394,7 @@
         # current format
         self.build_tree(['checkout/', 'tree/file'])
         checkout = bzrdir.BzrDirMetaFormat1().initialize('checkout')
-        bzrlib.branch.BranchReferenceFormat().initialize(checkout, main_branch)
+        branch.BranchReferenceFormat().initialize(checkout, main_branch)
         old_tree = self.workingtree_format.initialize(checkout)
         # now commit to 'tree'
         wt.add('file')
@@ -419,7 +425,7 @@
         # current format
         self.build_tree(['checkout/', 'tree/file'])
         checkout = bzrdir.BzrDirMetaFormat1().initialize('checkout')
-        bzrlib.branch.BranchReferenceFormat().initialize(checkout, main_branch)
+        branch.BranchReferenceFormat().initialize(checkout, main_branch)
         old_tree = self.workingtree_format.initialize(checkout)
         # now commit to 'tree'
         wt.add('file')
@@ -526,7 +532,7 @@
         tree.add('blo')
         tree.commit("blah", allow_pointless=False)
         base = tree.basis_tree()
-        BzrDir.open("mine").sprout("other")
+        bzrdir.BzrDir.open("mine").sprout("other")
         file('other/bloo', 'wb').write('two')
         othertree = WorkingTree.open('other')
         othertree.commit('blah', allow_pointless=False)
@@ -540,7 +546,6 @@
         self.assertEqual(len(tree.conflicts()), 1)
 
     def test_clear_merge_conflicts(self):
-        from bzrlib.conflicts import ConflictList
         tree = self.make_merge_conflicts()
         self.assertEqual(len(tree.conflicts()), 1)
         try:

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2006-06-10 00:21:11 +0000
+++ bzrlib/trace.py	2006-06-20 05:32:16 +0000
@@ -1,4 +1,18 @@
-# Copyright (C) 2005, Canonical Ltd
+# Copyright (C) 2005, 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 """Messages and logging for bazaar-ng.
 
@@ -32,21 +46,21 @@
 form.
 """
 
-# TODO: in debug mode, stderr should get full tracebacks and also
-# debug messages.  (Is this really needed?)
-
 # FIXME: Unfortunately it turns out that python's logging module
 # is quite expensive, even when the message is not printed by any handlers.
 # We should perhaps change back to just simply doing it here.
 
 
+import errno
+import os
 import sys
-import os
 import logging
 
 import bzrlib
 from bzrlib.errors import BzrError, BzrNewError
-
+from bzrlib.symbol_versioning import (deprecated_function,
+        zero_nine,
+        )
 
 _file_handler = None
 _stderr_handler = None
@@ -56,25 +70,6 @@
 _bzr_log_file = None
 
 
-class QuietFormatter(logging.Formatter):
-    """Formatter that suppresses the details of errors.
-
-    This is used by default on stderr so as not to scare the user.
-    """
-    # At first I tried overriding FormatException to suppress the
-    # exception details, but that has global effect: no loggers
-    # can get the exception details is we suppress them here.
-
-    def format(self, record):
-        if record.levelno >= logging.WARNING:
-            s = 'bzr: ' + record.levelname + ': '
-        else:
-            s = ''
-        s += record.getMessage()
-        if record.exc_info:
-            s += '\n' + format_exception_short(record.exc_info)
-        return s
-        
 # configure convenient aliases for output routines
 
 _bzr_logger = logging.getLogger('bzr')
@@ -135,7 +130,7 @@
     # information if something goes wrong.  In a future version this
     # file will be removed on successful completion.
     global _file_handler, _bzr_log_file
-    import stat, codecs
+    import codecs
 
     trace_fname = os.path.join(os.path.expanduser(tracefilename))
     _rollover_trace_maybe(trace_fname)
@@ -157,15 +152,7 @@
         warning("failed to open trace file: %s" % (e))
 
 
-def log_startup(argv):
-    debug('\n\nbzr %s invoked on python %s (%s)',
-          bzrlib.__version__,
-          '.'.join(map(str, sys.version_info)),
-          sys.platform)
-    debug('  arguments: %r', argv)
-    debug('  working dir: %r', os.getcwdu())
-
-
+@deprecated_function(zero_nine)
 def log_exception(msg=None):
     """Log the last exception to stderr and the trace file.
 
@@ -196,7 +183,6 @@
     # FIXME: if this is run twice, things get confused
     global _stderr_handler, _file_handler, _trace_file, _bzr_log_file
     _stderr_handler = logging.StreamHandler()
-    _stderr_handler.setFormatter(QuietFormatter())
     logging.getLogger('').addHandler(_stderr_handler)
     _stderr_handler.setLevel(logging.INFO)
     if not _file_handler:
@@ -204,8 +190,7 @@
     _trace_file = _bzr_log_file
     if _file_handler:
         _file_handler.setLevel(logging.DEBUG)
-    _bzr_logger.setLevel(logging.DEBUG) 
-
+    _bzr_logger.setLevel(logging.DEBUG)
 
 
 def be_quiet(quiet=True):
@@ -268,32 +253,40 @@
         enable_default_logging()
 
 
-def format_exception_short(exc_info):
-    """Make a short string form of an exception.
-
-    This is used for display to stderr.  It specially handles exception
-    classes without useful string methods.
-
-    The result has no trailing newline.
-
-    exc_info - typically an exception from sys.exc_info()
-    """
-    exc_type, exc_object, exc_tb = exc_info
-    try:
-        if exc_type is None:
-            return '(no exception)'
-        if isinstance(exc_object, (BzrError, BzrNewError)):
-            return str(exc_object)
-        else:
-            import traceback
-            tb = traceback.extract_tb(exc_tb)
-            msg = '%s: %s' % (exc_type, exc_object)
-            if msg[-1] == '\n':
-                msg = msg[:-1]
-            if tb:
-                msg += '\n  at %s line %d\n  in %s' % (tb[-1][:3])
-            return msg
-    except Exception, formatting_exc:
-        # XXX: is this really better than just letting it run up?
-        return '(error formatting exception of type %s: %s)' \
-                % (exc_type, formatting_exc)
+def report_exception(exc_info, err_file):
+    exc_type, exc_object, exc_tb = exc_info
+    if (isinstance(exc_object, IOError)
+        and getattr(exc_object, 'errno', None) == errno.EPIPE):
+        print >>err_file, "bzr: broken pipe"
+    elif isinstance(exc_object, KeyboardInterrupt):
+        print >>err_file, "bzr: interrupted"
+    elif getattr(exc_object, 'is_user_error', False):
+        report_user_error(exc_info, err_file)
+    elif isinstance(exc_object, (OSError, IOError)):
+        # Might be nice to catch all of these and show them as something more
+        # specific, but there are too many cases at the moment.
+        report_user_error(exc_info, err_file)
+    else:
+        report_bug(exc_info, err_file)
+
+
+# TODO: Should these be specially encoding the output?
+def report_user_error(exc_info, err_file):
+    print >>err_file, "bzr: ERROR:", str(exc_info[1])
+
+
+def report_bug(exc_info, err_file):
+    """Report an exception that probably indicates a bug in bzr"""
+    import traceback
+    exc_type, exc_object, exc_tb = exc_info
+    print >>err_file, "bzr: ERROR: %s: %s" % (exc_type, exc_object)
+    print >>err_file
+    traceback.print_exception(exc_type, exc_object, exc_tb, file=err_file)
+    print >>err_file
+    print >>err_file, 'bzr %s on python %s (%s)' % \
+                       (bzrlib.__version__,
+                        '.'.join(map(str, sys.version_info)),
+                        sys.platform)
+    print >>err_file, 'arguments: %r' % sys.argv
+    print >>err_file
+    print >>err_file, "** please send this report to bazaar-ng@lists.ubuntu.com"

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2006-06-13 12:55:45 +0000
+++ bzrlib/transform.py	2006-06-20 03:57:11 +0000
@@ -539,9 +539,9 @@
         if child_id is None:
             return lexists(self._tree.abspath(childpath))
         else:
-            if tt.final_parent(child_id) != parent_id:
+            if self.final_parent(child_id) != parent_id:
                 return False
-            if child_id in tt._removed_contents:
+            if child_id in self._removed_contents:
                 # XXX What about dangling file-ids?
                 return False
             else:

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-06-09 09:04:53 +0000
+++ bzrlib/transport/__init__.py	2006-06-20 05:32:16 +0000
@@ -30,18 +30,21 @@
 from collections import deque
 from copy import deepcopy
 import re
-from stat import *
+from stat import S_ISDIR
 import sys
 from unittest import TestSuite
 import urllib
 import urlparse
+import warnings
 
 import bzrlib
 import bzrlib.errors as errors
 from bzrlib.errors import DependencyNotPresent
 import bzrlib.osutils as osutils
 from bzrlib.osutils import pumpfile
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_passed, deprecated_method, deprecated_function, 
+        DEPRECATED_PARAMETER,
+        zero_eight)
 from bzrlib.trace import mutter, warning
 import bzrlib.urlutils as urlutils
 
@@ -63,7 +66,7 @@
     # working, etc.
     global _protocol_handlers
     if deprecated_passed(override):
-        warn("register_transport(override) is deprecated")
+        warnings.warn("register_transport(override) is deprecated")
     _protocol_handlers.setdefault(prefix, []).insert(0, klass)
 
 
@@ -703,7 +706,7 @@
             raise errors.InvalidURL(base, error_str % m.group('proto'))
         # This doesn't look like a protocol, consider it a local path
         new_base = urlutils.local_path_to_url(base)
-        mutter('converting os path %r => url %s' , base, new_base)
+        mutter('converting os path %r => url %s', base, new_base)
         return new_base
 
     # Catch any URLs which are passing Unicode rather than ASCII

=== modified file 'bzrlib/transport/fakenfs.py'
--- bzrlib/transport/fakenfs.py	2006-04-02 22:42:19 +0000
+++ bzrlib/transport/fakenfs.py	2006-06-20 03:57:11 +0000
@@ -22,7 +22,7 @@
 To get a fake nfs transport use get_transport('fakenfs+' + real_url)
 """
 
-from stat import *
+from stat import S_ISDIR
 
 import bzrlib.errors as errors
 from bzrlib.transport.decorator import TransportDecorator, DecoratorServer

=== modified file 'bzrlib/transport/ftp.py'
--- bzrlib/transport/ftp.py	2006-05-22 05:32:51 +0000
+++ bzrlib/transport/ftp.py	2006-06-20 03:57:11 +0000
@@ -670,7 +670,7 @@
             *why* it cannot make a directory.
             """
             if len (line) != 2:
-                self.command_not_understood (string.join (line))
+                self.command_not_understood(''.join(line))
             else:
                 path = line[1]
                 try:

=== modified file 'bzrlib/transport/http/__init__.py'
--- bzrlib/transport/http/__init__.py	2006-04-25 20:18:04 +0000
+++ bzrlib/transport/http/__init__.py	2006-06-11 03:40:17 +0000
@@ -19,11 +19,13 @@
 There are separate implementation modules for each http client implementation.
 """
 
+from collections import deque
+from cStringIO import StringIO
 import errno
 import os
-from collections import deque
-from cStringIO import StringIO
+import posixpath
 import re
+import sys
 import urlparse
 import urllib
 from warnings import warn
@@ -398,6 +400,34 @@
         method = getattr(self, mname)
         method()
 
+    if sys.platform == 'win32':
+        # On win32 you cannot access non-ascii filenames without
+        # decoding them into unicode first.
+        # However, under Linux, you can access bytestream paths
+        # without any problems. If this function was always active
+        # it would probably break tests when LANG=C was set
+        def translate_path(self, path):
+            """Translate a /-separated PATH to the local filename syntax.
+
+            For bzr, all url paths are considered to be utf8 paths.
+            On Linux, you can access these paths directly over the bytestream
+            request, but on win32, you must decode them, and access them
+            as Unicode files.
+            """
+            # abandon query parameters
+            path = urlparse.urlparse(path)[2]
+            path = posixpath.normpath(urllib.unquote(path))
+            path = path.decode('utf-8')
+            words = path.split('/')
+            words = filter(None, words)
+            path = os.getcwdu()
+            for word in words:
+                drive, word = os.path.splitdrive(word)
+                head, word = os.path.split(word)
+                if word in (os.curdir, os.pardir): continue
+                path = os.path.join(path, word)
+            return path
+
 
 class TestingHTTPServer(BaseHTTPServer.HTTPServer):
     def __init__(self, server_address, RequestHandlerClass, test_case):

=== modified file 'bzrlib/transport/http/_urllib.py'
--- bzrlib/transport/http/_urllib.py	2006-04-06 05:28:00 +0000
+++ bzrlib/transport/http/_urllib.py	2006-06-20 03:57:11 +0000
@@ -14,6 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import errno
 import urllib, urllib2
 
 import bzrlib  # for the version

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-06-09 09:57:44 +0000
+++ bzrlib/transport/local.py	2006-06-20 07:55:43 +0000
@@ -51,6 +51,7 @@
             base = base + '/'
         super(LocalTransport, self).__init__(base)
         self._local_base = urlutils.local_path_from_url(base)
+        ## mutter("_local_base: %r => %r", base, self._local_base)
 
     def should_cache(self):
         return False
@@ -314,23 +315,6 @@
             return True
 
 
-class ScratchTransport(LocalTransport):
-    """A transport that works in a temporary dir and cleans up after itself.
-    
-    The dir only exists for the lifetime of the Python object.
-    Obviously you should not put anything precious in it.
-    """
-
-    def __init__(self, base=None):
-        if base is None:
-            base = tempfile.mkdtemp()
-        super(ScratchTransport, self).__init__(base)
-
-    def __del__(self):
-        rmtree(self.base, ignore_errors=True)
-        mutter("%r destroyed" % self)
-
-
 class LocalRelpathServer(Server):
     """A pretend server for local transports, using relpaths."""
 

=== modified file 'bzrlib/transport/memory.py'
--- bzrlib/transport/memory.py	2006-05-02 20:46:11 +0000
+++ bzrlib/transport/memory.py	2006-06-20 03:57:11 +0000
@@ -24,8 +24,9 @@
 import os
 import errno
 import re
-from stat import *
+from stat import S_IFREG, S_IFDIR
 from cStringIO import StringIO
+import warnings
 
 from bzrlib.errors import TransportError, NoSuchFile, FileExists, LockError
 from bzrlib.trace import mutter
@@ -260,7 +261,7 @@
     def __del__(self):
         # Should this warn, or actually try to cleanup?
         if self.transport:
-            warn("MemoryLock %r not explicitly unlocked" % (self.path,))
+            warnings.warn("MemoryLock %r not explicitly unlocked" % (self.path,))
             self.unlock()
 
     def unlock(self):

=== modified file 'bzrlib/ui/__init__.py'
--- bzrlib/ui/__init__.py	2006-05-04 08:39:32 +0000
+++ bzrlib/ui/__init__.py	2006-06-20 03:57:11 +0000
@@ -31,7 +31,7 @@
 import sys
 
 import bzrlib.progress
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method, zero_eight)
 
 
 class UIFactory(object):

=== modified file 'bzrlib/ui/text.py'
--- bzrlib/ui/text.py	2006-05-09 01:57:17 +0000
+++ bzrlib/ui/text.py	2006-06-20 03:57:11 +0000
@@ -23,7 +23,8 @@
 import sys
 
 import bzrlib.progress
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method, 
+        zero_eight)
 from bzrlib.ui import CLIUIFactory
 
 

=== modified file 'bzrlib/uncommit.py'
--- bzrlib/uncommit.py	2006-05-23 05:26:46 +0000
+++ bzrlib/uncommit.py	2006-06-20 03:57:11 +0000
@@ -18,7 +18,6 @@
 """
 
 import os
-import bzrlib
 from bzrlib.errors import BoundBranchOutOfDate
 
 def test_remove(filename):
@@ -35,7 +34,6 @@
     :param verbose: Print each step as you do it
     :param revno: Remove back to this revision
     """
-    from bzrlib.atomicfile import AtomicFile
     unlockable = []
     try:
         if tree is not None:

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2006-06-15 21:07:12 +0000
+++ bzrlib/urlutils.py	2006-06-18 18:56:23 +0000
@@ -19,7 +19,7 @@
 """A collection of function for handling URL operations."""
 
 import os
-from posixpath import split as _posix_split
+from posixpath import split as _posix_split, normpath as _posix_normpath
 import re
 import sys
 import urllib
@@ -165,41 +165,48 @@
     """
     # importing directly from posixpath allows us to test this 
     # on non-posix platforms
-    from posixpath import normpath
-    return 'file://' + escape(normpath(bzrlib.osutils._posix_abspath(path)))
+    return 'file://' + escape(_posix_normpath(
+        bzrlib.osutils._posix_abspath(path)))
 
 
 def _win32_local_path_from_url(url):
-    """Convert a url like file:///C|/path/to/foo into C:/path/to/foo"""
+    """Convert a url like file:///C:/path/to/foo into C:/path/to/foo"""
     if not url.startswith('file:///'):
         raise errors.InvalidURL(url, 'local urls must start with file:///')
     # We strip off all 3 slashes
     win32_url = url[len('file:///'):]
-    if (win32_url[0] not in 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
+    if (win32_url[0] not in ('abcdefghijklmnopqrstuvwxyz'
+                             'ABCDEFGHIJKLMNOPQRSTUVWXYZ')
         or win32_url[1] not in  '|:'
         or win32_url[2] != '/'):
-        raise errors.InvalidURL(url, 'Win32 file urls start with file:///X|/, where X is a valid drive letter')
-    # TODO: jam 20060426, we could .upper() or .lower() the drive letter
-    #       for better consistency.
-    return win32_url[0].upper() + u':' + unescape(win32_url[2:])
+        raise errors.InvalidURL(url, 'Win32 file urls start with'
+                ' file:///x:/, where x is a valid drive letter')
+    # Preferentially using .lower() because os.getcwd() returns
+    # paths with lowercase drive letters, and that helps
+    # bzrlib.osutils.relpath() work correctly
+    return win32_url[0].lower() + u':' + unescape(win32_url[2:])
 
 
 def _win32_local_path_to_url(path):
-    """Convert a local path like ./foo into a URL like file:///C|/path/to/foo
+    """Convert a local path like ./foo into a URL like file:///C:/path/to/foo
 
     This also handles transforming escaping unicode characters, etc.
     """
     # importing directly from ntpath allows us to test this 
-    # on non-win32 platforms
+    # on non-win32 platform
+    # FIXME: It turns out that on nt, ntpath.abspath uses nt._getfullpathname
+    #       which actually strips trailing space characters.
+    #       The worst part is that under linux ntpath.abspath has different
+    #       semantics, since 'nt' is not an available module.
     win32_path = bzrlib.osutils._nt_normpath(
         bzrlib.osutils._win32_abspath(path)).replace('\\', '/')
-    return 'file:///' + win32_path[0].upper() + ':' + escape(win32_path[2:])
+    return 'file:///' + win32_path[0].lower() + ':' + escape(win32_path[2:])
 
 
 local_path_to_url = _posix_local_path_to_url
 local_path_from_url = _posix_local_path_from_url
 MIN_ABS_FILEURL_LENGTH = len('file:///')
-WIN32_MIN_ABS_FILEURL_LENGTH = len('file:///C|/')
+WIN32_MIN_ABS_FILEURL_LENGTH = len('file:///C:/')
 
 if sys.platform == 'win32':
     local_path_to_url = _win32_local_path_to_url
@@ -376,7 +383,7 @@
         file:///foo/      => file:///foo
         # This is unique on win32 platforms, and is the only URL
         # format which does it differently.
-        file:///C|/       => file:///C|/
+        file:///c|/       => file:///c:/
     """
     if not url.endswith('/'):
         # Nothing to do

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2006-06-15 20:20:48 +0000
+++ bzrlib/versionedfile.py	2006-06-20 05:32:16 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005, 2006 by Canonical Ltd
 #
 # Authors:
 #   Johan Rydberg <jrydberg@gnu.org>
@@ -26,11 +26,14 @@
 
 import bzrlib.errors as errors
 from bzrlib.inter import InterObject
-from bzrlib.symbol_versioning import *
 from bzrlib.textmerge import TextMerge
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.tsort import topo_sort
 from bzrlib import ui
+from bzrlib.symbol_versioning import (deprecated_function,
+        deprecated_method,
+        zero_eight,
+        )
 
 
 class VersionedFile(object):

=== modified file 'bzrlib/weave.py'
--- bzrlib/weave.py	2006-06-10 00:21:11 +0000
+++ bzrlib/weave.py	2006-06-20 03:57:11 +0000
@@ -73,6 +73,7 @@
 import os
 import sha
 import time
+import warnings
 
 from bzrlib.trace import mutter
 from bzrlib.errors import (WeaveError, WeaveFormatError, WeaveParentMismatch,
@@ -84,7 +85,10 @@
 import bzrlib.errors as errors
 from bzrlib.osutils import sha_strings
 import bzrlib.patiencediff
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_method,
+        deprecated_function,
+        zero_eight,
+        )
 from bzrlib.tsort import topo_sort
 from bzrlib.versionedfile import VersionedFile, InterVersionedFile
 from bzrlib.weavefile import _read_weave_v5, write_weave_v5
@@ -635,7 +639,7 @@
 
     def annotate(self, version_id):
         if isinstance(version_id, int):
-            warn('Weave.annotate(int) is deprecated. Please use version names'
+            warnings.warn('Weave.annotate(int) is deprecated. Please use version names'
                  ' in all circumstances as of 0.8',
                  DeprecationWarning,
                  stacklevel=2
@@ -1239,7 +1243,7 @@
     from bzrlib.weavefile import read_weave
 
     wf = file(weave_file, 'rb')
-    w = read_weave(wf, WeaveVersionedFile)
+    w = read_weave(wf)
     # FIXME: doesn't work on pipes
     weave_size = wf.tell()
 
@@ -1419,47 +1423,9 @@
         raise ValueError('unknown command %r' % cmd)
     
 
-
-def profile_main(argv):
-    import tempfile, hotshot, hotshot.stats
-
-    prof_f = tempfile.NamedTemporaryFile()
-
-    prof = hotshot.Profile(prof_f.name)
-
-    ret = prof.runcall(main, argv)
-    prof.close()
-
-    stats = hotshot.stats.load(prof_f.name)
-    #stats.strip_dirs()
-    stats.sort_stats('cumulative')
-    ## XXX: Might like to write to stderr or the trace file instead but
-    ## print_stats seems hardcoded to stdout
-    stats.print_stats(20)
-            
-    return ret
-
-
-def lsprofile_main(argv): 
-    from bzrlib.lsprof import profile
-    ret,stats = profile(main, argv)
-    stats.sort()
-    stats.pprint()
-    return ret
-
-
 if __name__ == '__main__':
     import sys
-    if '--profile' in sys.argv:
-        args = sys.argv[:]
-        args.remove('--profile')
-        sys.exit(profile_main(args))
-    elif '--lsprof' in sys.argv:
-        args = sys.argv[:]
-        args.remove('--lsprof')
-        sys.exit(lsprofile_main(args))
-    else:
-        sys.exit(main(sys.argv))
+    sys.exit(main(sys.argv))
 
 
 class InterWeave(InterVersionedFile):

=== modified file 'bzrlib/weave_commands.py'
--- bzrlib/weave_commands.py	2006-03-24 11:12:04 +0000
+++ bzrlib/weave_commands.py	2006-06-20 03:57:11 +0000
@@ -23,7 +23,7 @@
 import sys
 
 from bzrlib.commands import Command
-from bzrlib.trace import mutter, warning
+from bzrlib.trace import warning
 
 class cmd_weave_list(Command):
     """List the revision ids present in a weave, in alphabetical order"""
@@ -64,7 +64,7 @@
     takes_args = ['weave_file', 'revision_a', 'revision_b']
 
     def run(self, weave_file, revision_a, revision_b):
-        from bzrlib.weavefile import read_weave, write_weave
+        from bzrlib.weavefile import read_weave
         w = read_weave(file(weave_file, 'rb'))
         for state, line in w.plan_merge(revision_a, revision_b):
             # make sure to print every line with a newline, even if it doesn't
@@ -84,7 +84,7 @@
     takes_args = ['weave_file', 'revision_a', 'revision_b']
 
     def run(self, weave_file, revision_a, revision_b):
-        from bzrlib.weavefile import read_weave, write_weave
+        from bzrlib.weavefile import read_weave
         w = read_weave(file(weave_file, 'rb'))
         p = w.plan_merge(revision_a, revision_b)
         sys.stdout.writelines(w.weave_merge(p))

=== modified file 'bzrlib/win32console.py'
--- bzrlib/win32console.py	2006-05-09 07:16:38 +0000
+++ bzrlib/win32console.py	2006-06-20 03:57:11 +0000
@@ -7,10 +7,12 @@
 
 import struct
 
+# We can cope without it; use a separate variable to help pyflakes
 try:
    import ctypes
+   has_ctypes = True
 except ImportError:
-   ctypes = None
+    has_ctypes = False
 
 
 WIN32_STDIN_HANDLE = -10
@@ -27,7 +29,7 @@
 
    Dependencies: ctypes should be installed.
    """
-   if ctypes is None:
+   if not has_ctypes:
        # no ctypes is found
        return (defaultx, defaulty)
 

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-06-18 03:39:50 +0000
+++ bzrlib/workingtree.py	2006-06-20 07:55:43 +0000
@@ -49,10 +49,9 @@
 import re
 import stat
 from time import time
+import warnings
 
 from bzrlib.atomicfile import AtomicFile
-from bzrlib.branch import (Branch,
-                           quotefn)
 from bzrlib.conflicts import Conflict, ConflictList, CONFLICT_SUFFIXES
 import bzrlib.bzrdir as bzrdir
 from bzrlib.decorators import needs_read_lock, needs_write_lock
@@ -60,7 +59,6 @@
 from bzrlib.errors import (BzrCheckError,
                            BzrError,
                            ConflictFormatError,
-                           DivergedBranches,
                            WeaveRevisionNotPresent,
                            NotBranchError,
                            NoSuchFile,
@@ -92,7 +90,13 @@
 from bzrlib.progress import DummyProgress, ProgressPhase
 from bzrlib.revision import NULL_REVISION
 from bzrlib.rio import RioReader, rio_file, Stanza
-from bzrlib.symbol_versioning import *
+from bzrlib.symbol_versioning import (deprecated_passed,
+        deprecated_method,
+        deprecated_function,
+        DEPRECATED_PARAMETER,
+        zero_eight,
+        )
+
 from bzrlib.textui import show_status
 import bzrlib.tree
 from bzrlib.transform import build_tree
@@ -231,7 +235,7 @@
         self.bzrdir = _bzrdir
         if not _internal:
             # not created via open etc.
-            warn("WorkingTree() is deprecated as of bzr version 0.8. "
+            warnings.warn("WorkingTree() is deprecated as of bzr version 0.8. "
                  "Please use bzrdir.open_workingtree or WorkingTree.open().",
                  DeprecationWarning,
                  stacklevel=2)
@@ -251,7 +255,7 @@
         mutter("opening working tree %r", basedir)
         if deprecated_passed(branch):
             if not _internal:
-                warn("WorkingTree(..., branch=XXX) is deprecated as of bzr 0.8."
+                warnings.warn("WorkingTree(..., branch=XXX) is deprecated as of bzr 0.8."
                      " Please use bzrdir.open_workingtree() or"
                      " WorkingTree.open().",
                      DeprecationWarning,
@@ -260,8 +264,6 @@
             self._branch = branch
         else:
             self._branch = self.bzrdir.open_branch()
-        assert isinstance(self.branch, Branch), \
-            "branch %r is not a Branch" % self.branch
         self.basedir = realpath(basedir)
         # if branch is at our basedir and is a format 6 or less
         if isinstance(self._format, WorkingTreeFormat2):
@@ -417,7 +419,7 @@
         XXX: When BzrDir is present, these should be created through that 
         interface instead.
         """
-        warn('delete WorkingTree.create', stacklevel=3)
+        warnings.warn('delete WorkingTree.create', stacklevel=3)
         transport = get_transport(directory)
         if branch.bzrdir.root_transport.base == transport.base:
             # same dir 
@@ -609,7 +611,7 @@
         inv = self.read_working_inventory()
         for f,file_id in zip(files, ids):
             if self.is_control_filename(f):
-                raise BzrError("cannot add control file %s" % quotefn(f))
+                raise errors.ForbiddenControlFileError(filename=f)
 
             fp = splitpath(f)
 
@@ -617,19 +619,13 @@
                 raise BzrError("cannot add top-level %r" % f)
 
             fullpath = normpath(self.abspath(f))
-
             try:
                 kind = file_kind(fullpath)
             except OSError, e:
                 if e.errno == errno.ENOENT:
                     raise NoSuchFile(fullpath)
-                # maybe something better?
-                raise BzrError('cannot add: not a regular file, symlink or directory: %s' % quotefn(f))
-
             if not InventoryEntry.versionable_kind(kind):
-                raise BzrError('cannot add: not a versionable file ('
-                               'i.e. regular file, symlink or directory): %s' % quotefn(f))
-
+                raise errors.BadFileKindError(filename=f, kind=kind)
             if file_id is None:
                 inv.add_path(f, kind=kind)
             else:
@@ -932,19 +928,6 @@
 
         These are files in the working directory that are not versioned or
         control files or ignored.
-        
-        >>> from bzrlib.bzrdir import ScratchDir
-        >>> d = ScratchDir(files=['foo', 'foo~'])
-        >>> b = d.open_branch()
-        >>> tree = d.open_workingtree()
-        >>> map(str, tree.unknowns())
-        ['foo']
-        >>> tree.add('foo')
-        >>> list(b.unknowns())
-        []
-        >>> tree.remove('foo')
-        >>> list(b.unknowns())
-        [u'foo']
         """
         for subp in self.extras():
             if not self.is_ignored(subp):
@@ -1285,14 +1268,13 @@
                 # TODO: Perhaps make this just a warning, and continue?
                 # This tends to happen when 
                 raise NotVersionedError(path=f)
-            mutter("remove inventory entry %s {%s}", quotefn(f), fid)
             if verbose:
                 # having remove it, it must be either ignored or unknown
                 if self.is_ignored(f):
                     new_status = 'I'
                 else:
                     new_status = '?'
-                show_status(new_status, inv[fid].kind, quotefn(f), to_file=to_file)
+                show_status(new_status, inv[fid].kind, f, to_file=to_file)
             del inv[fid]
 
         self._write_inventory(inv)
@@ -1586,7 +1568,7 @@
         except NoSuchFile:
             raise errors.NoWorkingTree(base=transport.base)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):

=== modified file 'bzrlib/xml5.py'
--- bzrlib/xml5.py	2006-05-24 08:26:20 +0000
+++ bzrlib/xml5.py	2006-06-20 03:57:11 +0000
@@ -1,3 +1,5 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -13,10 +15,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-from bzrlib.xml_serializer import ElementTree, SubElement, Element, Serializer
+from bzrlib.xml_serializer import SubElement, Element, Serializer
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 import bzrlib.inventory as inventory
-from bzrlib.revision import Revision        
+from bzrlib.revision import Revision
 from bzrlib.errors import BzrError
 
 
@@ -197,11 +199,11 @@
             return
         for prop_elt in props_elt:
             assert prop_elt.tag == 'property', \
-                "bad tag under properties list: %r" % p.tag
+                "bad tag under properties list: %r" % prop_elt.tag
             name = prop_elt.get('name')
             value = prop_elt.text
             assert name not in rev.properties, \
-                "repeated property %r" % p.name
+                "repeated property %r" % name
             rev.properties[name] = value
 
 

=== added file 'profile_imports.py'
--- profile_imports.py	1970-01-01 00:00:00 +0000
+++ profile_imports.py	2006-06-19 14:40:19 +0000
@@ -0,0 +1,173 @@
+# Copyright (C) 2006 by Canonical Ltd
+# Written by John Arbash Meinel <john@arbash-meinel.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""A custom importer and regex compiler which logs time spent."""
+
+import sre
+import sys
+import time
+
+
+_parent_stack = []
+_total_stack = {}
+_info = {}
+_cur_id = 0
+
+
+def stack_add(name, frame_name, frame_lineno, scope_name=None):
+    """Start a new record on the stack"""
+    global _cur_id
+    _cur_id += 1
+    this_stack = (_cur_id, name)
+
+    if _parent_stack:
+        _total_stack[_parent_stack[-1]].append(this_stack)
+    _total_stack[this_stack] = []
+    _parent_stack.append(this_stack)
+    _info[this_stack] = [len(_parent_stack)-1, frame_name, frame_lineno, scope_name]
+
+    return this_stack
+
+
+def stack_finish(this, cost):
+    """Finish a given entry, and record its cost in time"""
+    global _parent_stack
+
+    assert _parent_stack[-1] == this, \
+        'import stack does not end with this %s: %s' % (this, _parent_stack)
+    _parent_stack.pop()
+    _info[this].append(cost)
+
+
+def log_stack_info(out_file, sorted=True, hide_fast=True):
+    # Find all of the roots with import = 0
+    out_file.write(' cum  inline name\t\t\t\t\t\tframe\n')
+    todo = [(value[-1], key) for key,value in _info.iteritems() if value[0] == 0]
+
+    if sorted:
+        todo.sort()
+
+    while todo:
+        cum_time, cur = todo.pop()
+        children = _total_stack[cur]
+
+        c_times = []
+
+        info = _info[cur]
+        if hide_fast and info[-1] < 0.0001:
+            continue
+
+        # Compute the module time by removing the children times
+        mod_time = info[-1]
+        for child in children:
+            c_info = _info[child]
+            mod_time -= c_info[-1]
+            c_times.append((c_info[-1], child))
+
+        # indent, cum_time, mod_time, name,
+        # scope_name, frame_name, frame_lineno
+        out_file.write('%5.1f %5.1f %s %-35s\t@ %s:%d\n'
+            % (info[-1]*1000., mod_time*1000., '+'*info[0], 
+               cur[1][:40], info[1], info[2]))
+
+        if sorted:
+            c_times.sort()
+        else:
+            c_times.reverse()
+        todo.extend(c_times)
+
+
+_real_import = __import__
+
+def timed_import(name, globals, locals, fromlist):
+    """Wrap around standard importer to log import time"""
+
+    scope_name = globals.get('__name__', None)
+    if scope_name is None:
+        scope_name = globals.get('__file__', None)
+    if scope_name is None:
+        scope_name = globals.keys()
+    else:
+        # Trim out paths before bzrlib
+        loc = scope_name.find('bzrlib')
+        if loc != -1:
+            scope_name = scope_name[loc:]
+        # For stdlib, trim out early paths
+        loc = scope_name.find('python2.4')
+        if loc != -1:
+            scope_name = scope_name[loc:]
+
+    # Figure out the frame that is doing the importing
+    frame = sys._getframe(1)
+    frame_name = frame.f_globals.get('__name__', '<unknown>')
+    extra = ''
+    cur_frame = 1
+    if frame_name.endswith('demandload'):
+        # If this was demandloaded, we have 3 frames to ignore
+        extra = ' (demandload)'
+        frame = sys._getframe(4)
+        cur_frame = 4
+        frame_name = frame.f_globals.get('__name__', '<unknown>')
+    frame_lineno = frame.f_lineno
+
+    this = stack_add(name+extra, frame_name, frame_lineno, scope_name)
+
+    tstart = time.time()
+    try:
+        # Do the import
+        mod = _real_import(name, globals, locals, fromlist)
+    finally:
+        tload = time.time()-tstart
+        stack_finish(this, tload)
+
+    return mod
+
+
+_real_compile = sre._compile
+
+def timed_compile(*args, **kwargs):
+    """Log how long it takes to compile a regex"""
+
+    # And who is requesting this?
+    frame = sys._getframe(2)
+    frame_name = frame.f_globals.get('__name__', '<unknown>')
+    frame_lineno = frame.f_lineno
+
+    this = stack_add(repr(args[0]), frame_name, frame_lineno)
+
+    tstart = time.time()
+    try:
+        # Measure the compile time
+        comp = _real_compile(*args, **kwargs)
+    finally:
+        tcompile = time.time() - tstart
+        stack_finish(this, tcompile)
+
+    return comp
+
+
+def install():
+    """Install the hooks for measuring import and regex compile time."""
+    __builtins__['__import__'] = timed_import
+    sre._compile = timed_compile
+
+
+def uninstall():
+    """Remove the import and regex compile timing hooks."""
+    __builtins__['__import__'] = _real_import
+    sre._compile = _real_compile
+

=== modified file 'setup.py'
--- setup.py	2006-06-04 10:55:31 +0000
+++ setup.py	2006-06-21 13:54:14 +0000
@@ -88,6 +88,7 @@
       description='Friendly distributed version control system',
       license='GNU GPL v2',
       packages=['bzrlib',
+                'bzrlib.benchmarks',
                 'bzrlib.doc',
                 'bzrlib.doc.api',
                 'bzrlib.export',

